


**********************************************************************

* Author: [Vanessa Baird]
* Vanessa.Baird@colorado.edu 

* Date Created: [5/19/22]
* Contents: Cleaning Inverted Scale World Values

* Find original data here 
* https://www.worldvaluessurvey.org/WVSDocumentationWV7.jsp 
* World Values Survey Wave 7 Inverted stata v3 0.zip

* Above is identical to my file 
* World_Values_7_Orig.dta (downloaded in May 2022)


**********************************************************************
* Master World Values recodes, mising values decisions, 
*	and other documentation 
**********************************************************************


* PLEASE READ DOCUMENTATION CAREFULLY; I TRIED TO MAKE IT CONCISE

**********************************************************************
* Personal path  
**********************************************************************

* This directory directs Stata to Vanessa Baird's OneDrive 
* Note: you can use my globals for your paths after you put your personal path here 

*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*///

* This is my path; YOU MUST PLUG IN YOUR OWN PATH HERE 

*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*///

global MyWVPath "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/Data and documentation/WorldValues/"

*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*///


* FOR WINDOWS, IT MIGHT LOOK LIKE THIS

* global WorldValuesPath "C:\WorldValues\"

*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*\/!\!/!\*///

* After you designate your own path as $MyPath, and copy the World Values directory 
*	from my shared onedrive, you can run this do file


**********************************************************************
* Create macros for paths 
*	and create date strings to keep data created on different dates separate 
do "${MyWVPath}Documentation/wv_macro_paths.do"

**********************************************************************
* These are the commands in above do file - 
*	separate so that you can change it to match your file system 
**********************************************************************

* global date: display %td_CCYY_NN_DD date(c(current_date), "DMY")

* global date_string = subinstr(trim("$date"), " " , "-", .)

* Global paths 
* . 
* . * This directory directs Stata to OneDrive Data and Documentation folder, for World Values Documentation files 
* . 
* . global WVDoc "${MyWVPath}Documentation/"
* 
* . 
* . * This directory contains logs and Stata created codebooks  
* . global WVLogsCodebooks "${WVDoc}Logs and codebooks"
* 
* * 






**********************************************************************
 
* /!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!

* Some variables should be double checked !!!!! 

* There are likely some errors in the data downloaded from the WorldValues website (but may just be problematic value labels)
 
* /!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!

**********************************************************************

use "${MyWVPath}World_Values_7_Orig.dta"

save "${MyWVPath}${date_string}_World_Values_7_Clean.dta" , replace 


* file /Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/Data and documentation/WorldValues/2022-05-17_World_Values_7_Clean.dta saved



**********************************************************************
* Notes on this version of the data and related documentation 
*	for entire data file

* 		(Notes on MY PERSONAL coding decisions in next section) 
**********************************************************************


**********************************************************************
* Sometimes, the value labels in the data do not correctly match the codebook 
**********************************************************************

* On the website, you will find the question wording 
* WVS-7 Master Questionnaire 2017-2020 English.pdf

* Many scales were "inverted" in the data, following the documentation in:
*	 WVS Explanatory note on scales recoding.pdf


* Mostly, the labels in the data 
* 	World Values Survey Wave 7 Inverted stata v3 0.zip 
* 	match the  WVS Explanatory note on scales recoding.pdf

* BUT SOMETIMES THEY DO NOT MATCH 
 
**********************************************************************

* Example   
* 	(Note: in the original data, the missings and no answers are usually negative; thus the if QXXX > 0)

* The immigration (Q121 - Q129) scales all say "agree" is high in the data, and some are "agree immigration causes problems" 
* 	and some are "agree immigration is good" which means they should be negatively correlated 


* Illustration  

* tab Q123 if Q123 > 0 

*    Immigration in your |
*   country: Strengthens |
*     cultural diversity |      Freq.     Percent        Cum.
* -----------------------+-----------------------------------
*               Disagree |     21,947       25.93       28.91
*            Hard to say |     16,419       19.40       48.31
*                  Agree |     43,750       51.69      100.00


* tab Q124 if Q124 > 0 

*    Immigration in your |
* country: Increases the |
*             crime rate |      Freq.     Percent        Cum.
* -----------------------+-----------------------------------
*               Disagree |     25,910       30.61       32.96
*            Hard to say |     19,371       22.89       55.84
*                  Agree |     37,372       44.16      100.00


* But they are positively correlated:

* corr Q123 Q124 if Q123 > 0 &  Q124 > 0
* (obs=40,975)

*         Q123 |   1.0000
*         Q124 |   0.1619   1.0000

**********************************************************************
* Thus: likely "Agree" in value label for original variable means "Disagree"

* My recodes reflect my best guess 
**********************************************************************


**********************************************************************
* Another example 

* Essential features of democracy: * Q241-249 (essdem_xxxx) may be incorrect. 
* Rel. leaders interpreting the law as an essential feature to democracy 
* 	is positively correlated with 
* 	believing econ equality is essential to democracy. 

* Maybe that is the way it is, but it seems weird. 
**********************************************************************

**********************************************************************
* Thus:
* It is likely that the labels in the original variables in the data are sometimes incorrect. 
**********************************************************************


**********************************************************************

* /!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!

* There are likely other examples! 
* Be sure and check that the direction makes sense

* /!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!

**********************************************************************




**********************************************************************
* Notes on MY PERSONAL coding decisions 
**********************************************************************
							
* All variables ending with 01 have been recoded such that they run from 0-1. 

* If, in Stata, you run a "codebook, notes" command, pay attention: 
*	the notes attached to the variables contain the question wording.


**********************************************************************
* Sometimes, I made a judgment call about not following their inverted scales.
**********************************************************************

* Example

* Q224P - Q233P asks about how often X happens
* X affects democratic functioning. 

* When that X is positive, such as Q224P: how often R perceives votes are 
*	counted fairly, I followed the inverted scale codebook.

* But when X is bad for democracy, such as Q225P: how often opposition candidates 
*	are prevented from running, I recoded it to be the opposite.

* Therefore, the scales elec_votes and their 0-1 scale "elec_votes01" 
* 	indicates perceived democratic functioning as high 

**********************************************************************

* Illustration 

* recode	Q224P			(	4=5	"5.Very often"		)							///
* 							(	3=4	"4.Fairly often"		)						///
* 							(	2=2	"2.Not often"		)							///
* 							(	1=1	"1.Not at all often"		)					///
* 							(	-1=3	"3.Don't know"		)						///
* 							(	-2=.e	"Not answered"		)						///
* 							(	-4=.a	"NA"		)								///
* 							(	-5=.a	"NA"), generate (	elec_votes	)
* 
* recode	Q225P			(	4=1	"1.Very often"		)							///
* 							(	3=2	"2.Fairly often"		)						///
* 							(	2=4	"4.Not often"		)							///
* 							(	1=5	"5.Not at all often"		)					///
* 							(	-1=3	"3.Don't know"		)						///
* 							(	-2=.e	"Not answered"		)						///
* 							(	-4=.a	"NA"		)								///
* 							(	-5=.a	"NA"), generate (	elec_oppno	)
* * 






**********************************************************************
* Notes on don't know 
**********************************************************************

* At times, I made a judgment about putting "Don't know" as a valid respnse

**********************************************************************
* Sometimes, it made sense to put "dont know" in the middle of the scale
**********************************************************************

* Example 

*  tab Q39P

*     People who don´t work turn lazy (+) |      Freq.     Percent        Cum.
* ----------------------------------------+-----------------------------------
* Other missing; Multiple answers Mail (E |         77        0.09        0.09
*                               No answer |        175        0.21        0.30
*                              Don´t know |        428        0.51        0.80
*                       Disagree strongly |      2,827        3.34        4.14
*                                Disagree |     10,634       12.56       16.71
*              Neither agree nor disagree |     10,977       12.97       29.68
*                                   Agree |     33,365       39.42       69.10
*                          Agree strongly |     26,155       30.90      100.00
* ----------------------------------------+-----------------------------------

* Recoded 
* (	-1 3=3	"3.Neither / don't know"	)				

**********************************************************************							
* Sometimes, it made sense to put it at the bottom (e.g. knowledge questions: Q91-Q93)
**********************************************************************

* For the participation questions, I put "don't know" near the bottom, above "would never do"

* Example 

* tab Q209P

*     Political action: Signing a petition |
*                                      (+) |      Freq.     Percent        Cum.
*  ----------------------------------------+-----------------------------------
* Recoded value:

* 2                             Don´t know |      1,840        2.17        2.89
* 1                         Would never do |     38,197       45.13       48.02
* 3                               Might do |     24,987       29.52       77.54
* 4                              Have done |     19,008       22.46      100.00
**********************************************************************




**********************************************************************
* Other times, I made "don't know" = .d

* 	(	-1=.d	"Don't know"		)						

**********************************************************************

**********************************************************************
* Other mising codes
**********************************************************************

* I took advantage of Stata's .x missing codes 

* .n means that the question is not relevant to them

* Example: not voting because one is not allowed to vote 
*							(	1=.n	"Not allowed to vote"		)				///

* .d for "don't know" if i did not put "don't know" as valid in the scale 
* This way, if you choose to do so, you can recode .d = #
* 							(	-1=.d	"Don't know"		)						///

* .e means they just did not answer:
* 							(	-2=.e	"Not answered"		)						///

* .a means they answered an invalid choice (multiple answers) 
*	OR the question was not asked in this country 

**********************************************************************

* Illustration: Confidence in courts was not asked in Egypt 
* tab Q70P
* 
*   Confidence: Justice System/Courts (+) |      Freq.     Percent        Cum.
* ----------------------------------------+-----------------------------------
* Other missing; Multiple answers Mail (E |         95        0.11        0.11
*                               Not asked |      1,200        1.42        1.53
*                               No answer |        276        0.33        1.86
*                              Don´t know |      1,517        1.79        3.65
*                             None at all |     12,773       15.09       18.74
*                           Not very much |     24,208       28.60       47.34
*                             Quite a lot |     31,021       36.65       83.99
*                            A great deal |     13,548       16.01      100.00
* ----------------------------------------+-----------------------------------
*                                   Total |     84,638      100.00
* 
* tab Q70P, nolabel
* 
* Confidence: |
*     Justice |
* System/Cour |
*      ts (+) |      Freq.     Percent        Cum.
* ------------+-----------------------------------
*          -5 |         95        0.11        0.11
*          -4 |      1,200        1.42        1.53
*          -2 |        276        0.33        1.86
*          -1 |      1,517        1.79        3.65
*           1 |     12,773       15.09       18.74
*           2 |     24,208       28.60       47.34
*           3 |     31,021       36.65       83.99
*           4 |     13,548       16.01      100.00
* ------------+-----------------------------------
*       Total |     84,638      100.00
* * 

* . tab Q70P B_COUNTRY if Q70P == -4
* 
*                       | ISO 3166-1
*                       |  numeric
*                       |  country
*   Confidence: Justice |    code
*     System/Courts (+) |     Egypt |     Total
* ----------------------+-----------+----------
*             Not asked |     1,200 |     1,200 
* ----------------------+-----------+----------
*                 Total |     1,200 |     1,200
* * 








**********************************************************************
* Technical variables and World Values indices  
**********************************************************************


clonevar year=A_YEAR
clonevar country=B_COUNTRY
clonevar country_str=B_COUNTRY_ALPHA
clonevar cow=C_COW_NUM
clonevar cow_str=C_COW_ALPHA
clonevar int_id=D_INTERVIEW
clonevar id=S007_01
clonevar int_date=J_INTDATE
clonevar region_iso=N_REGION_ISO
clonevar region=N_REGION_WVS
clonevar psu=I_PSU
clonevar lang=S_INTLANGUAGE
clonevar int_literacy=E1_LITERACY
clonevar weight_cs=W_WEIGHT
clonevar weight=S018
clonevar popweight=pwght
clonevar post12=Y001
clonevar post4=Y002
clonevar aut5=Y003


**********************************************************************
* Note on my names for their scales 
**********************************************************************
 
* I changed the name of the scale to reflect the opposite of the name of the scale with the word "not" 
* Their notation for the scale being the opposite is I_ 

* Illustration: I_AUTHORITY means "Inverse of values authority"

* clonevar val_notobey01=I_AUTHORITY

* So, I_Authority is inverted authoritarianism
* I called it val_notobey01 for valuing not obedience 
**********************************************************************

clonevar valsec01=sacsecval
clonevar valeman01=resemaval
clonevar val_notobey01=I_AUTHORITY
clonevar val_notnat01=I_NATIONALISM
clonevar val_notrel01=I_DEVOUT
clonevar valdefy01=defiance
clonevar rel_notimp01=I_RELIGIMP
clonevar rel_notbel01=I_RELIGBEL
clonevar rel_notprac01=I_RELIGPRAC
clonevar reldis01=disbelief
clonevar norm1=I_NORM1
clonevar norm2=I_NORM2
clonevar norm3=I_NORM3
clonevar nonconform01=relativism
clonevar not_trustarmy01=I_TRUSTARMY
clonevar not_trustpolice01=I_TRUSTPOLICE
clonevar not_trust_courts01=I_TRUSTCOURTS
clonevar skeptic01=scepticism
clonevar indep01=I_INDEP
clonevar imag01=I_IMAGIN
clonevar notobey01=I_NONOBED
clonevar autonomy01=autonomy

         
clonevar equality01=equality
clonevar choice01=choice
clonevar voice01=voice



* I wanted to create this index myself; the way I did it created a number of valid responses that are coded as missing by WorldValues 


* Equivalent of I_VOICE1 but I_VOICE1 requires both Qs to be nonmissing, so has 1177 more missing than val_voice1_alt03

gen val_voice1_alt03 = .n if (Q154 <0 & Q155 <0 )									// They have to both be missing to be .n 
replace val_voice1_alt03 = 0 if (val_voice1_alt03 ~= .n & ///
								(Q155 == 1 | Q155 == 3 | Q154 == 1 | Q154 == 3 ))	// All set to lowest voice if any are non-voice but has at least one valid response 
replace val_voice1_alt03 = 1 if  (Q155 == 2 | Q155 == 4)							// Set to 1 if voice is second in priority 
replace val_voice1_alt03 = 2 if  (Q154 == 2 | Q154 == 4)							// Set to 2 if voice is first priority 
replace val_voice1_alt03 = 3 if ((Q154 == 2 | Q154 == 4) & (Q155 == 2 | Q155 == 4))	// Set to 3 if voice is both second and first 


gen val_voice1_alt01 = val_voice1_alt03/3

label var val_voice1_alt03 "Voice priority: two out of four"
label var val_voice1_alt01 "Voice priority: two out of four"

note val_voice1_alt03: Values speech and giving people a say (Q154 and Q155). I_VOICE1 requires both Qs to be nonmissing, so has 1177 more missing than val_voice1_alt03
note val_voice1_alt01: Values speech and giving people a say (Q154 and Q155). I_VOICE1 requires both Qs to be nonmissing, so has 1177 more missing than val_voice1_alt01
note I_VOICE1: Missing if either Q154 or Q155 is missing. WorldValues data labels are in opposite direction 




gen val_voice2_alt01 = .n if (Q152 < 0 & Q153 < 0 )									// They have to both be missing to be .n 
replace val_voice2_alt01 = 0 if (val_voice2_alt ~=.n & (Q152 ~=3 | Q153 ~=3 ))  	// Not 3 but also not missing on at least one question  
replace val_voice2_alt01 = .5 if ( Q153 ==3 )   									// Voice on second priority   
replace val_voice2_alt01 = 1 if ( Q152 ==3 )   										// Voice on first priority  

label var val_voice2_alt01 "Voice priority: one out of four"
note val_voice2_alt01: Values speech and giving people a say (Q154 and Q155). I_VOICE2 requires both Qs to be nonmissing, so has 1456 more missing than val_voice1_alt03							

note I_VOICE2: Missing if either Q152 or Q153 is missing WorldValues calls it inverse voice. Labels of I_VOICE2 are correct direction but in Spanish -bajo is low



label define voice01 0 "Voice not a priority" 1 "Voice has priority"
label values val_voice1_alt01 val_voice2_alt01 voice01

* These should be the same except 1177 additional 0s that are missing on I_VOICE1
tab val_voice1_alt01 I_VOICE1, miss 

* These should be the same except 1456 additional 0s that are missing on I_VOICE2
tab val_voice2_alt01 I_VOICE2, miss 

* Pearson r is .26
corr val_voice1_alt01 val_voice2_alt01

egen voice_alt01 = rowmean (val_voice1_alt01 val_voice2_alt01 )

* voice_alt01 voice01 I_VOI2_00 are correlated at 1.0 


* My own emancipative scale with WorldValues equality01 and WorldValues choice01 but my voice_alt01 , which is correlated at 1.0. 
egen emancip01 = rowmean (equality01 choice01 voice_alt01 autonomy01)











**********************************************************************
* Test to make sure direction of these scales are internally consistent
**********************************************************************

* corr valsec01 valdefy01 val_notobey01 val_notnat01 val_notrel01
* (obs=79,464)
* 
*              | valsec01 valde~01 val_~y01 val_~t01 val_~l01
* -------------+---------------------------------------------
*     valsec01 |   1.0000
*    valdefy01 |   0.5471   1.0000
* val_notob~01 |   0.3476   0.7785   1.0000
* val_notnat01 |   0.4125   0.6101   0.1641   1.0000
* val_notrel01 |   0.3798   0.6173   0.1828   0.2236   1.0000
* 
* . corr valsec01 reldis01 rel_notimp01 rel_notbelnot01 rel_notprac01 
* (obs=81,583)
* 
*              | valsec01 reldis01 rel_~p01 rel_~t01 rel_~c01
* -------------+---------------------------------------------
*     valsec01 |   1.0000
*     reldis01 |   0.6248   1.0000
* rel_notimp01 |   0.5535   0.8232   1.0000
* rel_notbe~01 |   0.5322   0.8547   0.5490   1.0000
* rel_notpr~01 |   0.4564   0.7875   0.5403   0.4660   1.0000
* 
* Autonomy could be valuing independence, imagination, and not valuing obedience.
* These are not that highly correlated, so the index should be used with caution to make inferences about individuals. 
* Without making any value judgments about their argument, the following citation explains their belief that variables that correlate poorly can be used to create scales that can be used to make inferences at country levels. 
* Welzel, Christian, and Ronald F. Inglehart. "Misconceptions of measurement equivalence: Time for a paradigm shift." Comparative Political Studies 49, no. 8 (2016): 1068-1094.
* 
* At the individual levels, for example, when I make this argument to students, I might say that eating a ton of sweets might show a low correlation with eating too much salty fats like chips, but both, taken together can indicate the causes of obesity. 
* Or let's say psychiatric clinicians want to estimate the likelihood of psychosis. Neurological problems such as epilepsy are likely to be uncorrelated with schizophrenia, both of which may exhibit a low correlation with encephalitis. But taken together, a scale of these items can be used to indicate a likelihood of psychosis. 
* The autonomy scale is analogous to this and is used to infer the multiplicity of ways we as humans value autonomy.
* . corr  autonomy01 indep01 imag01 notobey01
* (obs=83,189)
* 
*              | auton~01  indep01   imag01 notob~01
* -------------+------------------------------------
*   autonomy01 |   1.0000
*      indep01 |   0.7085   1.0000
*       imag01 |   0.5617   0.1004   1.0000
*    notobey01 |   0.6868   0.2186   0.1048   1.0000
* 
* Rule of law norms – called "relativism" by Welzel and World Values documentation.
* 
* norm1, norm2, and norm 3 were recodes of the following variables Q178 Q180 Q181 respectively, where R was coded as rejecting norms if they said any of the following were anything but "Never justified" 
* avoid a fare on public transport, Q178
* cheat on taxes if provided the chance, Q180
* and accept a bribe in the course of professional duties Q181
* I used those variables as measures of the rule of law, so they are coded as accepting legal norms. Therefore, they should be negatively correlated with my scales. 
* 
* . corr nonconform01 norm1  norm2  norm3  law_fare01  law_taxes01  law_bribe01
* (obs=80,705)
* 
*              | nonco~01    norm1    norm2    norm3 law_f~01 law_t~01 law_b~01
* -------------+---------------------------------------------------------------
* nonconform01 |   1.0000
*        norm1 |   0.8206   1.0000
*        norm2 |   0.8676   0.5539   1.0000
*        norm3 |   0.8408   0.5026   0.6425   1.0000
*   law_fare01 |  -0.6037  -0.7386  -0.4035  -0.3707   1.0000
*  law_taxes01 |  -0.6652  -0.4241  -0.7466  -0.5139   0.4861   1.0000
*  law_bribe01 |  -0.6482  -0.3917  -0.5080  -0.7530   0.4317   0.6175   1.0000
* 


**********************************************************************

	


recode	G_TOWNSIZE			(	1=1	"1.Under 2,000"			)						///
							(	2=2	"2.2,000-5,000"			)						///
							(	3=3	"3.5,000-10,000"		)						///
							(	4=4	"4.10,000-20,000"		)						///
							(	5=5	"5.20,000-50,000"		)						///
							(	6=6	"6.50,000-100,000"		)						///
							(	7=7	"7.100,000-500,000"		)						///
							(	8=8	"8.500,000 and more"	)						///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"				)						///
							(	-5=.a	"NA"), generate (	townsize8	)

recode	G_TOWNSIZE2			(	1=1	"1.Under 5,000"		)							///
							(	2=2	"2.5000-20000"		)							///
							(	3=3	"3.20000-100000"		)						///
							(	4=4	"4.100000-500000"		)						///
							(	5=5	"5.500000 and more"		)						///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	townsize5	)

recode	H_SETTLEMENT			(	1=5	"5.Capital city"		)					///
							(	2=4	"4.Regional center"		)						///
							(	3=3	"3.District center"		)						///
							(	4=2	"2.Not district center"		)					///
							(	5=1	"1.Village"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	towntype	)

recode	H_URBRURAL			(	1=1	"1.Urban"		)								///
							(	2=0	"0.Rural"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	urban	)	

recode	E_RESPINT			(	1=3	"3.Very interested"		)						///
							(	2=2	"2.Somewhat interested"		)					///
							(	3=1	"1.Not interested"		)						///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	int_rint	)

recode	F_INTPRIVACY		(	1=1	"1.No other people around"		)				///
							(	2=0	"0.There were other people around"		)		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	int_priv	)


							
**********************************************************************
* Variables in questionnaire   
**********************************************************************


**********************************************************************
* Notes: 

* Here is an exammple of how some of the variables change from the 
* 	original questionnaire with the notations on 
* See below for notes from codebook from "WVS-7 Master Questionnaire 2017-2020 English.pdf"

**********************************************************************
							

* Illustration 

* Here is a tab of Q1P
* tab Q1P
* 
*           Important in life: Family (+) |      Freq.     Percent        Cum.
* ----------------------------------------+-----------------------------------
* Other missing; Multiple answers Mail (E |         49        0.06        0.06
*                               No answer |         47        0.06        0.11
*                              Don´t know |         17        0.02        0.13
*                    Not at all important |        166        0.20        0.33
*                      Not very important |        715        0.84        1.17
*                        Rather important |      7,244        8.56        9.73
*                          Very important |     76,400       90.27      100.00
* ----------------------------------------+-----------------------------------
*                                   Total |     84,638      100.00
* tab Q1P, nolabel
* 
*   Important |
*    in life: |
*  Family (+) |      Freq.     Percent        Cum.
* ------------+-----------------------------------
*          -5 |         49        0.06        0.06
*          -2 |         47        0.06        0.11
*          -1 |         17        0.02        0.13
*           1 |        166        0.20        0.33
*           2 |        715        0.84        1.17
*           3 |      7,244        8.56        9.73
*           4 |     76,400       90.27      100.00
* ------------+-----------------------------------
*       Total |     84,638      100.00
* * 


* Notes from "F00010768-WVS_Explanatory_note_on_scales_recoding" on Q1P-Q6P

*Variable 						Original scale 			Recoded "positive" scale 
* Q1-6 	
* Importance of family, etc 	1=Very important 		4=Very important
* 								2=Rather important 		3=Rather important 
* 								3=Not very important 	2=Not very important 
* 								4=Not important at all 	1=Not important at all


* tab Q1P
* 
*           Important in life: Family (+) |      Freq.     Percent        Cum.
* ----------------------------------------+-----------------------------------
* Other missing; Multiple answers Mail (E |         49        0.06        0.06
*                               No answer |         47        0.06        0.11
*                              Don´t know |         17        0.02        0.13
*                    Not at all important |        166        0.20        0.33
*                      Not very important |        715        0.84        1.17
*                        Rather important |      7,244        8.56        9.73
*                          Very important |     76,400       90.27      100.00
* ----------------------------------------+-----------------------------------
*                                   Total |     84,638      100.00* 
* * 
* * 
* 

						
							
recode	Q1P					(	4=4	"4.Very important"		)						///
							(	3=3	"3.Rather important"		)					///
							(	2=2	"2.Not Very important"		)					///
							(	1=1	"1.Not at all important"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imp_family	)

recode	Q2P					(	4=4	"4.Very important"		)						///
							(	3=3	"3.Rather important"		)					///
							(	2=2	"2.Not Very important"		)					///
							(	1=1	"1.Not at all important"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imp_friends 	)

recode	Q3P					(	4=4	"4.Very important"		)						///
							(	3=3	"3.Rather important"		)					///
							(	2=2	"2.Not very important"		)					///
							(	1=1	"1.Not at all important"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imp_leisure 	)

recode	Q4P					(	4=4	"4.Very important"		)						///
							(	3=3	"3.Rather important"		)					///
							(	2=2	"2.Not very important"		)					///
							(	1=1	"1.Not at all important"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imp_politics 	)

recode	Q5P					(	4=4	"4.Very important"		)						///
							(	3=3	"3.Rather important"		)					///
							(	2=2	"2.Not very important"		)					///
							(	1=1	"1.Not at all important"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imp_work	)

recode	Q6P					(	4=4	"4.Very important"		)						///
							(	3=3	"3.Rather important"		)					///
							(	2=2	"2.Not very important"		)					///
							(	1=1	"1.Not at all important"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imp_rel	)

recode	Q7P					(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_manners	)

recode	Q8P					(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_indep	)

recode	Q9P					(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_work	)

recode	Q10P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_resp	)

recode	Q11P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_imag	)

recode	Q12P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_tol	)

recode	Q13P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_thrift	)

recode	Q14P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_determ	)

recode	Q15P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_rel	)

recode	Q16P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_unself	)

recode	Q17P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Important"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_obey	)

recode	Q18P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_addicts	)

recode	Q19P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_race	)

recode	Q20P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_aids	)

recode	Q21P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_imm	)

recode	Q22P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_gay	)

recode	Q23P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_reldif	)

recode	Q24P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_drink	)

recode	Q25P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_notmar	)

recode	Q26P				(	0=0	"0.Not mentioned"		)						///
							(	1=1	"1.Mentioned"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_langdif	)

recode	Q27P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	par_proud	)
														
recode	Q28P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notfem_kids	)							
							
recode	Q29P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notfem_pol	)							
							
recode	Q30P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notfem_educ	)							
	                       						
recode	Q31P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notfem_execs	)							
							
recode	Q32P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notfem_wifeall	)							
							
recode	Q33P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notfem_jobs	)							
							
recode	Q34P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notimm_jobs	)							
							
recode	Q35P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notfem_inc	)							
							
recode	Q36P				(	4=1	"1.Strongly agree"		)						///
							(	3=2	"2.Agree"		)								///
							(	2=4	"4.Disagree"		)							///
							(	1=5	"5.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	gay_kids	)
							
recode	Q37P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	duty_kids	)	
							
recode	Q38P				(	4=5	"5.Strongly agree"		)						///
							(	3=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	duty_par	)						

recode	Q39P				(	5=5	"5.Strongly agree"		)						///
							(	4=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1 3=3	"3.Neither / don't know"	)				///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	notwork_lazy	)

recode	Q40P				(	5=5	"5.Strongly agree"		)						///
							(	4=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1 3=3	"3.Neither / don't know"	)				///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	work_duty	)

recode	Q41P				(	5=5	"5.Strongly agree"		)						///
							(	4=4	"4.Agree"		)								///
							(	2=2	"2.Disagree"		)							///
							(	1=1	"1.Strongly disagree"		)					///
							(	-1 3=3	"3.Neither / don't know"	)				///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	workfirst	)

recode	Q42					(	1=1	"1.Radical change"		)						///
							(	2=2	"2.Reform"				)					///
							(	3=3	"3.Present society"		)						///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	cons_ref_rev	)

recode	Q43P				(	3=1	"1.Good thing"		)							///
							(	2 -1=2	"2.Don´t mind / don't know"		)			///
							(	1=3	"3.Bad thing"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	fut_work_notless	)

recode	Q44P				(	3=3	"3.Good thing"		)								///
							(	2 -1=2	"2.Don´t mind"		)						///
							(	1=1	"1.Bad thing"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	fut_tech	)

recode	Q45P				(	3=3	"3.Good thing"		)							///
							(	2 -1=2	"2.Don´t mind"		)						///
							(	1=1	"1.Bad thing"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	fut_obey	)

recode	Q46P				(	4=4 	"4.Very happy"		)						///
							(	3=3	"3.Quite happy"		)							///
							(	2=2	"2.Not very happy"		)						///
							(	1=1	"1.Not at all happy"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	happy	)

recode	Q47P				(	5=5	"5.Very good"		)							///
							(	4=4	"4.Good"		)								///
							(	3=3	"3.Fair"		)								///
							(	2=2	"2.Poor"		)								///
							(	1=1	"1.Very poor"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	health	)

recode	Q48					(	10=1	"1.A great deal of personal control"	)	///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Completely external locus of control")	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	ext_loc_control	)

recode	Q49					(	10=10	"10.Completely satisfied"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Completely dissatisfied"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	satlife	)

recode	Q50					(	10=10	"10.Completely satisfied"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Completely dissatisfied"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	satfin	)

recode	Q51P				(	4=4	"4.Often"		)								///
							(	3=3	"3.Sometimes"		)							///
							(	2=2	"2.Rarely"		)								///
							(	1=1	"1.Never"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	econbad_food	)

recode	Q52P				(	4=4	"4.Often"		)								///
							(	3=3	"3.Sometimes"		)							///
							(	2=2	"2.Rarely"		)								///
							(	1=1	"1.Never"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	econbad_crime	)

recode	Q53P				(	4=4	"4.Often"		)								///
							(	3=3	"3.Sometimes"		)							///
							(	2=2	"2.Rarely"		)								///
							(	1=1	"1.Never"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	econbad_med	)

recode	Q54P				(	4=4	"4.Often"		)								///
							(	3=3	"3.Sometimes"		)							///
							(	2=2	"2.Rarely"		)								///
							(	1=1	"1.Never"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	econbad_cash	)

recode	Q55P				(	4=4	"4.Often"		)								///
							(	3=3	"3.Sometimes"		)							///
							(	2=2	"2.Rarely"		)								///
							(	1=1	"1.Never"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	econbad_home	)

recode	Q56P				(	3=3	"3.Better off"		)							///
							(	2=1	"2.Worse off"		)							///
							(	1=2	"1.Same"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	econ_parents	)

recode	Q57P				(	2=2	"2.Most people can be trusted"		)			///
							(	2=1	"1.Need to be very careful"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	trust	)

recode	Q58P				(	4=4	"4.Trust completely"		)					///
							(	3=3	"3.Trust somewhat"		)						///
							(	2=2	"2.Do not trust very much"		)				///
							(	1=1	"1.Do not trust at all"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	trust_fam	)

recode	Q59P				(	4=4	"4.Trust completely"		)					///
							(	3=3	"3.Trust somewhat"		)						///
							(	2=2	"2.Do not trust very much"		)				///
							(	1=1	"1.Do not trust at all"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	trust_nei	)

recode	Q60P				(	4=4	"4.Trust completely"		)					///
							(	3=3	"3.Trust somewhat"		)						///
							(	2=2	"2.Do not trust very much"		)				///
							(	1=1	"1.Do not trust at all"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	trust_know	)

recode	Q61P				(	4=4	"4.Trust completely"		)					///
							(	3=3	"3.Trust somewhat"		)						///
							(	2=2	"2.Do not trust very much"		)				///
							(	1=1	"1.Do not trust at all"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	trust_meet	)

recode	Q62P				(	4=4	"4.Trust completely"		)					///
							(	3=3	"3.Trust somewhat"		)						///
							(	2=2	"2.Do not trust very much"		)				///
							(	1=1	"1.Do not trust at all"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	trust_rel	)

recode	Q63P				(	4=4	"4.Trust completely"		)					///
							(	3=3	"3.Trust somewhat"		)						///
							(	2=2	"2.Do not trust very much"		)				///
							(	1=1	"1.Do not trust at all"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	trust_noncit	)

recode	Q64P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_church	)

recode	Q65P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_army	)

recode	Q66P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_press	)

recode	Q67P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_tv	)

recode	Q68P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_unions	)

recode	Q69P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_police	)

recode	Q70P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_courts	)

recode	Q71P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_gov	)

recode	Q72P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_parties	)

recode	Q73P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_parl	)

recode	Q74P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_civil	)

recode	Q75P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_univ	)

recode	Q76P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_elec	)

recode	Q77P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_bus	)

recode	Q78P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_banks	)

recode	Q79P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_env	)

recode	Q80P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_womens	)

recode	Q81P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_charit	)

recode	Q82P				(	4=4	"4.A great deal"		)						///
							(	3=3	"3.Quite a lot"		)							///
							(	3=2	"2.Not very much"		)						///
							(	1=1	"1.None at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	conf_reggov	)

recode	Q91					(	1 2 -1=0 "0.Wrong answer: France or China"		)	///
							(	3=1	"1.Knows India does not have a permanent seat")	///
							(	-2=0	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	know_UN 	)

recode	Q92					(	2 3 -1=0 "0.Wrong answer: London or Geneva")		///
							(	1=1	"1.Knows IMF is in DC"		)					///
							(	-2=0	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	know_IMF 	)

recode	Q93					(	1 3 -1=0 "0.Wrong answer: France or China"		)	///
							(	2=1	"1.Knows Am Intl focuses on human rights")		///
							(	-2=0	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	know_Amnesty 	)

recode	Q94					(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_church	)

recode	Q95					(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_sport	)

recode	Q96					(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_art	)

recode	Q97					(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_union	)

recode	Q98					(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_party	)

recode	Q99					(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_env	)

recode	Q100				(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_prof	)

recode	Q101				(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_charit	)

recode	Q102				(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_consumer	)

recode	Q103				(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_selfhelp	)

recode	Q104				(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_womens	)

recode	Q105				(	0 -1=0	"Don't belong"		)						///
							(	1=1	"Inactive member"		)						///
							(	2=2	"Active member"		)							///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mem_other	)

recode	Q106				(	10=10	"10.Larger income differences"		)		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Incomes should be more equal"		)		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_incdif 	)

recode	Q107				(	10=1 "1.Increase government ownership of business")	///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10 "10.Increase private ownership of business")	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_privown	)

recode	Q108				(	1=1	"1.Government should be more responsible")		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	10=10	"10.People should be responsible")			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_ind	)

recode	Q109				(	10=1	"1.Competition harmful"		)				///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Competition is good"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_compet	)

recode	Q110				(	10=1	"1.Success more about luck"		)			///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Success from hard work"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_hardwork	)

recode	Q111				(	1=2	"2.Protect environment"		)					///
							(	2=0	"0.Economic growth"		)						///
							(	3=1	".5 Other / don't know"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_env	)

recode	Q112				(	10=10	"10.Abundant corruption"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.No corruption"		)						///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	corrupt	)

recode	Q113				(	1=1	"1.None of them"		)						///
							(	2=2	"2.Few of them"		)							///
							(	3=4	"4.Most of them"		)						///
							(	4=5	"5.All of them"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	corr_state	)

recode	Q114				(	1=1	"1.None of them"		)						///
							(	2=2	"2.Few of them"		)							///
							(	3=4	"4.Most of them"		)						///
							(	4=5	"5.All of them"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	corr_bus	)

recode	Q115				(	1=1	"1.None of them"		)						///
							(	2=2	"2.Few of them"		)							///
							(	3=4	"4.Most of them"		)						///
							(	4=5	"5.All of them"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	corr_local	)

recode	Q116				(	1=1	"1.None of them"		)						///
							(	2=2	"2.Few of them"		)							///
							(	3=4	"4.Most of them"		)						///
							(	4=5	"5.All of them"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	corr_civil	)

recode	Q117				(	1=1	"1.None of them"		)						///
							(	2=2	"2.Few of them"		)							///
							(	3=4	"4.Most of them"		)						///
							(	4=5	"5.All of them"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	corr_journ	)

recode	Q118				(	1=1	"1.Never"		)								///
							(	2=2	"2.Rarely"		)								///
							(	3=4	"4.Frequently"		)							///
							(	4=5	"5.Always"		)								///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	bribe_freq	)

recode	Q120				(	10=1	"1.Very high risk"		)					///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.No risk at all"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	bribe_account	)

recode	Q121				(	1=1	"1.Rather bad"		)							///
							(	2=2	"2.Quite bad"		)							///
							(	3=3	"3.Neither good, nor bad"		)				///
							(	4=4	"4.Quite good"		)							///
							(	5=5	"5.Very good"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_good	)

recode	Q122				(	0=0	"0.Immigrants do not fill useful jobs"		)	///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2.Immigrants fill useful jobs"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_useful_jobs	)

recode	Q123				(	0=0	"0.Immigrants do not strengthen culture"	)	///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2.Immigrants strengthen culture"		)		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_cult_div	)

recode	Q124				(	0=0	"0.Immigration increases crime"		)			///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2.Immigration does not increase crime"		)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_crime	)

recode	Q125				(	0=0	"0.Immigration not for asylum"		)			///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2.Immigrants for asylum"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_asylum	)

recode	Q126				(	0=0	"0.Immigration increases terrorism"		)		///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2.Immigration does not increase terrorism"	)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_terror	)

recode	Q127				(	0=0	"0.Immigration does not give people new lives")	///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2. Immigration gives people new lives"		)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_poor	)

recode	Q128				(	0=0	"0.Immigration increases unemployment"		)	///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2. Immigration does not increase unemployment") ///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_unemp	)

recode	Q129				(	0=0	"0.Immigration increases social conflict")		///
							(	1=1	"1.Hard to say"		)							///
							(	2=2	"2.Immigration does not increase conflict"	)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	imm_conflict	)

recode	Q130P				(	4=5	"5.Let anyone come"		)						///
							(	3=4	"4.Let people in if jobs available"		)		///
							(	2=2	"2.Strict limits on the number"		)			///
							(	1=1	"1.Prohibit immigration"		)				///
							(	-1=3	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mig_sup	)

recode	Q131P				(	4=4	"4.Very Secure"		)							///
							(	3=3	"3.Quite secure"		)						///
							(	2=2	"2.Not very secure"		)						///
							(	1=1	"1.Not at all secure"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_sec	)

recode	Q132P				(	4=5	"5.Very frequently"		)						///
							(	3=4	"4.Quite frequently"		)					///
							(	2=2	"2.Not frequently"		)						///
							(	1=1	"1.Not at all frequently"		)				///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_rob	)

recode	Q133P				(	4=5	"5.Very frequently"		)						///
							(	3=4	"4.Quite frequently"		)					///
							(	2=2	"2.Not frequently"		)						///
							(	1=1	"1.Not at all frequently"		)				///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_alc	)

recode	Q134P				(	4=5	"5.Very frequently"		)						///
							(	3=4	"4.Quite frequently"		)					///
							(	2=2	"2.Not frequently"		)						///
							(	1=1	"1.Not at all frequently"		)				///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_police	)

recode	Q135P				(	4=5	"5.Very frequently"		)						///
							(	3=4	"4.Quite frequently"		)					///
							(	2=2	"2.Not frequently"		)						///
							(	1=1	"1.Not at all frequently"		)				///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_racist	)

recode	Q136P				(	4=5	"5.Very frequently"		)						///
							(	3=4	"4.Quite frequently"		)					///
							(	2=2	"2.Not frequently"		)						///
							(	1=1	"1.Not at all frequently"		)				///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_drugs	)

recode	Q137P				(	4=5	"5.Very frequently"		)						///
							(	3=4	"4.Quite frequently"		)						///
							(	2=2	"2.Not frequently"		)						///
							(	1=1	"1.Not at all frequently"		)						///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_viol	)

recode	Q138P				(	4=5	"5.Very frequently"		)						///
							(	3=4	"4.Quite frequently"		)					///
							(	2=2	"2.Not frequently"		)						///
							(	1=1	"1.Not at all frequently"		)				///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_harass	)

recode	Q139P				(	0=0	"0.No"		)	(	1=1	"1.Yes"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_cash	)

recode	Q140P				(	0=0	"0.No"		)	(	1=1	"1.Yes"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_out	)

recode	Q141P				(	0=0	"0.No"		)	(	1=1	"1.Yes"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nei_weap	)

recode	Q142P				(	4=5	"5.Very much"		)							///
							(	3=4	"4.A great deal"		)						///
							(	2=2	"2.Not much"		)							///
							(	1=1	"1.Not at all"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	worry_job	)

recode	Q143P				(	4=5	"5.Very much"		)							///
							(	3=4	"4.A great deal"		)						///
							(	2=2	"2.Not much"		)							///
							(	1=1	"1.Not at all"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	worry_kidseduc	)

recode	Q144P				(	0=0	"0.No"		)	(	1=1	"1.Yes"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	victim_self	)

recode	Q145P				(	0=0	"0.No"		)	(	1=1	"1.Yes"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	victim_fam	)

recode	Q146P				(	4=5	"5.Very much"		)							///
							(	3=4	"4.A great deal"		)						///
							(	2=2	"2.Not much"		)							///
							(	1=1	"1.Not at all"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	worry_war	)

recode	Q147P				(	4=5	"5.Very much"		)							///
							(	3=4	"4.A great deal"		)						///
							(	2=2	"2.Not much"		)							///
							(	1=1	"1.Not at all"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	worry_terror	)

recode	Q148P				(	4=5	"5.Very much"		)							///
							(	3=4	"4.A great deal"		)						///
							(	2=2	"2.Not much"		)							///
							(	1=1	"1.Not at all"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	worry_civwar	)

recode	Q149				(	2=0	"0.Equality"		)							///
							(	1=1	"1.Freedom"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_free_equal	)

recode	Q150				(	2=0	"0.Security"		)							///
							(	1=1	"1.Freedom"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_free_sec	)

recode	Q151P 				(	0=0	"0.No"		)	(	1=1	"1.Yes"	)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	fight_country	)

							





recode	Q158				(	10=10	"10.Science improves lives"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Science does not improve lives"		)		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	valsci_life	)

recode	Q159				(	10=10	"10.Science provides opportunities"		)	///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Science does not provide opportunities"		) ///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	valsci_opp	)

recode	Q160				(	10=1	"1.Science, not enough faith"		)		///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Not depend too much on science"		)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	valsci_faith	)

recode	Q161				(	10=1	"1.Science ruins morals"		)			///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Science doesn't ruin morals"		)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	valsci_morals	)

recode	Q162				(	10=1	"1.Not important to know"		)			///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10 "10.Science important to know for daily life")	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	valsci_know	)

recode	Q163				(	10=10	"10.Science makes us better off"		)	///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Science makes us worse off"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	valsci_better	)

recode	Q164				(	10=10	"10.God very important"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.God not important"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_godimp	)

recode	Q165				(	0=0	"0.No"		)	(	1=2	"2.Yes"		)			///
							(	-1=1	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_god	)

recode	Q166				(	0=0	"0.No"		)	(	1=2	"2.Yes"		)			///
							(	-1=1	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_life	)

recode	Q167				(	0=0	"0.No"		)	(	1=2	"2.Yes"		)			///
							(	-1=1	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_hell	)

recode	Q168				(	0=0	"0.No"		)	(	1=2	"2.Yes"		)			///
							(	-1=1	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_heaven	)

recode	Q169				(	1=1	"1.Strongly disagree"		)					///
							(	2=2	"2.Disagree"		)							///
							(	3=4	"4.Agree"		)								///
							(	4=5	"5.Strongly agree"		)						///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_right	)

recode	Q170				(	1=1	"1.Strongly disagree"		)					///
							(	2=2	"2.Disagree"		)							///
							(	3=4	"4.Agree"		)								///
							(	4=5	"5.Strongly agree"		)						///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_mine	)

recode	Q171				(	7=7	"7.More than once a week"		)				///
							(	6=6	"6.Once a week"		)							///
							(	5=5	"5.Once a month"		)						///
							(	4=4	"4.Only on holy days"		)					///
							(	3=3	"3.Once a year"		)							///
							(	2=2 	"2.Less often"		)						///
							(	1=1	"1.Never, practically never"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_attend	)

recode	Q172				(	8=8	"8.Several times a day"		)					///
							(	7=7	"7.Once a day"		)						///
							(	6=6	"6.Several times each week"		)				///
							(	5=5	"5.Only in services"		)					///
							(	4=4	"4.Only on holy days"		)					///
							(	3=3	"3.Once a year"		)						///
							(	2=2 	"2.Less often"		)						///
							(	1=1	"1.Never, practically never"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_pray	)

recode	Q173				(	3=3	"3.A religious person"		)					///
							(	2=2	"Not a religious person"		)				///
							(	1=1	"An atheist"		)						///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_pers	)

recode	Q174				(	1=1	"1.Follow norms, ceremony"		)				///
							(	2=3	"3.Do good to others"		)					///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_good	)

recode	Q175				(	1=1	"1.Make sense of life after death"		)		///
							(	2=3	"3.Make sense of life in this world"		)	///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	rel_thislife	)

recode	Q176				(	10=10	"10.Completely agree"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Completely disagree"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"		)	(	-4=.a	"NA"		)	///
							(	-5=.a	"NA"), generate (	morals_hard	)

recode	Q177				(	10=1	"1.Always justifiable"		)				///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Never justifiable"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	law_govben	)

recode	Q178				(	10=1	"1.Always justifiable"		)				///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Never justifiable"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	law_fare	)

recode	Q179				(	10=1	"1.Always justifiable"		)				///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Never justifiable"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	law_steal	)

recode	Q180				(	10=1	"1.Always justifiable"		)				///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Never justifiable"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	law_taxes	)

recode	Q181				(	10=1	"1.Always justifiable"		)				///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Never justifiable"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	law_bribe	)

recode	Q182				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_gay	)

recode	Q183				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_prost	)

recode	Q184				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_abor	)

recode	Q185				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_div	)

recode	Q186				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_sex	)

recode	Q187				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_suic	)

recode	Q188				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_letdie	)

recode	Q189				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	viol_beatwife	)

recode	Q190				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	viol_childs	)

recode	Q191				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	viol_other	)

recode	Q192				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	viol_terror	)

recode	Q193				(	10=1	"1.Always justifiable"		)				///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Never justifiable"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	morals_casual	)

recode	Q194				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	viol_pol	)

recode	Q195				(	10=10	"10.Always justifiable"		)				///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Never justifiable"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	viol_death_pen	)

recode	Q196P				(	1=1	"1.Government definitely should surveil")		///
							(	2=2	"2.Probably should"		)						///
							(	3=4	"4.Probably should not"		)					///
							(	4=5	"5.Government definitely should not surveil")	///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	surv_video	)

recode	Q197P				(	1=1	"1.Government definitely should surveil")		///
							(	2=2	"2.Probably should"		)						///
							(	3=4	"4.Probably should not"		)					///
							(	4=5	"5.Government definitely should not surveil")	///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	surv_email	)

recode	Q198P				(	1=1	"1.Government definitely should surveil")		///
							(	2=2	"2.Probably should"		)						///
							(	3=4	"4.Probably should not"		)					///
							(	4=5	"5.Government definitely should not surveil")	///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	surv_allinfo	)

recode	Q199P				(	4=4	"4.Very interested"		)						///
							(	3=3	"3.Somewhat interested"		)					///
							(	2=2	"2.Not very interested"		)					///
							(	1=1	"1.1.Not at all interested"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polint	)

recode	Q200P				(	3=3	"3.Frequently"		)							///
							(	2=2	"2.Occasionally"		)						///
							(	3 -1=1	"1.Never"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	poltalk	)

recode	Q201P				(	5=5	"5.Daily"	)									///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"	)									///
							(	3=2	"2.Less than monthly"	)						///
							(	1=1	"1.Never"	)									///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_paper	)

recode	Q202P				(	5=5	"5.Daily"		)								///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"		)								///
							(	3=2	"2.Less than monthly"		)					///
							(	1=1	"1.Never"		)								///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_tv	)

recode	Q203P				(	5=5	"5.Daily"		)								///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"		)								///
							(	3=2	"2.Less than monthly"		)					///
							(	1=1	"1.Never"		)								///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_radio	)

recode	Q204P				(	5=5	"5.Daily"		)								///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"		)								///
							(	3=2	"2.Less than monthly"		)					///
							(	1=1	"1.Never"		)								///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_mobile	)

recode	Q205P				(	5=5	"5.Daily"		)								///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"		)								///
							(	3=2	"2.Less than monthly"		)					///
							(	1=1	"1.Never"		)								///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_email	)

recode	Q206P				(	5=5	"5.Daily"		)								///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"		)								///
							(	3=2	"2.Less than monthly"		)					///
							(	1=1	"1.Never"		)								///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_web	)

recode	Q207P				(	5=5	"5.Daily"		)								///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"		)								///
							(	3=2	"2.Less than monthly"		)					///
							(	1=1	"1.Never"		)								///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_social	)

recode	Q208P				(	5=5	"5.Daily"		)								///
							(	4=4 "4.Weekly"		)								///
							(	3=3	"3.Monthly"		)								///
							(	3=2	"2.Less than monthly"		)					///
							(	1=1	"1.Never"		)								///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	news_friends	)

recode	Q209P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_pet	)

recode	Q210P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_boy	)

recode	Q211P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_prot	)

recode	Q212P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_strikes	)

recode	Q213P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_donate	)

recode	Q214P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_contact	)

recode	Q215P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_othact	)

recode	Q216P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_othvote	)

recode	Q217P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_socmed_search	)

recode	Q218P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_socmed_sign	)

recode	Q219P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_socmed_othact	)

recode	Q220P				(	3=4	"4.Have done"		)							///
							(	2=3	"3.Might do"		)							///
							(	3=1	"1.Would never do"		)						///
							(	-1=2	"2.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polpart_socmed_organize	)

recode	Q221P				(	4=3	"3.Always"		)								///
							(	3=2	"2.Usually"		)								///
							(	2=1	"1.Never"		)								///
							(	1=.n	"Not allowed to vote"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	vote_local	)

recode	Q222P				(	4=3	"3.Always"		)								///
							(	3=2	"2.Usually"		)								///
							(	2=1	"1.Never"		)								///
							(	1=.n	"Not allowed to vote"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	vote_nat	)

recode	Q224P				(	4=5	"5.Very often"		)							///
							(	3=4	"4.Fairly often"		)						///
							(	2=2	"2.Not often"		)							///
							(	1=1	"1.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_votes	)

recode	Q225P				(	4=1	"1.Very often"		)							///
							(	3=2	"2.Fairly often"		)						///
							(	2=4	"4.Not often"		)							///
							(	1=5	"5.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_oppno	)

recode	Q226P				(	4=1	"1.Very often"		)							///
							(	3=2	"2.Fairly often"		)						///
							(	2=4	"4.Not often"		)							///
							(	1=5	"5.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_press_incum	)

recode	Q227P				(	4=1	"1.Very often"		)							///
							(	3=2	"2.Fairly often"		)						///
							(	2=4	"4.Not often"		)							///
							(	1=5	"5.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_bribe	)

recode	Q228P				(	4=5	"5.Very often"		)							///
							(	3=4	"4.Fairly often"		)						///
							(	2=2	"2.Not often"		)							///
							(	1=1	"1.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_pressfair	)

recode	Q229P				(	4=5	"5.Very often"		)							///
							(	3=4	"4.Fairly often"		)						///
							(	2=2	"2.Not often"		)							///
							(	1=1	"1.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_off	)

recode	Q230P				(	4=1	"1.Very often"		)							///
							(	3=2	"2.Fairly often"		)						///
							(	2=4	"4.Not often"		)							///
							(	1=5	"5.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_rich	)

recode	Q231P				(	4=1	"1.Very often"		)							///
							(	3=2	"2.Fairly often"		)						///
							(	2=4	"4.Not often"		)							///
							(	1=5	"5.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_viol	)

recode	Q232P				(	4=5	"5.Very often"		)							///
							(	3=4	"4.Fairly often"		)						///
							(	2=2	"2.Not often"		)							///
							(	1=1	"1.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_choice	)

recode	Q233P				(	4=5	"5.Very often"		)							///
							(	3=4	"4.Fairly often"		)						///
							(	2=2	"2.Not often"		)							///
							(	1=1	"1.Not at all often"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_fem	)

recode	Q234AP				(	5=5	"5.A great deal"		)						///
							(	4=4	"4.A lot"		)								///
							(	3=3	"3.Some"		)								///
							(	2=2	"2.Very little"		)							///
							(	1=1	"1.Not at all"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	elec_say	)

recode	Q234P				(	4=5	"5.Very important"		)						///
							(	3=4	"4.Rather important"		)					///
							(	2=2	"2.Not very important"		)					///
							(	1=1	"1.Not at all important"		)				///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	honelec_matter	)

recode	Q235P				(	4=1	"1.Very good"		)							///
							(	3=2	"2.Fairly good"		)							///
							(	2=4	"4.Fairly bad"		)							///
							(	1=5	"5.Very bad"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	dem_strong	)

recode	Q236P				(	4=1	"1.Very good"		)							///
							(	3=2	"2.Fairly good"		)							///
							(	2=4	"4.Fairly bad"		)							///
							(	1=5	"5.Very bad"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	dem_experts	)

recode	Q237P				(	4=1	"1.Very good"		)							///
							(	3=2	"2.Fairly good"		)							///
							(	2=4	"4.Fairly bad"		)							///
							(	1=5	"5.Very bad"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	dem_army	)

recode	Q238P				(	4=5	"5.Very good"		)							///
							(	3=4	"4.Fairly good"		)							///
							(	2=2	"2.Fairly bad"		)							///
							(	1=1	"1.Very bad"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	dem_dem	)

recode	Q239P				(	4=1	"1.Very good"		)							///
							(	3=2	"2.Fairly good"		)							///
							(	2=4	"4.Fairly bad"		)							///
							(	1=5	"5.Very bad"		)							///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	dem_rel	)

recode	Q240				(	10=1	"1.Right"		)							///
							(	9=2)	(	8=3)									///
							(	7=4)	(	6=5)	(	5=6)	(	4=	7)			///
							(	3=8)	(	2=9)									///
							(	1=10	"10.Left"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	val_left	)

recode	Q241				(	10=10	"10.Taxing rich to help poor essential"	)	///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Taxing rich to help poor not essential")	///
							(	0=0		"0.Taxing rich against democracy"	)		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_poor	)

recode	Q242				(	10=10	"10.Religious rule essential"		)		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Religious rule not essential"	)		///
							(	0=0		"0.Religious rule against democracy")		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_rel	)

recode	Q243				(	10=10	"10.Free elections essential"		)		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Free elections not essential"		)		///
							(	0=0	"0.Free elections against democracy"		)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_elec	)

recode	Q244				(	10=10	"10.Help unemployed essential"		)		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Help unemployed not essential"	)		///
							(	0=0		"0.Help unemployed against democracy"	)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_unemp	)

recode	Q245				(	10=10	"10.Army can take over essential"		)	///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Army can take over not essential"	)	///
							(	0=0		"0.Army can take over against democracy")	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_army	)

recode	Q246				(	10=10	"10.Civil liberties essential"		)		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Civil liberties not essential"	)		///
							(	0=0		"0.Civil liberties against democracy"	)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_liberty	)

recode	Q247				(	10=10	"10.Income equality essential"		)		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Income equality not essential"	)		///
							(	0=0		"0.Income equality against democracy")		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_equal	)

recode	Q248				(	10=10	"10.Obedience essential"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Obedience rule not essential"	)		///
							(	0=0		"0.Obedience against democracy"		)		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_obey	)

recode	Q249				(	10=10	"10.Women's rights essential"		)		///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1		"1.Women's rights not essential"	)		///
							(	0=0		"0.Women's rights against democracy"	)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	essdem_fem	)

recode	Q250				(	10=10	"10.Absolutely important"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Not at all important"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	demimp 	)

recode	Q251				(	10=10	"10.Completely democratic"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Not at all democratic"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	howdem	)

recode	Q252				(	10=10	"10.Completely satisfied"		)			///
							(	9=9)	(	8=8)									///
							(	7=7)	(	6=6)	(	5=5)	(	4=	4)			///
							(	3=8)	(	2=9)									///
							(	1=1	"1.Not at all satisfied"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	polsat	)

recode	Q253P				(	4=5	"5.A great deal of respect"		)				///
							(	3=4	"4.Fair amount"		)							///
							(	2=2	"2.Not much respect"		)					///
							(	1=1	"1.No respect at all"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	perc_rights	)

recode	Q254P				(	4=5	"5.Very proud"		)							///
							(	3=4	"4.Quite proud"		)							///
							(	2=2	"2.Not very proud"		)						///
							(	1=1	"1.Not at all proud"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	nat_pride	)

recode	Q255P				(	4=5	"5.Very close"		)							///
							(	3=4	"4.Close"		)								///
							(	2=2	"2.Not very close"		)						///
							(	1=1	"1.Not at all close"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	close_local	)

recode	Q256P				(	4=5	"5.Very close"		)							///
							(	3=4	"4.Close"		)								///
							(	2=2	"2.Not very close"		)						///
							(	1=1	"1.Not at all close"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	seeself_local	)

recode	Q257P				(	4=5	"5.Very close"		)							///
							(	3=4	"4.Close"		)								///
							(	2=2	"2.Not very close"		)						///
							(	1=1	"1.Not at all close"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	seeself_reg	)

recode	Q258P				(	4=5	"5.Very close"		)							///
							(	3=4	"4.Close"		)								///
							(	2=2	"2.Not very close"		)						///
							(	1=1	"1.Not at all close"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	close_cont	)

recode	Q259P				(	4=5	"5.Very close"		)							///
							(	3=4	"4.Close"		)								///
							(	2=2	"2.Not very close"		)						///
							(	1=1	"1.Not at all close"		)					///
							(	-1=3	"3.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	close_world	)

recode	Q260				(	1=0	"0.Male"		)								///
							(	2=1	"1.Female"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	female	)

recode	Q261								(	-1=.d	"Don't know"		)		///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	birthyr	)

recode	Q262				(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	age	)

recode	X003R				(	1=1	"1.16-24 years"		)							///
							(	2=2	"2.25-34 years"		)							///
							(	3=3	"3.35-44 years"		)							///
							(	4=4	"4.45-54 years"		)							///
							(	5=5	"5.55-64 years"		)							///
							(	6=6	"6.65 and over"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	age_6cat	)

recode	X003R2				(	1=1	"1.16-29 years"		)							///
							(	2=2	"2.30-49 years"		)							///
							(	3=3	"3.50 years and older"		)					///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	age_3cat	)

recode	Q263				(	1=0	"0.Born here"		)							///
							(	2=1	"1.Immigrant"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	forborn	)

recode	Q264				(	1=0	"0.Born here"		)							///
							(	2=1	"1.Immigrant"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	ma_forborn	)

recode	Q265				(	1=0	"0.Born here"		)							///
							(	2=1	"1.Immigrant"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	pa_forborn	)

recode	Q269				(	1=1	"1.Citizen"		)								///
							(	2=0	"0.Not citizen"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	citizen	)

recode	Q270								(	-1=.d	"Don't know"		)		///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	hh_num	)

recode	Q271				(	1=0	"0.No"		)									///
							(	2=1	"1.Live with parents"		)					///
							(	3 4=2	"2.Live with in laws"		)				///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	hh_parents	)

recode	Q273				(	1=1	"1.Married"		)								///
							(	2=2	"2.Living as married"		)					///
							(	3=3	"3.Divorced"		)							///
							(	4=4	"4.Separated"		)							///
							(	5=5	"5.Widowed"		)								///
							(	6=6	"6.Single"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	mar_nom	)

recode	Q274				(	0=0	"0.None"		)								///
							(	1=1	"1.One child"		)							///
							(	2=2	"2.Two children"		)						///
							(	3=3	"3.Three children"		)						///
							(	4=4	"4.Four children"		)						///
							(	5=5	"5.Five children"		)						///
							(	6=6	"6.Six children"		)						///
							(	7 / 24=7	"7.Seven or more children"		)		///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	hh_kidsnum	)

recode	Q275				(	0=0	"0.No education"		)						///
							(	1=1	"1.Primary school"		)						///
							(	2=2	"2.Lower secondary"		)						///
							(	3=3	"3.Finished secondary"		)					///
							(	4=4	"4.Post-secondary general"		)				///
							(	5=5	"5.Post-secondary vocational"		)			///
							(	6=6	"6.Bachelors"		)							///
							(	7=7	"7.Masters"		)								///
							(	8=8	"7.Doctorate"		)							///
							(	-1 9=.d	"Don't know or other"		)				///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	educ	)

recode	Q276				(	0=0	"0.No education"		)						///
							(	1=1	"1.Primary school"		)						///
							(	2=2	"2.Lower secondary"		)						///
							(	3=3	"3.Finished secondary"		)					///
							(	4=4	"4.Post-secondary general"		)				///
							(	5=5	"5.Post-secondary vocational"		)			///
							(	6=6	"6.Bachelors"		)							///
							(	7=7	"7.Masters"		)								///
							(	8=8	"7.Doctorate"		)							///
							(	-1 9=.d	"Don't know or other"		)				///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	sp_educ	)

recode	Q277				(	0=0	"0.No education"		)						///
							(	1=1	"1.Primary school"		)						///
							(	2=2	"2.Lower secondary"		)						///
							(	3=3	"3.Finished secondary"		)					///
							(	4=4	"4.Post-secondary general"		)				///
							(	5=5	"5.Post-secondary vocational"		)			///
							(	6=6	"6.Bachelors"		)							///
							(	7=7	"7.Masters"		)								///
							(	8=8	"7.Doctorate"		)							///
							(	-1 9=.d	"Don't know or other"		)				///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	ma_educ	)

recode	Q278				(	0=0	"0.No education"		)						///
							(	1=1	"1.Primary school"		)						///
							(	2=2	"2.Lower secondary"		)						///
							(	3=3	"3.Finished secondary"		)					///
							(	4=4	"4.Post-secondary general"		)				///
							(	5=5	"5.Post-secondary vocational"		)			///
							(	6=6	"6.Bachelors"		)							///
							(	7=7	"7.Masters"		)								///
							(	8=8	"7.Doctorate"		)							///
							(	-1 9=.d	"Don't know or other"		)				///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	pa_educ	)

recode	Q279				(	1=1	"1.Full time"		)							///
							(	2=2	"2.Part time"		)							///
							(	3=3	"3.Self-employed"		)						///
							(	4=4	"4.4.Retired"		)							///
							(	5=5	"5.5.Housewife"		)							///
							(	6=6	"6.6.Student"		)							///
							(	7=7	"7.7.Unemployed"		)						///
							(	8=8	"8.8.Other"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)(	-3=.n	"NA"		)		///
							(	-5=.a	"NA"), generate (	employ_nom	)

recode	Q280				(	1=1	"1.Full time"		)							///
							(	2=2	"2.Part time"		)							///
							(	3=3	"3.Self-employed"		)						///
							(	4=4	"4.4.Retired"		)							///
							(	5=5	"5.5.Housewife"		)							///
							(	6=6	"6.6.Student"		)							///
							(	7=7	"7.7.Unemployed"		)						///
							(	8=8	"8.8.Other"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)	(	-3=.n	"NA"		)	///
							(	-5=.a	"NA"), generate (	sp_employ_nom	)

recode	Q281				(	0=0	"0.Never had a job"		)						///
 						(	1=1	"1.Professional or tech"		)					///
 						(	2=2	"2.Higher admin"		)							///
 						(	3=3	"3.Clerical"		)								///
 						(	4=4	"4.Sales"		)									///
 						(	5=5	"5.Service"		)									///
 						(	6=6	"6.Skilled worker"		)							///
 						(	7=7	"7.Semi-skilled worker"		)						///
						(	8=8	"8.Unskilled worker"		)						///
 						(	9=9	"9.Farm worker"		)								///
 						(	10=10	"10.Farm owner, manager"		)				///
 						(	11=11	"11.JP,KG,TJ: Other"		)					///
							(	-3=12	"12.Not currently employed"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	occ_nom	)

recode	Q282				(	0=0	"0.Never had a job"		)						///
 						(	1=1	"1.Professional or tech"		)					///
 						(	2=2	"2.Higher admin"		)							///
 						(	3=3	"3.Clerical"		)								///
 						(	4=4	"4.Sales"		)									///
 						(	5=5	"5.Service"		)									///
 						(	6=6	"6.Skilled worker"		)							///
 						(	7=7	"7.Semi-skilled worker"		)						///
						(	8=8	"8.Unskilled worker"		)						///
 						(	9=9	"9.Farm worker"		)								///
 						(	10=10	"10.Farm owner, manager"		)				///
 						(	11=11	"11.JP,KG,TJ: Other"		)					///
							(	-3=12	"12.Not currently employed"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	sp_occ_nom	)

recode	Q283				(	0=0	"0.Never had a job"		)						///
 						(	1=1	"1.Professional or tech"		)					///
 						(	2=2	"2.Higher admin"		)							///
 						(	3=3	"3.Clerical"		)								///
 						(	4=4	"4.Sales"		)									///
 						(	5=5	"5.Service"		)									///
 						(	6=6	"6.Skilled worker"		)							///
 						(	7=7	"7.Semi-skilled worker"		)						///
						(	8=8	"8.Unskilled worker"		)						///
 						(	9=9	"9.Farm worker"		)								///
 						(	10=10	"10.Farm owner, manager"		)				///
 						(	11=11	"11.JP,KG,TJ: Other"		)					///
							(	-3=12	"12.Not currently employed"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	pa_occ_nom	)

recode	Q284				(	-3=0	"0.Never had a job"		)					///
							(	1=1	"1.Government institution"		)				///
							(	2=2	"2.Private business"		)					///
							(	3=3	"3.Non-profit"		)							///
							(	-1=4	"4.Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	sector_nom	)

recode	Q285				(	1=1	"1.Yes"		)	(	2=0	"0.No"		)			///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	chief_earn	)

recode	Q286				(	1=4	"4.Save money"		)							///
							(	2=2	"2.Just get by"		)							///
							(	3=3	"3.Spent some savings"		)					///
							(	4=1	"1.Spent savings and borrowed money"		)	///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	savings	)

recode	Q287P				(	5=5	"5.Upper class"		)							///
							(	4=4	"4.Upper middle class"		)					///
							(	3=3	"3.Lower middle class"		)					///
							(	2=2	"2.Working class"		)						///
							(	1=1	"1.Lower class"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	class	)

recode	Q288				(	1=1	"1.Lower step"		)							///
							(	2=2	"2.second step"		)							///
							(	3=3	"3.Third step"		)							///
							(	4=4	"4.Fourth step"		)							///
							(	5=5	"5.Fifth step"		)							///
							(	6=6	"6.Sixth step"		)							///
							(	7=7	"7.Seventh step"		)						///
							(	8=8	"8.Eight step"		)							///
							(	9=9	"9.Nineth step"		)							///
							(	10=10	"10.=Tenth step"		)							///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	income	)

recode	Q288R				(	1=1	"1.Low"		)										///
							(	2=2	"2.Medium"		)								///
							(	3=3	"3.High"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	inc_3cat	)

recode	Q289				(	0=0	"0.Do not belong to a denomination"		)		///
							(	1=1	"1.Roman Catholic"		)						///
							(	2=2	"2.Protestant"		)							///
							(	3=3	"3.Orthodox-Russian-Greek")									///
							(	4=4	"4.Jew"		)									///
							(	5=5	"5.Muslim"		)								///
							(	6=6	"6.Hindu"		)								///
							(	7=7	"7.Buddhist"		)							///
							(	8=8	"8.Other Christian"		)						///
							(	9=9	"9.Other"		)								///
							(	-1=.d	"Don't know"		)						///
							(	-2=.e	"Not answered"		)						///
							(	-4=.a	"NA"		)								///
							(	-5=.a	"NA"), generate (	denom	)


recode news_paper news_tv news_radio news_mobile news_email news_web news_social news_friends (	-1=.d)

recode ma_forborn pa_forborn sp_educ ma_educ pa_educ (	-3=.n)


foreach var of varlist  townsize8 townsize5 towntype urban int_rint int_priv imp_family imp_friends imp_leisure imp_politics imp_work imp_rel val_manners val_indep val_work val_resp val_imag val_tol val_thrift val_determ val_rel val_unself val_obey nei_addicts nei_race nei_aids nei_imm nei_gay nei_reldif nei_drink nei_notmar nei_langdif par_proud notfem_kids notfem_pol notfem_educ notfem_execs notfem_wifeall notfem_jobs notimm_jobs notfem_inc gay_kids duty_kids duty_par notwork_lazy work_duty workfirst cons_ref_rev fut_work_notless fut_tech fut_obey happy health ext_loc_control satlife satfin econbad_food econbad_crime econbad_med econbad_cash econbad_home econ_parents trust trust_fam trust_nei trust_know trust_meet trust_rel trust_noncit conf_church conf_army conf_press conf_tv conf_unions conf_police conf_courts conf_gov conf_parties conf_parl conf_civil conf_univ conf_elec conf_bus conf_banks conf_env conf_womens conf_charit conf_reggov know_UN know_IMF know_Amnesty mem_church mem_sport mem_art mem_union mem_party mem_env mem_prof mem_charit mem_consumer mem_selfhelp mem_womens mem_other val_incdif val_privown val_ind val_compet val_hardwork val_env corrupt corr_state corr_bus corr_local corr_civil corr_journ bribe_freq bribe_account imm_good imm_useful_jobs imm_cult_div imm_crime imm_asylum imm_terror imm_poor imm_unemp imm_conflict mig_sup nei_sec nei_rob nei_alc nei_police nei_racist nei_drugs nei_viol nei_harass nei_cash nei_out nei_weap worry_job worry_kidseduc victim_self victim_fam worry_war worry_terror worry_civwar val_free_equal val_free_sec fight_country valsci_life valsci_opp valsci_faith valsci_morals valsci_know valsci_better rel_godimp rel_god rel_life rel_hell rel_heaven rel_right rel_mine rel_attend rel_pray rel_pers rel_good rel_thislife morals_hard law_govben law_fare law_steal law_taxes law_bribe morals_gay morals_prost morals_abor morals_div morals_sex morals_suic morals_letdie viol_beatwife viol_childs viol_other viol_terror morals_casual viol_pol viol_death_pen surv_video surv_email surv_allinfo polint poltalk news_paper news_tv news_radio news_mobile news_email news_web news_social news_friends polpart_pet polpart_boy polpart_prot polpart_strikes polpart_donate polpart_contact polpart_othact polpart_othvote polpart_socmed_search polpart_socmed_sign polpart_socmed_othact polpart_socmed_organize vote_local vote_nat elec_votes elec_oppno elec_press_incum elec_bribe elec_pressfair elec_off elec_rich elec_viol elec_choice elec_fem elec_say honelec_matter dem_strong dem_experts dem_army dem_dem dem_rel val_left essdem_poor essdem_rel essdem_elec essdem_unemp essdem_army essdem_liberty essdem_equal essdem_obey essdem_fem demimp howdem polsat perc_rights nat_pride close_local seeself_local seeself_reg close_cont close_world female birthyr age forborn ma_forborn pa_forborn citizen hh_num hh_parents hh_kidsnum educ sp_educ ma_educ pa_educ chief_earn savings class income   {
	qui sum `var'
	gen `var'01=(	`var' - `r(	min)')	/ (	`r(	max)'-`r(	min)')
}



	
	order secvalwgt resemavalwgt fhregion polregfh freestfh prfhrat prfhscore clfhrat clfhscore democ autoc polity durable regtype ruleoflaw corrupttransp electintegr btiregion btistatus btidemstatus btistate btipolpart btiruleoflaw btistability btiintegration btimarket btigovindex btigoveperform btiregime regionWB incomeWB landWB GDPpercap1 GDPpercap2 giniWB incrichest10p popWB1990 popWB2000 popWB2019 lifeexpect popgrowth urbanpop laborforce deathrate unemployfem unemploymale unemploytotal accessclfuel accesselectr renewelectr co2emis co2percap easeofbusiness militaryexp Trade healthexp educationexp medageun meanschooling educationHDI compulseduc gii dgi womenparl hdi incomeindexHDI humanineqiality lifeexpectHDI homiciderate Refugeesorigin internetusers mobphone migrationrate schoolgpi femchoutsch choutsch v2x_polyarchy v2x_libdem v2x_partipdem v2x_delibdem v2x_egaldem v2x_freexp_altinf v2x_frassoc_thick v2xel_frefair v2xcl_rol v2x_cspart v2xeg_eqdr v2excrptps v2exthftps v2juaccnt v2cltrnslw v2clacjust v2clsocgrp v2clacfree v2clrelig v2csrlgrep v2mecenefm v2mecenefi v2mebias v2pepwrses v2pepwrgen v2peedueq v2pehealth v2peapsecon v2peasjsoecon v2clgencl v2peasjgen v2peasbgen v2cafres v2cafexch v2x_corr v2x_gender v2x_gencl v2x_genpp v2x_rule v2xcl_acjst ID_GPS ID_PartyFacts Partyabb cparty cpartyabb Type_Values Type_Populism Type_Populist_Values Type_Partysize_vote Type_Partysize_seat GPS_V4_Scale GPS_V6_Scale GPS_V8_Scale GPS_V9 GPS_V10 GPS_V11 GPS_V12 GPS_V13 GPS_V14 GPS_V15 GPS_V16 GPS_V17 WVS_LR_PartyVoter WVS_LibCon_PartyVoter WVS_Polmistrust_PartyVoter WVS_LR_MedianVoter WVS_LibCon_MedianVoter v2psbars v2psorgs v2psprbrch v2psprlnks v2psplats v2xnp_client v2xps_party , after (	savings01)
clonevar fh_reg=fhregion
clonevar fh_regime=polregfh
clonevar fh_free=freestfh
clonevar fh_pol=prfhrat
clonevar fh_polscore=prfhscore
clonevar fh_civlib=clfhrat
clonevar fh_civlibscore=clfhscore
clonevar p_democ=democ
clonevar p_autoc=autoc
clonevar p_regdur=durable
clonevar p_regtype=regtype
clonevar wjp_ruleoflaw=ruleoflaw
clonevar ti_corrupt=corrupttransp
clonevar elect_integ=electintegr
clonevar bti_region=btiregion
clonevar bti_status=btistatus
clonevar bti_demstatus=btidemstatus
clonevar bti_state=btistate
clonevar bti_polpart=btipolpart
clonevar bti_ruleoflaw=btiruleoflaw
clonevar bti_stability=btistability
clonevar bti_integration=btiintegration
clonevar bti_market=btimarket
clonevar bti_govindex=btigovindex
clonevar bti_goveperform=btigoveperform
clonevar bti_regime=btiregime
clonevar wb_reg=regionWB
clonevar wb_gdp=incomeWB
clonevar wb_land=landWB
clonevar gdp2=GDPpercap2
clonevar wb_gini=giniWB
clonevar richest10=incrichest10p
clonevar wb_pop1990=popWB1990
clonevar wb_pop2000=popWB2000
clonevar wb_pop=popWB2019
clonevar life_exp=lifeexpect
clonevar popgrow=popgrowth
clonevar death=deathrate
clonevar unemp_fem=unemployfem
clonevar unemp_men=unemploymale
clonevar unemp=unemploytotal
clonevar ease_bus=easeofbusiness
clonevar mil_expend=militaryexp
clonevar trade=Trade
clonevar health_expend=healthexp
clonevar educ_expend=educationexp
clonevar med_age=medageun
clonevar mean_educ=meanschooling
clonevar gender_ineq=gii
clonevar gen_dev=dgi
clonevar fempols=womenparl
clonevar humdev=hdi
clonevar income_HDI01=incomeindexHDI
clonevar hum_ineq=humanineqiality
clonevar un_life_exp=lifeexpectHDI
clonevar murder=homiciderate
clonevar web_users=internetusers
clonevar mob_users=mobphone
clonevar migrate=migrationrate

clonevar v2_poly=v2x_polyarchy
clonevar v2_libdem=v2x_libdem
clonevar v2_polpart=v2x_partipdem
clonevar v2_delib=v2x_delibdem
clonevar v2_egal=v2x_egaldem
clonevar v2_altspeech=v2x_freexp_altinf
clonevar v2_assoc=v2x_frassoc_thick
clonevar v2_freefair=v2xel_frefair
clonevar v2_rol=v2xcl_rol
clonevar v2_civpart=v2x_cspart
clonevar v2_equal=v2xeg_eqdr
clonevar v2_pubcorrupt=v2excrptps
clonevar v2_pubtheft=v2exthftps
clonevar v2_judaccount=v2juaccnt
clonevar v2_lawclear=v2cltrnslw
clonevar v2_classequal=v2clacjust
clonevar v2_groupequal=v2clsocgrp
clonevar v2_acadcultexp=v2clacfree
clonevar v2_relfree=v2clrelig
clonevar v2_relorgrep=v2csrlgrep
clonevar v2_govcens=v2mecenefm
clonevar v2_intexp=v2mecenefi
clonevar v2_medbias=v2mebias
clonevar v2_classpower=v2pepwrses
clonevar v2_gendpower=v2pepwrgen
clonevar v2_educequal=v2peedueq
clonevar v2_healthequal=v2pehealth
clonevar v2_pubservequal=v2peapsecon
clonevar v2_statejobsequal=v2peasjsoecon
clonevar v2_gendcivlib=v2clgencl
clonevar v2_statejobsgend=v2peasjgen
clonevar v2_statebusgend=v2peasbgen
clonevar v2_research_teach=v2cafres
clonevar v2_acadfree=v2cafexch
clonevar v2_polcorr=v2x_corr
clonevar v2_fempower=v2x_gender
clonevar v2_femcivlib=v2x_gencl
clonevar v2_fempolpart=v2x_genpp
clonevar v2_ruleoflaw=v2x_rule
clonevar v2_accessjust=v2xcl_acjst


label var region				"WV: Region" 
label var townsize8				"WV: Size of town, 8 categories" 
label var townsize5				"WV: Size of town, 5 categories" 
label var towntype				"WV: Political power of town" 
label var urban					"WV: Urban" 
label var psu					"Primary sampling unit" 
label var lang					"Language" 
label var int_rint				"Interviewer: R interested" 
label var int_priv				"Interviewer: privacy" 
label var weight_cs				"Weight to use in analyzing single countries" 
label var weight				"Weight to use for multiple countries" 
label var popweight				"Weight to use when generalizing globally" 
label var post12				"Post-materialism, 12 categories" 
label var post4					"Post-materialism, 4 categories" 
label var aut5					"Values autonomy, 5 categories" 
label var valsec01				"Values secular" 
label var valeman01				"Values freedom" 
label var val_notobey01			"Values authority" 
label var val_notnat01			"Values nationalism" 
label var val_notrel01			"Devoutness" 
label var valdefy01				"Authority defiance" 
label var rel_notimp01			"Religious importance" 
label var rel_notbel01			"Religious belief" 
label var rel_notprac01			"Religious activitiess" 
label var reldis01				"Religious disbelief" 
label var norm1					"Nonconformity I" 
label var norm2					"Nonconformity II" 
label var norm3					"Nonconformity III" 
label var nonconform01			"Overall nonconformity" 
label var not_trustarmy01 		"Not trust army" 
label var not_trustpolice01 	"Not trust police" 
label var not_trust_courts		"Not trust courts" 
label var skeptic01				"Distrust of army, police, courts" 
label var indep01				"Value independence" 
label var imag01				"Value imagination" 
label var notobey01				"Value not obeying" 
label var autonomy01			"Value autonomy" 



label var imp_family			"Important: Family"
label var imp_friends			"Important: Friends"
label var imp_leisure			"Important: Leisure time"
label var imp_politics			"Important: Politics"
label var imp_work				"Important: Work"
label var imp_rel				"Important:  Religion"
label var val_manners			"Children: manners"
label var val_indep				"Children: Independence"
label var val_work				"Children: Hard work"
label var val_resp				"Children: Responsibility"
label var val_imag				"Children: Imagination"
label var val_tol				"Children: Tolerant"
label var val_thrift			"Children: thrifty"
label var val_determ			"Children: perseverance"
label var val_rel				"Children: religious"
label var val_unself			"Children: Unselfish"
label var val_obey				"Children: Obedience"
label var nei_addicts			"Not want as neighbors: Drug addicts"
label var nei_race				"Not want as neighbors: People of a different race"
label var nei_aids				"Not want as neighbors: People who have AIDS"
label var nei_imm				"Not want as neighbors: Immigrants / foreign workers"
label var nei_gay				"Not want as neighbors: LGBTQ"
label var nei_reldif			"Not want as neighbors: Different religion"
label var nei_drink				"Not want as neighbors: Heavy drinkers"
label var nei_notmar			"Not want as neighbors: Unmarried couples"
label var nei_langdif			"Not want as neighbors: Different language"
label var par_proud				"Main goal: make my parents proud"
label var notwork_lazy			"People who don´t work turn lazy"
label var work_duty				"Work is a duty towards society"
label var workfirst				"Work should always come first even if it means less spare time"
label var cons_ref_rev			"Society: preserve low is revolution 	high is preserve"
label var fut_work_notless		"Future not less work"
label var fut_tech				"Future more technology"
label var fut_obey				"Future more authority"



label var happy					"Happiness"
label var health				"Health"
label var ext_loc_control		"External locus of control"
label var satlife				"Life satisfaction"
label var satfin				"Financial satisfaction"
label var econbad_food			"Last year: not enough food"
label var econbad_crime			"Last year: felt unsafe from crime"
label var econbad_med			"Last year: can't afford healthcare"
label var econbad_cash			"Last year: too little income"
label var econbad_home			"Last year: homeless"
label var econ_parents			"Financial, compared to parents"
label var trust					"Most people can be trusted"
label var trust_fam				"Trust family"
label var trust_nei				"Trust neighbors"
label var trust_know			"Trust people you know"
label var trust_meet			"Trust people you meet"
label var trust_rel				"Trust people of another religion"
label var trust_noncit			"Trust people from another country"
label var conf_church			"Confidence in churches"
label var conf_army				"Confidence in army"
label var conf_press			"Confidence in press"
label var conf_tv				"Confidence in television"
label var conf_unions			"Confidence in labor unions"
label var conf_police			"Confidence in police"
label var conf_courts			"Confidence in judicial system"
label var conf_gov				"Confidence in government"
label var conf_parties			"Confidence in political parties"
label var conf_parl				"Confidence in legislature"
label var conf_civil			"Confidence in civil service"
label var conf_univ				"Confidence in universities"
label var conf_elec				"Confidence in elections"
label var conf_bus				"Confidence in major companies"
label var conf_banks			"Confidence in banks"
label var conf_env				"Confidence in environmental movement"
label var conf_womens			"Confidence in women´s movement"
label var conf_charit			"Confidence in charities"
label var conf_reggov			"Confidence in state"



label var know_UN 				"Knowledge: UN Security Council 3"
label var know_IMF 				"Knowledge: headquarters of the IMF 1"
label var know_Amnesty 			"Knowledge: Amnesty Int. 2"
label var mem_church			"Member of a church member"
label var mem_sport				"Sports, leisure member"
label var mem_art				"Member of a church"
label var mem_union				"Member of a union"
label var mem_party				"Member of a political party"
label var mem_env				"Member of an environmental group"
label var mem_prof				"Member of a professional org"
label var mem_charit			"Member of a charity"
label var mem_consumer			"Member of a consumer group"
label var mem_selfhelp			"Member of a self-help group"
label var mem_womens			"Member of a women's group"
label var mem_other				"Member of a different group"
label var val_incdif			"Incomes should be more equal"
label var val_privown			"Private vs state ownership of business"
label var val_ind				"Individual´s responsibility not government"
label var val_compet			"Competition good over harmful"
label var val_hardwork			"Success: hard work over luck"
label var val_env				"Protecting environment over economy"
label var corrupt				"Perceptions of corruption in the..."
label var corr_state			"Corrupt: State"
label var corr_bus				"Corrupt: Business"
label var corr_local			"Corrupt: Local			"
label var corr_civil			"Corrupt: Civil servants"
label var corr_journ			"Corrupt: Journalists"
label var bribe_freq			"Corrupt: ordinary people bribe"
label var bribe_account			"Risk of being caught for bribes"
label var imm_good				"Immigration: good overall"
label var imm_useful_jobs		"Immigrants take useful jobs"
label var imm_cult_div			"Immigrants bring cultural diversity"
label var imm_asylum			"Immigrants seeking asylum"
label var imm_poor				"Immigrants help reduce poverty"
label var imm_crime				"Immigrants bring crime"
label var imm_terror			"Immigrants bring terrorism"
label var imm_unemp				"Immigrants increase unemployment"
label var imm_conflict			"Immigrants bring conflict"
label var mig_sup				"Immigration for work: increased"
label var nei_sec				"Neighborhood security"
label var nei_rob				"Neighborhood: robberies"
label var nei_alc				"Neighborhood: drunks"
label var nei_police			"Neighborhood: police interfere"
label var nei_racist			"Neighborhood: racists"
label var nei_drugs				"Neighborhood: drugs"
label var nei_viol				"Neighborhood: violence"
label var nei_harass			"Neighborhood: harassment"
label var nei_cash				"To protect safety: not take cash"
label var nei_out				"To protect safety: not gone out at night"
label var nei_weap				"To protect safety: carry weapon"
label var worry_job				"Worries: Losing my job"
label var worry_kidseduc		"Worries: Kids education"
label var victim_self			"Last year: victim of crime"
label var victim_fam			"Last year: family victim of crime"
label var worry_war				"Worries: war"
label var worry_terror			"Worries: terrorism"
label var worry_civwar			"Worries: civil war"
label var val_free_equal		"Values freedom over equality"
label var val_free_sec			"Values freedom over security"
label var fight_country			"Willingness to fight for country"
label var valsci_life			"Science makes our lives better"
label var valsci_opp			"Science creates opportunities for future"
label var valsci_faith			"Not depend too much on science"
label var valsci_morals			"Science does not harm our sense of right and wrong"
label var valsci_know			"Important to know about science for daily life"
label var valsci_better			"Science makes world better off"
label var rel_godimp			"Importance of God"
label var rel_god				"Belief: God"
label var rel_life				"Belief: life after death"
label var rel_hell				"Belief: hell"
label var rel_heaven			"Belief: heaven"
label var rel_right				"Religion, not science, is always right"
label var rel_mine				"Only my religion is acceptable"
label var rel_attend			"Religious attendance"
label var rel_pray				"Prayer"
label var rel_pers				"Religious person"
label var rel_good				"Meaning of religion: do good to others more than ceremony"
label var rel_thislife			"Meaning of religion: this world more than after death"
label var morals_hard			"Moral rules confusing"
label var law_govben			"Not justifiable to illegally claim government benefits"
label var law_fare				"Not justifiable to illegally avoid a fare on public transport"
label var law_steal				"Not justifiable to illegally steal"
label var law_taxes				"Not justifiable to illegally cheat on taxes"
label var law_bribe				"Not justifiable to illegally accept a bribe"
label var morals_gay			"Moral: LGBTQ"
label var morals_prost			"Moral: prostitution"
label var morals_abor			"Moral: abortion"
label var morals_div			"Moral: divorce"
label var morals_sex			"Moral: sex before marriage"
label var morals_suic			"Moral: suicide"
label var morals_letdie			"Moral: euthanasia"
label var viol_beatwife			"Justifiable: a man to beat his wife"
label var viol_childs			"Justifiable: Parents beating children"
label var viol_other			"Justifiable: Violence against other people"
label var viol_terror			"Justifiable: Terrorism"
label var morals_casual			"Justifiable: casual sex"
label var viol_pol				"Justifiable: Political violence"
label var viol_death_pen		"Justifiable: Death penalty"
label var surv_video			"Government should not: video surveillance"
label var surv_email			"Government should not: monitor e-mails"
label var surv_allinfo			"Government should not: Collect information about people"
label var polint				"Interest in politics"
label var poltalk				"Discuss politics with friends"
label var news_paper			"News: newspaper"
label var news_tv				"News: TV			"
label var news_radio			"News: Radio news"
label var news_mobile			"News: Mobile phone"
label var news_email			"News: Email"
label var news_web				"News: Internet"
label var news_social			"News: social media			"
label var news_friends			"News: discussions"
label var polpart_pet			"Political action: Sign a petition"
label var polpart_boy			"Political action: join boycotts"
label var polpart_prot			"Political action: demonstrations"
label var polpart_strikes			"Political action: unofficial strikes"
label var polpart_donate			"Social activism: donations"
label var polpart_contact			"Social activism: contacting an official"
label var polpart_othact			"Social activism: encouraging others"
label var polpart_othvote			"Social activism: Encouraging others to vote"
label var polpart_socmed_search		"Politics online: searching information"
label var polpart_socmed_sign		"Politics online: electronic petition"
label var polpart_socmed_othact		"Politics online: encouraging others"
label var polpart_socmed_organize	"Politics online: Organizing"
label var vote_local				"Vote: local"
label var vote_nat					"Vote: National"
label var elec_votes				"Votes are counted fairly"
label var elec_oppno				"Opposition candidates are not prevented from running"
label var elec_press_incum			"TV news free from favoring the governing party"
label var elec_bribe				"Voters are not bribed"
label var elec_pressfair			"Journalists provide fair coverage"
label var elec_off					"Election officials are fair"
label var elec_rich					"Rich people buy elections"
label var elec_viol					"Voters are not threatened with violence at the polls"
label var elec_choice				"Voters are offered a genuine choice in the elections"
label var elec_fem					"Women have equal opportunities to run the office"
label var elec_say					"How much the political system allows people to have a say			"
label var honelec_matter			"Honest elections matter"
label var dem_strong				"Best not to have a strong leader"
label var dem_experts				"Best not to have experts rule"
label var dem_army					"Best not to have army rule"
label var dem_dem					"Best to have a democracy"
label var dem_rel					"Best not to have religious rule"
label var val_left					"Left ideology"
label var essdem_poor				"Democracy essential: tax the rich to help the poor"
label var essdem_rel				"Democracy essential is not: religious rule"
label var essdem_elec				"Democracy essential: free elections"
label var essdem_unemp				"Democracy essential: aid unemployment"
label var essdem_army				"Democracy essential is not: army takes over"
label var essdem_liberty			"Democracy essential: civil liberties and rights"
label var essdem_equal				"Democracy essential is not: equal incomes"
label var essdem_obey				"Democracy essential: people obey their rulers"
label var essdem_fem				"Democracy essential: women have the same rights as men"
label var demimp					"Importance of democracy"
label var howdem					"How democratic is this country"
label var polsat					"Satisfaction with the political system"
label var perc_rights				"Respect for individual human rights nowadays"
label var nat_pride					"National pride"
label var close_local			"Feel close to your town"
label var seeself_local			"Feel close to your region or state"
label var seeself_reg			"Feel close to your country"
label var close_cont			"Feel close to your continent"
label var close_world			"Feel close to the world"
label var female				"Female"
label var birthyr				"Birth year"
label var age					"Age"
label var age_6cat				"Age, 6 categories"
label var age_3cat				"Age, 3 categories"
label var forborn				"Respondent immigrant"
label var ma_forborn			"Mother immigrant"
label var pa_forborn			"Father immigrant"
label var citizen				"Respondent citizen"
label var hh_num				"Number of people in household"
label var hh_parents			"Live with your parents or inlaws"
label var mar_nom				"Marital status"
label var hh_kidsnum			"Number of children"
label var educ					"Education"
label var sp_educ				"Education: Spouse"
label var ma_educ				"Education: Mother"
label var pa_educ				"Education: Father"
label var employ_nom			"Employment"
label var sp_employ_nom			"Employment: Spouse"
label var occ_nom				"Occupational group"
label var sp_occ_nom			"Occupational group: Spouse"
label var pa_occ_nom			"Occupational group: Father"
label var sector_nom			"Sector of employment"
label var chief_earn			"Chief wage earner"
label var savings				"Family savings versus debt in last year"
label var class					"Social class"
label var income				"Income"
label var inc_3cat				"Income"
label var denom					"Religious denomination"


label var fh_reg			"Freedom House: Region"
label var fh_regime			"Freedom House: Regime freedom"
label var fh_free			"Freedom House: Global Freedom			"
label var fh_pol			"Freedom House: Political rights, 7 categories"
label var fh_polscore		"Freedom House: Political rights, 40 categories"
label var fh_civlib			"Freedom House: Civil liberties, 7 categories"
label var fh_civlibscore	"Freedom House: Civil liberties, 40 categories"
label var p_democ			"Polity: institutionalized democracy"
label var p_autoc			"Polity: institutionalized autocracy			"
label var polity			"Polity: democracy overall"
label var p_regdur			"Polity: number of years since regime change"
label var p_regtype			"Polity: Regime type, 5 categories"
label var wjp_ruleoflaw		"World Justice Project: Rule of law"
label var ti_corrupt		"Transparency International: Corruption perception			"
label var elect_integ		"Electoral Integrity Project index"
label var bti_region		"BTI: Region			"
label var bti_status		"BTI: Status index			"
label var bti_demstatus		"BTI: Democracy level"
label var bti_state			"BTI: Stateness"
label var bti_polpart		"BTI: Political participation"
label var bti_ruleoflaw		"BTI: Rule of law"
label var bti_stability		"BTI: Stability of democratic institutions"
label var bti_integration	"BTI: Political and social integration"
label var bti_market		"BTI: Market economy"
label var bti_govindex		"BTI: Governance index"
label var bti_goveperform	"BTI: Governance performance"
label var bti_regime		"BTI: Regime type, 5 categories"
label var wb_reg			"World Bank: Region, 7 categories"
label var wb_gdp			"World Bank: Income of country, 4 categories"
label var wb_land			"World Bank: Land area"
label var gdp2				"World Bank: GDP 2017 $"
label var wb_gini			"World Bank: GINI index latest available"
label var richest10			"World Bank: Income of richest 10%"
label var wb_pop1990		"World Bank: Population, 1990"
label var wb_pop2000		"World Bank: Population, 2000"
label var wb_pop			"World Bank: Population, 2019"
label var life_exp			"World Bank: Life expectancy"
label var popgrow			"World Bank: Population growth"
label var urbanpop			"World Bank: Urban population"
label var death				"World Bank: Death rate"
label var unemp_fem			"World Bank: Unemployment, female"
label var unemp_men			"World Bank: Unemployment, male"
label var unemp				"World Bank: Unemployment, total"
label var ease_bus			"World Bank: Ease of doing business"
label var mil_expend		"World Bank: Military expenditure"
label var trade				"World Bank: Trade"
label var health_expend		"World Bank: Health expenditure			"
label var educ_expend		"World Bank: Education expenditure"
label var med_age			"UN: Median age			"
label var mean_educ			"UN: Mean years of schooling"
label var gender_ineq		"UN: Gender inequality"
label var gen_dev			"UN: Gender development"
label var fempols			"Seats held by women in legislature"
label var humdev			"UN: Human development index"
label var income_HDI01		"UN: Country income			"
label var hum_ineq			"UN: Coefficient of human inequality"
label var un_life_exp		"UN: Life expectancy"
label var murder			"UN: Homicide rate"
label var web_users			"UN: Internet users, percent"
label var mob_users			"UN: Mobile phone users, percent"
label var migrate			"UN: Net migration rate			"
label var v2_poly			"V-Dem: Electoral democracy"
label var v2_libdem			"V-Dem: Liberal democracy"
label var v2_polpart		"V-Dem: Participatory democracy"
label var v2_delib			"V-Dem: Deliberative democracy"
label var v2_egal			"V-Dem: Egalitarian democracy"
label var v2_altspeech		"V-Dem: Freedom for alternate sources of information"
label var v2_assoc			"V-Dem: Freedom of association thick"
label var v2_freefair		"V-Dem: Clean elections"
label var v2_rol			"V-Dem: Equality, liberty before the law"
label var v2_civpart		"V-Dem: Civil society participation			"
label var v2_equal			"V-Dem: Equal distribution of resources"
label var v2_pubcorrupt		"V-Dem: Public sector corruption"
label var v2_pubtheft		"V-Dem: Public sector theft"
label var v2_judaccount		"V-Dem: Judicial accountability"
label var v2_lawclear		"V-Dem: Transparency, predictability of law enforcement"
label var v2_classequal		"V-Dem: Social class civil liberties"
label var v2_groupequal		"V-Dem: Social group civil liberties"
label var v2_acadcultexp	"V-Dem: Academic and cultural expression"
label var v2_relfree		"V-Dem: Freedom of religion"
label var v2_relorgrep		"V-Dem: Religious organization repression"
label var v2_govcens		"V-Dem: Government censorship of media"
label var v2_intexp			"V-Dem: Internet censorship effort"
label var v2_medbias		"V-Dem: Media bias"
label var v2_classpower		"V-Dem: Power distributed by socioeconomic position"
label var v2_gendpower		"V-Dem: Power distributed by gender"
label var v2_educequal		"V-Dem: Educational equality"
label var v2_healthequal	"V-Dem: Health equality"
label var v2_pubservequal	"V-Dem: Equality of access to public services, class"
label var v2_statejobsequal	"V-Dem: Access to state jobs by socio-economic position"
label var v2_gendcivlib		"V-Dem: Gender equality in respect for civil liberties"
label var v2_statejobsgend	"V-Dem: Access to state jobs by gender"
label var v2_statebusgend	"V-Dem: Access to state business opportunities by gender"
label var v2_research_teach	"V-Dem: Freedom to research and teach			"
label var v2_acadfree		"V-Dem: Academic freedom"
label var v2_polcorr		"V-Dem: Political corruption"
label var v2_fempower		"V-Dem: Women political empowerment"
label var v2_femcivlib		"V-Dem: Women civil liberties"
label var v2_fempolpart		"V-Dem: Women political participation"
label var v2_ruleoflaw		"V-Dem: Rule of law"
label var v2_accessjust		"V-Dem: Access to justice"



label var imp_family				"Important: Family"
label var imp_friends				"Important: Friends"
label var imp_leisure				"Important: Leisure time"
label var imp_politics				"Important: Politics"
label var imp_work					"Important: Work"
label var imp_rel					"Important:  Religion"
label var val_manners				"Children: manners"
label var val_indep					"Children: Independence"
label var val_work					"Children: Hard work"
label var val_resp					"Children: Responsibility"
label var val_imag					"Children: Imagination"
label var val_tol					"Children: Tolerant"
label var val_thrift				"Children: thrifty"
label var val_determ				"Children: perseverance"
label var val_rel					"Children: religious"
label var val_unself				"Children: Unselfish"
label var val_obey					"Children: Obedience"
label var nei_addicts				"Not want as neighbors: Drug addicts"
label var nei_race					"Not want as neighbors: People of a different race"
label var nei_aids					"Not want as neighbors: People who have AIDS"
label var nei_imm					"Not want as neighbors: Immigrants / foreign workers"
label var nei_gay					"Not want as neighbors: LGBTQ"
label var nei_reldif				"Not want as neighbors: Different religion"
label var nei_drink					"Not want as neighbors: Heavy drinkers"
label var nei_notmar				"Not want as neighbors: Unmarried couples"
label var nei_langdif				"Not want as neighbors: Different language"
label var par_proud					"Main goal: make my parents proud"
label var notwork_lazy				"People who don´t work turn lazy"
label var work_duty					"Work is a duty towards society"
label var workfirst					"Work should always come first even if it means less spare time"
label var cons_ref_rev				"Society: preserve low is revolution 			high is preserve"
label var fut_work_notless			"Future not less work"
label var fut_tech					"Future more technology"
label var fut_obey					"Future more authority"



label var happy						"Happiness"
label var health					"Health"
label var ext_loc_control			"External locus of control"
label var satlife					"Life satisfaction"
label var satfin					"Financial satisfaction"
label var econbad_food				"Last year: not enough food"
label var econbad_crime				"Last year: felt unsafe from crime"
label var econbad_med				"Last year: can't afford healthcare"
label var econbad_cash				"Last year: too little income"
label var econbad_home				"Last year: homeless"
label var econ_parents				"Financial, compared to parents"
label var trust						"Most people can be trusted"
label var trust_fam					"Trust family"
label var trust_nei					"Trust neighbors"
label var trust_know				"Trust people you know"
label var trust_meet				"Trust people you meet"
label var trust_rel					"Trust people of another religion"
label var trust_noncit				"Trust people from another country"
label var conf_church				"Confidence in churches"
label var conf_army					"Confidence in army"
label var conf_press				"Confidence in press"
label var conf_tv					"Confidence in television"
label var conf_unions				"Confidence in labor unions"
label var conf_police				"Confidence in police"
label var conf_courts				"Confidence in judicial system"
label var conf_gov					"Confidence in government"
label var conf_parties				"Confidence in political parties"
label var conf_parl					"Confidence in legislature"
label var conf_civil				"Confidence in civil service"
label var conf_univ					"Confidence in universities"
label var conf_elec					"Confidence in elections"
label var conf_bus					"Confidence in major companies"
label var conf_banks				"Confidence in banks"
label var conf_env					"Confidence in environmental movement"
label var conf_womens				"Confidence in women´s movement"
label var conf_charit				"Confidence in charities"
label var conf_reggov				"Confidence in state"



label var know_UN					"Knowledge: UN Security Council 3"
label var know_IMF					"Knowledge: headquarters of the IMF 1"
label var know_Amnesty				"Knowledge: Amnesty Int. 2"
label var mem_church				"Member of a church member"
label var mem_sport					"Sports, leisure member"
label var mem_art					"Member of a church"
label var mem_union					"Member of a union"
label var mem_party					"Member of a political party"
label var mem_env					"Member of an environmental group"
label var mem_prof					"Member of a professional org"
label var mem_charit				"Member of a charity"
label var mem_consumer				"Member of a consumer group"
label var mem_selfhelp				"Member of a self-help group"
label var mem_womens				"Member of a women's group"
label var mem_other					"Member of a different group"
label var val_incdif				"Incomes should be more equal"
label var val_privown				"Private vs state ownership of business"
label var val_ind					"Individual´s responsibility not government"
label var val_compet				"Competition good over harmful"
label var val_hardwork				"Success: hard work over luck"
label var val_env					"Protecting environment over economy"
label var corrupt					"Perceptions of corruption in the..."
label var corr_state				"Corrupt: State"
label var corr_bus					"Corrupt: Business"
label var corr_local				"Corrupt: Local				"
label var corr_civil				"Corrupt: Civil servants"
label var corr_journ				"Corrupt: Journalists"
label var bribe_freq				"Corrupt: ordinary people bribe"
label var bribe_account				"Risk of being caught for bribes"
label var imm_good					"Immigration: good overall"
label var imm_useful_jobs			"Immigrants take useful jobs"
label var imm_cult_div				"Immigrants bring cultural diversity"
label var imm_asylum				"Immigrants seeking asylum"
label var imm_poor					"Immigrants help reduce poverty"
label var imm_crime					"Immigrants bring crime"
label var imm_terror				"Immigrants bring terrorism"
label var imm_unemp					"Immigrants increase unemployment"
label var imm_conflict				"Immigrants bring conflict"
label var mig_sup					"Immigration for work: increased"
label var nei_sec					"Neighborhood security"
label var nei_rob					"Neighborhood: robberies"
label var nei_alc					"Neighborhood: drunks"
label var nei_police				"Neighborhood: police interfere"
label var nei_racist				"Neighborhood: racists"
label var nei_drugs					"Neighborhood: drugs"
label var nei_viol					"Neighborhood: violence"
label var nei_harass				"Neighborhood: harassment"
label var nei_cash					"To protect safety: not take cash"
label var nei_out					"To protect safety: not gone out at night"
label var nei_weap					"To protect safety: carry weapon"
label var worry_job					"Worries: Losing my job"
label var worry_kidseduc			"Worries: Kids education"
label var victim_self				"Last year: victim of crime"
label var victim_fam				"Last year: family victim of crime"
label var worry_war					"Worries: war"
label var worry_terror				"Worries: terrorism"
label var worry_civwar				"Worries: civil war"
label var val_free_equal			"Values freedom over equality"
label var val_free_sec				"Values freedom over security"
label var fight_country				"Willingness to fight for country"
label var valsci_life				"Science makes our lives better"
label var valsci_opp				"Science creates opportunities for future"
label var valsci_faith				"Not depend too much on science"
label var valsci_morals				"Science does not harm our sense of right and wrong"
label var valsci_know				"Important to know about science for daily life"
label var valsci_better				"Science makes world better off"
label var rel_godimp				"Importance of God"
label var rel_god					"Belief: God"
label var rel_life					"Belief: life after death"
label var rel_hell					"Belief: hell"
label var rel_heaven				"Belief: heaven"
label var rel_right					"Religion, not science, is always right"
label var rel_mine					"Only my religion is acceptable"
label var rel_attend				"Religious attendance"
label var rel_pray					"Prayer"
label var rel_pers					"Religious person"
label var rel_good					"Meaning of religion: do good to others more than ceremony"
label var rel_thislife				"Meaning of religion: this world more than after death"
label var morals_hard				"Moral rules confusing"
label var law_govben				"Not justifiable to illegally claim government benefits"
label var law_fare					"Not justifiable to illegally avoid a fare on public transport"
label var law_steal					"Not justifiable to illegally steal"
label var law_taxes					"Not justifiable to illegally cheat on taxes"
label var law_bribe					"Not justifiable to illegally accept a bribe"
label var morals_gay				"Moral: LGBTQ"
label var morals_prost				"Moral: prostitution"
label var morals_abor				"Moral: abortion"
label var morals_div				"Moral: divorce"
label var morals_sex				"Moral: sex before marriage"
label var morals_suic				"Moral: suicide"
label var morals_letdie				"Moral: euthanasia"
label var viol_beatwife				"Justifiable: a man to beat his wife"
label var viol_childs				"Justifiable: Parents beating children"
label var viol_other				"Justifiable: Violence against other people"
label var viol_terror				"Justifiable: Terrorism"
label var morals_casual				"Justifiable: casual sex"
label var viol_pol					"Justifiable: Political violence"
label var viol_death_pen			"Justifiable: Death penalty"
label var surv_video				"Government should not: video surveillance"
label var surv_email				"Government should not: monitor e-mails"
label var surv_allinfo				"Government should not: Collect information about people"
label var polint					"Interest in politics"
label var poltalk					"Discuss politics with friends"
label var news_paper				"News: newspaper"
label var news_tv					"News: TV			"
label var news_radio				"News: Radio news"
label var news_mobile				"News: Mobile phone"
label var news_email				"News: Email"
label var news_web					"News: Internet"
label var news_social				"News: social media			"
label var news_friends				"News: discussions"
label var polpart_pet				"Political action: Sign a petition"
label var polpart_boy				"Political action: join boycotts"
label var polpart_prot				"Political action: demonstrations"
label var polpart_strikes			"Political action: unofficial strikes"
label var polpart_donate			"Social activism: donations"
label var polpart_contact			"Social activism: contacting an official"
label var polpart_othact			"Social activism: encouraging others"
label var polpart_othvote			"Social activism: Encouraging others to vote"
label var polpart_socmed_search		"Politics online: searching information"
label var polpart_socmed_sign		"Politics online: electronic petition"
label var polpart_socmed_othact		"Politics online: encouraging others"
label var polpart_socmed_organize	"Politics online: Organizing"
label var vote_local				"Vote: local"
label var vote_nat					"Vote: National"
label var elec_votes				"Votes are counted fairly"
label var elec_oppno				"Opposition candidates are not prevented from running"
label var elec_press_incum			"TV news free from favoring the governing party"
label var elec_bribe				"Voters are not bribed"
label var elec_pressfair			"Journalists provide fair coverage"
label var elec_off					"Election officials are fair"
label var elec_rich					"Rich people buy elections"
label var elec_viol					"Voters are not threatened with violence at the polls"
label var elec_choice				"Voters are offered a genuine choice in the elections"
label var elec_fem					"Women have equal opportunities to run the office"
label var elec_say					"How much the political system allows people to have a say01"
label var honelec_matter			"Honest elections matter"
label var dem_strong				"Best not to have a strong leader"
label var dem_experts				"Best not to have experts rule"
label var dem_army					"Best not to have army rule"
label var dem_dem					"Best to have a democracy"
label var dem_rel					"Best not to have religious rule"
label var val_left					"Left ideology"
label var essdem_poor				"Democracy essential: tax the rich to help the poor"
label var essdem_rel				"Democracy essential is not: religious rule"
label var essdem_elec				"Democracy essential: free elections"
label var essdem_unemp				"Democracy essential: aid unemployment"
label var essdem_army				"Democracy essential is not: army takes over"
label var essdem_liberty			"Democracy essential: civil liberties and rights"
label var essdem_equal				"Democracy essential is not: equal incomes"
label var essdem_obey				"Democracy essential: people obey their rulers"
label var essdem_fem				"Democracy essential: women have the same rights as men"
label var demimp					"Importance of democracy"
label var howdem					"How democratic is this country"
label var polsat					"Satisfaction with the political system"
label var perc_rights				"Respect for individual human rights nowadays"
label var nat_pride					"National pride"











label var imp_family01				"Important: Family"
label var imp_friends01				"Important: Friends"
label var imp_leisure01				"Important: Leisure time"
label var imp_politics01			"Important: Politics"
label var imp_work01				"Important: Work"
label var imp_rel01					"Important:  Religion"
label var val_manners01				"Children: manners"
label var val_indep01				"Children: Independence"
label var val_work01				"Children: Hard work"
label var val_resp01				"Children: Responsibility"
label var val_imag01				"Children: Imagination"
label var val_tol01					"Children: Tolerant"
label var val_thrift01				"Children: thrifty"
label var val_determ01				"Children: perseverance"
label var val_rel01					"Children: religious"
label var val_unself01				"Children: Unselfish"
label var val_obey01				"Children: Obedience"
label var nei_addicts01				"Not want as neighbors: Drug addicts"
label var nei_race01				"Not want as neighbors: People of a different race"
label var nei_aids01				"Not want as neighbors: People who have AIDS"
label var nei_imm01					"Not want as neighbors: Immigrants / foreign workers"
label var nei_gay01					"Not want as neighbors: LGBTQ"
label var nei_reldif01				"Not want as neighbors: Different religion"
label var nei_drink01				"Not want as neighbors: Heavy drinkers"
label var nei_notmar01				"Not want as neighbors: Unmarried couples"
label var nei_langdif01				"Not want as neighbors: Different language"
label var par_proud01				"Main goal: make my parents proud"
label var notwork_lazy01			"People who don´t work turn lazy"
label var work_duty01				"Work is a duty towards society"
label var workfirst01				"Work should always come first even if it means less spare time"
label var cons_ref_rev01			"Society: preserve low is revolution 01			high is preserve"
label var fut_work_notless01		"Future not less work"
label var fut_tech01				"Future more technology"
label var fut_obey01				"Future more authority"



label var happy01					"Happiness"
label var health01					"Health"
label var ext_loc_control01			"External locus of control"
label var satlife01					"Life satisfaction"
label var satfin01					"Financial satisfaction"
label var econbad_food01			"Last year: not enough food"
label var econbad_crime01			"Last year: felt unsafe from crime"
label var econbad_med01				"Last year: can't afford healthcare"
label var econbad_cash01			"Last year: too little income"
label var econbad_home01			"Last year: homeless"
label var econ_parents01			"Financial, compared to parents"
label var trust01					"Most people can be trusted"
label var trust_fam01				"Trust family"
label var trust_nei01				"Trust neighbors"
label var trust_know01				"Trust people you know"
label var trust_meet01				"Trust people you meet"
label var trust_rel01				"Trust people of another religion"
label var trust_noncit01			"Trust people from another country"
label var conf_church01				"Confidence in churches"
label var conf_army01				"Confidence in army"
label var conf_press01				"Confidence in press"
label var conf_tv01					"Confidence in television"
label var conf_unions01				"Confidence in labor unions"
label var conf_police01				"Confidence in police"
label var conf_courts01				"Confidence in judicial system"
label var conf_gov01				"Confidence in government"
label var conf_parties01			"Confidence in political parties"
label var conf_parl01				"Confidence in legislature"
label var conf_civil01				"Confidence in civil service"
label var conf_univ01				"Confidence in universities"
label var conf_elec01				"Confidence in elections"
label var conf_bus01				"Confidence in major companies"
label var conf_banks01				"Confidence in banks"
label var conf_env01				"Confidence in environmental movement"
label var conf_womens01				"Confidence in women´s movement"
label var conf_charit01				"Confidence in charities"
label var conf_reggov01				"Confidence in state"



label var know_UN01					"Knowledge: UN Security Council 3"
label var know_IMF01				"Knowledge: headquarters of the IMF 1"
label var know_Amnesty01			"Knowledge: Amnesty Int. 2"
label var mem_church01				"Member of a church member"
label var mem_sport01				"Sports, leisure member"
label var mem_art01					"Member of a church"
label var mem_union01				"Member of a union"
label var mem_party01				"Member of a political party"
label var mem_env01					"Member of an environmental group"
label var mem_prof01				"Member of a professional org"
label var mem_charit01				"Member of a charity"
label var mem_consumer01			"Member of a consumer group"
label var mem_selfhelp01			"Member of a self-help group"
label var mem_womens01				"Member of a women's group"
label var mem_other01				"Member of a different group"
label var val_incdif01				"Incomes should be more equal"
label var val_privown01				"Private vs state ownership of business"
label var val_ind01					"Individual´s responsibility not government"
label var val_compet01				"Competition good over harmful"
label var val_hardwork01			"Success: hard work over luck"
label var val_env01					"Protecting environment over economy"
label var corrupt01					"Perceptions of corruption in the..."
label var corr_state01				"Corrupt: State"
label var corr_bus01				"Corrupt: Business"
label var corr_local01				"Corrupt: Local01			"
label var corr_civil01				"Corrupt: Civil servants"
label var corr_journ01				"Corrupt: Journalists"
label var bribe_freq01				"Corrupt: ordinary people bribe"
label var bribe_account01			"Risk of being caught for bribes"
label var imm_good01				"Immigration: good overall"
label var imm_useful_jobs01			"Immigrants take useful jobs"
label var imm_cult_div01			"Immigrants bring cultural diversity"
label var imm_asylum01				"Immigrants seeking asylum"
label var imm_poor01				"Immigrants help reduce poverty"
label var imm_crime01				"Immigrants bring crime"
label var imm_terror01				"Immigrants bring terrorism"
label var imm_unemp01				"Immigrants increase unemployment"
label var imm_conflict01			"Immigrants bring conflict"
label var mig_sup01					"Immigration for work: increased"
label var nei_sec01					"Neighborhood security"
label var nei_rob01					"Neighborhood: robberies"
label var nei_alc01					"Neighborhood: drunks"
label var nei_police01				"Neighborhood: police interfere"
label var nei_racist01				"Neighborhood: racists"
label var nei_drugs01				"Neighborhood: drugs"
label var nei_viol01				"Neighborhood: violence"
label var nei_harass01				"Neighborhood: harassment"
label var nei_cash01				"To protect safety: not take cash"
label var nei_out01					"To protect safety: not gone out at night"
label var nei_weap01				"To protect safety: carry weapon"
label var worry_job01				"Worries: Losing my job"
label var worry_kidseduc01			"Worries: Kids education"
label var victim_self01				"Last year: victim of crime"
label var victim_fam01				"Last year: family victim of crime"
label var worry_war01				"Worries: war"
label var worry_terror01			"Worries: terrorism"
label var worry_civwar01			"Worries: civil war"
label var val_free_equal01			"Values freedom over equality"
label var val_free_sec01			"Values freedom over security"
label var fight_country01			"Willingness to fight for country"
label var valsci_life01				"Science makes our lives better"
label var valsci_opp01				"Science creates opportunities for future"
label var valsci_faith01			"Not depend too much on science"
label var valsci_morals01			"Science does not harm our sense of right and wrong"
label var valsci_know01				"Important to know about science for daily life"
label var valsci_better01			"Science makes world better off"
label var rel_godimp01				"Importance of God"
label var rel_god01					"Belief: God"
label var rel_life01				"Belief: life after death"
label var rel_hell01				"Belief: hell"
label var rel_heaven01				"Belief: heaven"
label var rel_right01				"Religion, not science, is always right"
label var rel_mine01				"Only my religion is acceptable"
label var rel_attend01				"Religious attendance"
label var rel_pray01				"Prayer"
label var rel_pers01				"Religious person"
label var rel_good01				"Meaning of religion: do good to others more than ceremony"
label var rel_thislife01			"Meaning of religion: this world more than after death"
label var morals_hard01				"Moral rules confusing"
label var law_govben01				"Not justifiable to illegally claim government benefits"
label var law_fare01				"Not justifiable to illegally avoid a fare on public transport"
label var law_steal01				"Not justifiable to illegally steal"
label var law_taxes01				"Not justifiable to illegally cheat on taxes"
label var law_bribe01				"Not justifiable to illegally accept a bribe"
label var morals_gay01				"Moral: LGBTQ"
label var morals_prost01			"Moral: prostitution"
label var morals_abor01				"Moral: abortion"
label var morals_div01				"Moral: divorce"
label var morals_sex01				"Moral: sex before marriage"
label var morals_suic01				"Moral: suicide"
label var morals_letdie01			"Moral: euthanasia"
label var viol_beatwife01			"Justifiable: a man to beat his wife"
label var viol_childs01				"Justifiable: Parents beating children"
label var viol_other01				"Justifiable: Violence against other people"
label var viol_terror01				"Justifiable: Terrorism"
label var morals_casual01			"Justifiable: casual sex"
label var viol_pol01				"Justifiable: Political violence"
label var viol_death_pen01			"Justifiable: Death penalty"
label var surv_video01				"Government should not: video surveillance"
label var surv_email01				"Government should not: monitor e-mails"
label var surv_allinfo01			"Government should not: Collect information about people"
label var polint01					"Interest in politics"
label var poltalk01					"Discuss politics with friends"
label var news_paper01				"News: newspaper"
label var news_tv01					"News: TV01			"
label var news_radio01				"News: Radio news"
label var news_mobile01				"News: Mobile phone"
label var news_email01				"News: Email"
label var news_web01				"News: Internet"
label var news_social01				"News: social media01			"
label var news_friends01			"News: discussions"
label var polpart_pet01				"Political action: Sign a petition"
label var polpart_boy01				"Political action: join boycotts"
label var polpart_prot01			"Political action: demonstrations"
label var polpart_strikes01			"Political action: unofficial strikes"
label var polpart_donate01			"Social activism: donations"
label var polpart_contact01			"Social activism: contacting an official"
label var polpart_othact01			"Social activism: encouraging others"
label var polpart_othvote01			"Social activism: Encouraging others to vote"
label var polpart_socmed_search01	"Politics online: searching information"
label var polpart_socmed_sign01		"Politics online: electronic petition"
label var polpart_socmed_othact01	"Politics online: encouraging others"
label var polpart_socmed_organize01	"Politics online: Organizing"
label var vote_local01				"Vote: local"
label var vote_nat01				"Vote: National"
label var elec_votes01				"Votes are counted fairly"
label var elec_oppno01				"Opposition candidates are not prevented from running"
label var elec_press_incum01		"TV news free from favoring the governing party"
label var elec_bribe01				"Voters are not bribed"
label var elec_pressfair01			"Journalists provide fair coverage"
label var elec_off01				"Election officials are fair"
label var elec_rich01				"Rich people buy elections"
label var elec_viol01				"Voters are not threatened with violence at the polls"
label var elec_choice01				"Voters are offered a genuine choice in the elections"
label var elec_fem01				"Women have equal opportunities to run the office"
label var elec_say01				"How much the political system allows people to have a say01"
label var honelec_matter01			"Honest elections matter"
label var dem_strong01				"Best not to have a strong leader"
label var dem_experts01				"Best not to have experts rule"
label var dem_army01				"Best not to have army rule"
label var dem_dem01					"Best to have a democracy"
label var dem_rel01					"Best not to have religious rule"
label var val_left01				"Left ideology"
label var essdem_poor01				"Democracy essential: tax the rich to help the poor"
label var essdem_rel01				"Democracy essential is not: religious rule"
label var essdem_elec01				"Democracy essential: free elections"
label var essdem_unemp01			"Democracy essential: aid unemployment"
label var essdem_army01				"Democracy essential is not: army takes over"
label var essdem_liberty01			"Democracy essential: civil liberties and rights"
label var essdem_equal01			"Democracy essential is not: equal incomes"
label var essdem_obey01				"Democracy essential: people obey their rulers"
label var essdem_fem01				"Democracy essential: women have the same rights as men"
label var demimp01					"Importance of democracy"
label var howdem01					"How democratic is this country"
label var polsat01					"Satisfaction with the political system"
label var perc_rights01				"Respect for individual human rights nowadays"
label var nat_pride01				"National pride"













note imp_family: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Family
note imp_friends: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Friends
note imp_leisure: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Leisure time
note imp_politics: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Politics
note imp_work: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Work
note imp_rel: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Religion
note val_manners: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Good manners
note val_indep: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Independence
note val_work: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Hard work
note val_resp: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Feeling of responsibility
note val_imag: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Imagination
note val_tol: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Tolerance and respect for other people
note val_thrift: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Thrift saving money and things
note val_determ: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Determination, perseverance
note val_rel: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Religious faith
note val_unself: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Not being selfish (unselfishness)
note val_obey: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Obedience
note nei_addicts: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? - Drug addicts
note nei_race: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? - People of a different race
note nei_aids: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – People who have AIDS
note nei_imm: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – Immigrants/foreign workers
note nei_gay: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – Homosexuals
note nei_reldif: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – People of a different religion
note nei_drink: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? Heavy drinkers
note nei_notmar: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – Unmarried couples living together
note nei_langdif: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? - People who speak a different language
note par_proud: For each of the following statements I read out, can you tell me how much you agree with each. Do you agree strongly, agree, disagree, or disagree strongly? - One of my main goals in life has been to make my parents proud
note notwork_lazy: Do you agree or disagree with the following statements? - People who don't work turn lazy
note work_duty: Do you agree or disagree with the following statements? – Work is a duty towards society
note workfirst: Do you agree or disagree with the following statements? – Work should always come first, even if it means less spare time
note cons_ref_rev: On this card are three basic kinds of attitudes concerning the society we live in. Please choose the one which best describes your own opinion. 1 The entire way our society is organized must be radically changed by revolutionary action, 2 Our society must be gradually improved by reforms 3 Our present society must be valiantly defended against all subversive forces
note fut_work_notless: I'm going to read out a list of various changes in our way of life that might take place in the near future. Please tell me for each one, if it were to happen, whether you think it would be a good thing, a bad thing, or don't you mind? –Less importance placed on work in our lives
note fut_tech: I'm going to read out a list of various changes in our way of life that might take place in the near future. Please tell me for each one, if it were to happen, whether you think it would be a good thing, a bad thing, or don't you mind? –More emphasis on the development of technology
note fut_obey: I'm going to read out a list of various changes in our way of life that might take place in the near future. Please tell me for each one, if it were to happen, whether you think it would be a good thing, a bad thing, or don't you mind? –Greater respect for authority
note happy: Taking all things together, would you say you are 1 Very happy 2 Rather happy 3 Not very happy 4 Not at all happy
note health: All in all, how would you describe your state of health these days? Would you say it is... 1 Very good 2 Good 3 Fair 4 Poor 5 Very poor
note ext_loc_control: Some people feel they have completely free choice and control over their lives, while other people feel that what they do has no real effect on what happens to them. Please use this scale where 1 means 'none at all' and 10 means 'a great deal' to indicate how much freedom of choice and control you feel you have over the way your life turns out.
note satlife: All things considered, how satisfied are you with your life as a whole these days?
note satfin: How satisfied are you with the financial situation of your household? If '1' means you are completely dissatisfied on this scale, and '10' means you are completely satisfied, where would you put your satisfaction with your household's financial situation?
note econbad_food: In the last 12 months, how often have you or your family - Gone without enough food to eat
note econbad_crime: In the last 12 months, how often have you or your family - Felt unsafe from crime in your own home
note econbad_med: In the last 12 months, how often have you or your family - Gone without needed medicine or treatment that you needed
note econbad_cash: In the last 12 months, how often have you or your family - Gone without a cash income
note econbad_home: In the last 12 months, how often have you or your family - Gone without a safe shelter over your head
note econ_parents: Comparing your standard of living with your parents' standard of living when they were about your age, would you say that you are better off, worse off or about the same?
note trust: Generally speaking, would you say that most people can be trusted or that you need to be very careful in dealing with people?
note trust_fam: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? Your family
note trust_nei: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? Your neighborhood
note trust_know: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People you know personally
note trust_meet: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People you meet for the first time
note trust_rel: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People of another religion
note trust_noncit: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People of another nationality
note conf_church: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The Churches (mosque, temple etc.)
note conf_army: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The armed forces
note conf_press: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The press
note conf_tv: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Television
note conf_unions: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Labour Unions
note conf_police: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The police
note conf_courts: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The courts
note conf_gov: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The government (in your nation's capital)
note conf_parties: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Political Parties
note conf_parl: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Parliament
note conf_civil: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The Civil Services
note conf_univ: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Universities
note conf_elec: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Elections
note conf_bus: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Major Companies
note conf_banks: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Banks
note conf_env: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Environmental organizations
note conf_womens: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Women´s organizations
note conf_charit: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Charitable or humanitarian organizations
note conf_reggov: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? <major regional organization>
note know_UN: Here are some questions about international organizations. Many people don't know the answers to these questions, but if you do please tell me. Five countries have permanent seats on the Security Council of the United Nations. Which ones of the following is not a member?
note know_IMF: Here are some questions about international organizations. Many people don't know the answers to these questions, but if you do please tell me. Where are the headquarters of the International Monetary Fund (IMF)located?
note know_Amnesty: Here are some questions about international organizations. Many people don't know the answers to these questions, but if you do please tell me. Which of the following problems does the organization Amnesty International deal with?
note mem_church: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Church or religious organization

note mem_sport: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Sport or recreational organization, football/baseball/rugby team
note mem_art: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Art, music or educational organization
note mem_union: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Labour Union
note mem_party: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Political party
note mem_env: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Environmental organization
note mem_prof: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Professional association
note mem_charit: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Humanitarian or charitable organization
note mem_consumer: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Consumer organization
note mem_selfhelp: Now I am going to read off a list of voluntary organizations. For each organization, could you tell me whether you are an active member, an inactive member or not a member of that type of organization? Self-help group, mutual aid group
note mem_womens: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Women's group
note mem_other: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Other organization
note val_incdif: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. 'Incomes should be made more equal' versus 'There should be greater incentives for individual effort'
note val_privown: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. Private ownership of business and industry should be increased' versus 'Government ownership of business and industry should be increased'
note val_ind: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. 'Government should take more responsibility to ensure that everyone is provided for' versus 'People should take more responsibility to provide for themselves'
note val_compet: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. 'Competition is good for' versus 'Competition is harmful' 
note val_hardwork: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can chose any number in between. 'In the long run, hard work usually brings a better life' versus 'Hard work doesn't generally bring success—it's more a matter of luck and connections'
note val_env: Here are two statements people sometimes make when discussing the environment and economic growth. Which of them comes closer to your own point of view? A. Protecting the environment should be given priority, even if it causes slower economic growth and some loss of jobs B. Economic growth and creating jobs should be the top priority, even if the environment suffers to some extent
note corrupt: Now I'd like you to tell me your views on corruption – when people pay a bribe, give a gift or do a favor to other people in order to get the things they need done or the services they need. How would you place your views on corruption in your country on a 10-point scale where '1' means 'there is no corruption in this country' and '10' means 'there is abundant corruption in this country'. If your views are somewhat mixed, choose the appropriate number in between.
note corr_state: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? State authorities
note corr_bus: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Business executives
note corr_local: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Local authorities
note corr_civil: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Civil service providers (police, judiciary, civil servants, doctors, teachers)
note corr_journ: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Journalists and media
note bribe_freq: We want to know about your experience with local officials and service providers, like police officers, lawyers, doctors, teachers and civil servants in your community. How often do you think ordinary people like yourself or people from your neighborhood have to pay a bribe, give a gift or do a favor to these people in order to get the services you need? Does it happen never, rarely, frequently or always?
note bribe_account: How high is the risk in this country to be held accountable for giving or receiving a bribe, gift or favour in return for public service? To indicate your opinion, use a 10- point scale where'1' means 'no risk at all' and'10' means 'very high risk'.
note imm_good: Now we would like to know your opinion about the people from other countries who come to live in this country - the immigrants. How would you evaluate the impact of these people on the development of this country?
note imm_useful_jobs: From your point of view, what have been the effects of immigrants on the development of this country? - Fill useful jobs in the workforce
note imm_cult_div: From your point of view, what have been the effects of immigrants on the development of this country? - Strengthen cultural diversity
note imm_asylum: From your point of view, what have been the effects of immigrants on the development of this country? - Give asylum to political refugees
note imm_poor: From your point of view, what have been the effects of immigrants on the development of this country? Help poor people establish new lives
note imm_crime: From your point of view, what have been the effects of immigrants on the development of this country? - Increase the crime rate
note imm_terror: From your point of view, what have been the effects of immigrants on the development of this country? - Increase the risks of terrorism
note imm_unemp: From your point of view, what have been the effects of immigrants on the development of this country? Increase unemployment
note imm_conflict: From your point of view, what have been the effects of immigrants on the development of this country? Lead to social conflict
note mig_sup: How about people from other countries coming here to work. Which one of the following do you think the government should do? 1. Let anyone come who wants to 2. Let people come as long as there are jobs available 3. Place strict limits on the number of foreigners who can come here 4. Prohibit people coming here from other countries
note nei_sec: Could you tell me how secure do you feel these days in your neighborhood?
note nei_rob: How frequently do the following things occur in your neighborhood? Robberies
note nei_alc: How frequently do the following things occur in your neighborhood? Alcohol consumed in the streets
note nei_police: How frequently do the following things occur in your neighborhood? Police or military interfere with people's private life
note nei_racist: How frequently do the following things occur in your neighborhood? Racist behavior
note nei_drugs: How frequently do the following things occur in your neighborhood? Drug sale in streets
note nei_viol: How frequently do the following things occur in your neighborhood? Street violence and fights
note nei_harass: How frequently do the following things occur in your neighborhood? Sexual harassment
note nei_cash: Which of the following things have you done for reasons of security? Didn't carry much money
note nei_out: Which of the following things have you done for reasons of security? Preferred not to go out at night
note nei_weap: Which of the following things have you done for reasons of security? Carried a knife, gun or other weapon
note worry_job: To what degree are you worried about the following situations? Losing my job or not finding a job
note worry_kidseduc: To what degree are you worried about the following situations? Not being able to give one's children a good education
note victim_self: Have you been the victim of a crime during the past year?
note victim_fam: And what about your immediate family--has someone in your family been the victim of a crime during the last year?
note worry_war: To what degree are you worried about the following situations? A war involving my country
note worry_terror: To what degree are you worried about the following situations? A terrorist attack
note worry_civwar: To what degree are you worried about the following situations? A civil war
note val_free_equal: Most people consider both freedom and equality to be important, but if you had to choose between them, which one would you consider more important?
note val_free_sec: Most people consider both freedom and security to be important, but if you had to choose between them, which one would you consider more important?
note fight_country: Of course, we all hope that there will not be another war, but if it were to come to that, would you be willing to fight for your country?
note valsci_life: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree.' Science and technology are making our lives healthier, easier, and more comfortable
note valsci_opp: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree.' Because of science and technology, there will be more opportunities for the next generation
note valsci_faith: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree.' We depend too much on science and not enough on faith
note valsci_morals: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree' - One of the bad effects of science is that it breaks down people's ideas of right and wrong 
note valsci_know: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree' - It is not important for me to know about science in my daily life 
note valsci_better: All things considered, would you say that the world is better off, or worse off, because of science and technology? Please tell me which comes closest to your view on this scale - 1 means that 'the world is a lot worse off,' and 10 means that ''the world is a lot better off.' The world is better off, or worse off, because of science and technology
note rel_godimp: How important is God in your life?. Please use this scale to indicate. 10 means 'very important' and 1 means 'not at all important'.
note rel_god: In which of the following things do you believe, if you believe in any? - God
note rel_life: In which of the following things do you believe, if you believe in any? - Life after death
note rel_hell: In which of the following things do you believe, if you believe in any? - Hell
note rel_heaven: In which of the following things do you believe, if you believe in any? - Heaven
note rel_right: Please tell us if you strongly agree, agree, disagree, or strongly disagree with the following statements - Whenever science and religion conflict, religion is always right
note rel_mine: Please tell us if you strongly agree, agree, disagree, or strongly disagree with the following statements - The only acceptable religion is my religion
note rel_attend: Apart from weddings, funerals and christenings, about how often do you attend religious services these days?
note rel_pray: Apart from weddings and funerals, about how often do you pray?
note rel_pers: Independently of whether you go to church or not, would you say you are…
note rel_good: With which one of the following statements do you agree most? The meaning of religion is…
note rel_thislife: And with which of the following statements do you agree most? The meaning of religion is…
note morals_hard: How much do you agree or disagree with the statement that nowadays one often has trouble deciding which moral rules are the right ones to follow?
note law_govben: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between -  - Claiming government benefits to which you are not entitled
note law_fare: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - - Avoiding a fare on public transport 
note law_steal: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Stealing property
note law_taxes: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Cheating on taxes if you have a chance
note law_bribe: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Someone accepting a bribe in the course of their duties
note morals_gay: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Homosexuality
note morals_prost: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Prostitution
note morals_abor: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Abortion
note morals_div: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Divorce
note morals_sex: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Sex before marriage
note morals_suic: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Suicide
note morals_letdie: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Euthanasia
note viol_beatwife: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - For a man to beat his wife
note viol_childs: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Parents beating children
note viol_other: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Violence against other people
note viol_terror: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Terrorism as a political, ideological or religious mean
note morals_casual: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Having casual sex
note viol_pol: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between -  Political violence
note viol_death_pen: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between -  Death penalty
note surv_video: Do you think this country's government should or should not have the right to do the following - Keep people under video surveillance in public areas
note surv_email: Do you think this country's government should or should not have the right to do the following - Monitor all emails and any other information exchanged on the Internet
note surv_allinfo: Do you think that this country's government should or should not have the right to do the following - Collect information about anyone living in this country without their knowledge
note polint: How interested would you say you are in politics?
note poltalk: When you get together with your friends, would you say you discuss political matters frequently, occasionally or never?
note news_paper: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Daily newspaper
note news_tv: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - TV news
note news_radio: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Radio news
note news_mobile: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Mobile phone
note news_email: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Email
note news_web: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Internet
note news_social: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Social media (Facebook, Twitter, etc.)
note news_friends: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Talk with friends or colleagues
note polpart_pet: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Signing a petition
note polpart_boy: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Joining in boycotts
note polpart_prot: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Attending peaceful demonstrations
note polpart_strikes: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Joining strikes
note polpart_donate: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Donating to a group or campaign
note polpart_contact: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Contacting a government official
note polpart_othact: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Encouraging others to take action about political issues
note polpart_othvote: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Encouraging others to vote
note polpart_socmed_search: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it-Searching information about politics and political events
note polpart_socmed_sign: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it-Signing an electronic petition
note polpart_socmed_othact: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it - Encouraging other people to take any form of political action
note polpart_socmed_organize: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it-Organizing political activities, events, protests
note vote_local: Vote in elections - Local level
note vote_nat: Vote in elections - National level
note elec_votes: In your view, how often do the following things occur in this country's elections? Votes are counted fairly
note elec_oppno: In your view, how often do the following things occur in this country's elections? Opposition candidates are prevented from running
note elec_press_incum: In your view, how often do the following things occur in this country's elections? TV news favors the governing party
note elec_bribe: In your view, how often do the following things occur in this country's elections? Voters are bribed
note elec_pressfair: In your view, how often do the following things occur in this country's elections? Journalists provide fair coverage of elections
note elec_off: In your view, how often do the following things occur in this country's elections? Election officials are fair
note elec_rich: In your view, how often do the following things occur in this country's elections? Rich people buy elections
note elec_viol: In your view, how often do the following things occur in this country's elections? Voters are threatened with violence at the polls
note elec_choice: In your view, how often do the following things occur in this country's elections? Voters are offered a genuine choice in the elections
note elec_fem: In your view, how often do the following things occur in this country's elections? - Women have equal opportunities to run the office
note elec_say: Do you think that honest elections play an important role in deciding whether you and your family are able to make a good living? How important would you say this is—very important, fairly important, not very important or not at all important?
note honelec_matter: How much would you say the political system in your country allows people like you to have a say in what the government does?
note dem_strong: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having a strong leader who does not have to bother with parliament and elections
note dem_experts: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having experts, not government, make decisions according to what they think is best for the country
note dem_army: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having the army rule
note dem_dem: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having a democratic political system
note dem_rel: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having a system governed by religious law in which there are no political parties or elections
note val_left: In political matters, people talk of 'the left' and 'the right.' How would you place your views on this scale, generally speaking?
note essdem_poor: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - Governments tax the rich and subsidize the poor
note essdem_rel: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - Religious authorities interpret the laws
note essdem_elec: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - People choose their leaders in free elections
note essdem_unemp: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - People receive state aid for unemployment
note essdem_army: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - The army takes over when government is incompetent
note essdem_liberty: Please tell me for each of the following things how essential you think it is as a characteristic of democracy. - Civil rights protect people's liberty from state oppression
note essdem_equal: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - The state makes people´s incomes equal
note essdem_obey: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - People obey their rulers
note essdem_fem: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - Women have the same rights as men
note demimp: How important is it for you to live in a country that is governed democratically? On this scale where 1 means it is 'not at all important' and 10 means 'absolutely important' what position would you choose?
note howdem: And how democratically is this country being governed today?. Again using a scale from 1 to 10, where 1 means that it is 'not at all democratic' and 10 means that it is 'completely democratic," what position would you choose?
note polsat: How satisfied are you with how the political system is functioning in your country these days? On the scale from 1 to 10 below, 1 means not satisfied at all and 10 means completely satisfied.
note perc_rights: How much respect is there for individual human rights nowadays in this country?
note nat_pride: How proud are you to be of nationality of this country?
note close_local: People have different views about themselves and how they relate to the world. Using this card, would you tell me how close do you feel to…? Your village, town or city
note seeself_local: People have different views about themselves and how they relate to the world. Using this card, would you tell me how strongly you agree or disagree with each of the following statements about how you see yourself? Your county, region, district
note seeself_reg: People have different views about themselves and how they relate to the world. Using this card, would you tell me how strongly you agree or disagree with each of the following statements about how you see yourself? Country
note close_cont: People have different views about themselves and how they relate to the world. Using this card, would you tell me how close do you feel to…? Continent; e.g. Europe, Asia etc.
note close_world: People have different views about themselves and how they relate to the world. Using this card, would you tell me how strongly you agree or disagree with each of the following statements about how you see yourself? World





note imp_family01: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Family
note imp_friends01: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Friends
note imp_leisure01: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Leisure time
note imp_politics01: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Politics
note imp_work01: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Work
note imp_rel01: For each of the following aspects, indicate how important it is in your life. Would you say it is very important, rather important, not very important or not important at all? – Religion
note val_manners01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Good manners
note val_indep01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Independence
note val_work01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Hard work
note val_resp01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Feeling of responsibility
note val_imag01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Imagination
note val_tol01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Tolerance and respect for other people
note val_thrift01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Thrift saving money and things
note val_determ01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. – Determination, perseverance
note val_rel01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Religious faith
note val_unself01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Not being selfish (unselfishness)
note val_obey01: Here is a list of qualities that children can be encouraged to learn at home. Which, if any, do you consider to be especially important? Please choose up to five. –Obedience
note nei_addicts01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? - Drug addicts
note nei_race01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? - People of a different race
note nei_aids01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – People who have AIDS
note nei_imm01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – Immigrants/foreign workers
note nei_gay01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – Homosexuals
note nei_reldif01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – People of a different religion
note nei_drink01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? Heavy drinkers
note nei_notmar01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? – Unmarried couples living together
note nei_langdif01: On this list are various groups of people. Could you please mention any that you would not like to have as neighbors? - People who speak a different language
note par_proud01: For each of the following statements I read out, can you tell me how much you agree with each. Do you agree strongly, agree, disagree, or disagree strongly? - One of my main goals in life has been to make my parents proud
note notwork_lazy01: Do you agree or disagree with the following statements? - People who don't work turn lazy
note work_duty01: Do you agree or disagree with the following statements? – Work is a duty towards society
note workfirst01: Do you agree or disagree with the following statements? – Work should always come first, even if it means less spare time
note cons_ref_rev01: On this card are three basic kinds of attitudes concerning the society we live in. Please choose the one which best describes your own opinion. 1 The entire way our society is organized must be radically changed by revolutionary action, 2 Our society must be gradually improved by reforms 3 Our present society must be valiantly defended against all subversive forces
note fut_work_notless01: I'm going to read out a list of various changes in our way of life that might take place in the near future. Please tell me for each one, if it were to happen, whether you think it would be a good thing, a bad thing, or don't you mind? –Less importance placed on work in our lives
note fut_tech01: I'm going to read out a list of various changes in our way of life that might take place in the near future. Please tell me for each one, if it were to happen, whether you think it would be a good thing, a bad thing, or don't you mind? –More emphasis on the development of technology
note fut_obey01: I'm going to read out a list of various changes in our way of life that might take place in the near future. Please tell me for each one, if it were to happen, whether you think it would be a good thing, a bad thing, or don't you mind? –Greater respect for authority
note happy01: Taking all things together, would you say you are 1 Very happy 2 Rather happy 3 Not very happy 4 Not at all happy
note health01: All in all, how would you describe your state of health these days? Would you say it is... 1 Very good 2 Good 3 Fair 4 Poor 5 Very poor
note ext_loc_control01: Some people feel they have completely free choice and control over their lives, while other people feel that what they do has no real effect on what happens to them. Please use this scale where 1 means 'none at all' and 10 means 'a great deal' to indicate how much freedom of choice and control you feel you have over the way your life turns out.
note satlife01: All things considered, how satisfied are you with your life as a whole these days?
note satfin01: How satisfied are you with the financial situation of your household? If '1' means you are completely dissatisfied on this scale, and '10' means you are completely satisfied, where would you put your satisfaction with your household's financial situation?
note econbad_food01: In the last 12 months, how often have you or your family - Gone without enough food to eat
note econbad_crime01: In the last 12 months, how often have you or your family - Felt unsafe from crime in your own home
note econbad_med01: In the last 12 months, how often have you or your family - Gone without needed medicine or treatment that you needed
note econbad_cash01: In the last 12 months, how often have you or your family - Gone without a cash income
note econbad_home01: In the last 12 months, how often have you or your family - Gone without a safe shelter over your head
note econ_parents01: Comparing your standard of living with your parents' standard of living when they were about your age, would you say that you are better off, worse off or about the same?
note trust01: Generally speaking, would you say that most people can be trusted or that you need to be very careful in dealing with people?
note trust_fam01: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? Your family
note trust_nei01: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? Your neighborhood
note trust_know01: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People you know personally
note trust_meet01: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People you meet for the first time
note trust_rel01: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People of another religion
note trust_noncit01: I'd like to ask you how much you trust people from various groups. Could you tell me for each whether you trust people from this group completely, somewhat, not very much or not at all? People of another nationality
note conf_church01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The Churches (mosque, temple etc.)
note conf_army01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The armed forces
note conf_press01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The press
note conf_tv01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Television
note conf_unions01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Labour Unions
note conf_police01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The police
note conf_courts01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The courts
note conf_gov01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The government (in your nation's capital)
note conf_parties01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Political Parties
note conf_parl01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Parliament
note conf_civil01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? The Civil Services
note conf_univ01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Universities
note conf_elec01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Elections
note conf_bus01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Major Companies
note conf_banks01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Banks
note conf_env01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Environmental organizations
note conf_womens01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Women´s organizations
note conf_charit01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? Charitable or humanitarian organizations
note conf_reggov01: I am going to name a number of organizations. For each one, could you tell me how much confidence you have in them - is it a great deal of confidence, quite a lot of confidence, not very much confidence or none at all? <major regional organization>
note know_UN01: Here are some questions about international organizations. Many people don't know the answers to these questions, but if you do please tell me. Five countries have permanent seats on the Security Council of the United Nations. Which ones of the following is not a member?
note know_IMF01: Here are some questions about international organizations. Many people don't know the answers to these questions, but if you do please tell me. Where are the headquarters of the International Monetary Fund (IMF)located?
note know_Amnesty01: Here are some questions about international organizations. Many people don't know the answers to these questions, but if you do please tell me. Which of the following problems does the organization Amnesty International deal with?
note mem_church01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Church or religious organization

note mem_sport01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Sport or recreational organization, football/baseball/rugby team
note mem_art01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Art, music or educational organization
note mem_union01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Labour Union
note mem_party01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Political party
note mem_env01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Environmental organization
note mem_prof01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Professional association
note mem_charit01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Humanitarian or charitable organization
note mem_consumer01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Consumer organization
note mem_selfhelp01: Now I am going to read off a list of voluntary organizations. For each organization, could you tell me whether you are an active member, an inactive member or not a member of that type of organization? Self-help group, mutual aid group
note mem_womens01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Women's group
note mem_other01: Now I am going to read out a list of voluntary organizations; for each one, could you tell me whether you are a member, an active member, an inactive member or not a member of that type of organization? Other organization
note val_incdif01: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. 'Incomes should be made more equal' versus 'There should be greater incentives for individual effort'
note val_privown01: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. Private ownership of business and industry should be increased' versus 'Government ownership of business and industry should be increased'
note val_ind01: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. 'Government should take more responsibility to ensure that everyone is provided for' versus 'People should take more responsibility to provide for themselves'
note val_compet01: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can choose any number in between. 'Competition is good for' versus 'Competition is harmful' 
note val_hardwork01: Now I'd like you to tell me your views on various issues. How would you place your views on this scale? 1 means you agree completely with the statement on the left; 10 means you agree completely with the statement on the right; and if your views fall somewhere in between, you can chose any number in between. 'In the long run, hard work usually brings a better life' versus 'Hard work doesn't generally bring success—it's more a matter of luck and connections'
note val_env01: Here are two statements people sometimes make when discussing the environment and economic growth. Which of them comes closer to your own point of view? A. Protecting the environment should be given priority, even if it causes slower economic growth and some loss of jobs B. Economic growth and creating jobs should be the top priority, even if the environment suffers to some extent
note corrupt01: Now I'd like you to tell me your views on corruption – when people pay a bribe, give a gift or do a favor to other people in order to get the things they need done or the services they need. How would you place your views on corruption in your country on a 10-point scale where '1' means 'there is no corruption in this country' and '10' means 'there is abundant corruption in this country'. If your views are somewhat mixed, choose the appropriate number in between.
note corr_state01: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? State authorities
note corr_bus01: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Business executives
note corr_local01: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Local authorities
note corr_civil01: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Civil service providers (police, judiciary, civil servants, doctors, teachers)
note corr_journ01: Among the following groups of people, how many do you believe are involved in corruption? Tell me for each group if you believe it is none of them, few of them, most of them or all of them? Journalists and media
note bribe_freq01: We want to know about your experience with local officials and service providers, like police officers, lawyers, doctors, teachers and civil servants in your community. How often do you think ordinary people like yourself or people from your neighborhood have to pay a bribe, give a gift or do a favor to these people in order to get the services you need? Does it happen never, rarely, frequently or always?
note bribe_account01: How high is the risk in this country to be held accountable for giving or receiving a bribe, gift or favour in return for public service? To indicate your opinion, use a 10- point scale where'1' means 'no risk at all' and'10' means 'very high risk'.
note imm_good01: Now we would like to know your opinion about the people from other countries who come to live in this country - the immigrants. How would you evaluate the impact of these people on the development of this country?
note imm_useful_jobs01: From your point of view, what have been the effects of immigrants on the development of this country? - Fill useful jobs in the workforce
note imm_cult_div01: From your point of view, what have been the effects of immigrants on the development of this country? - Strengthen cultural diversity
note imm_asylum01: From your point of view, what have been the effects of immigrants on the development of this country? - Give asylum to political refugees
note imm_poor01: From your point of view, what have been the effects of immigrants on the development of this country? Help poor people establish new lives
note imm_crime01: From your point of view, what have been the effects of immigrants on the development of this country? - Increase the crime rate
note imm_terror01: From your point of view, what have been the effects of immigrants on the development of this country? - Increase the risks of terrorism
note imm_unemp01: From your point of view, what have been the effects of immigrants on the development of this country? Increase unemployment
note imm_conflict01: From your point of view, what have been the effects of immigrants on the development of this country? Lead to social conflict
note mig_sup01: How about people from other countries coming here to work. Which one of the following do you think the government should do? 1. Let anyone come who wants to 2. Let people come as long as there are jobs available 3. Place strict limits on the number of foreigners who can come here 4. Prohibit people coming here from other countries
note nei_sec01: Could you tell me how secure do you feel these days in your neighborhood?
note nei_rob01: How frequently do the following things occur in your neighborhood? Robberies
note nei_alc01: How frequently do the following things occur in your neighborhood? Alcohol consumed in the streets
note nei_police01: How frequently do the following things occur in your neighborhood? Police or military interfere with people's private life
note nei_racist01: How frequently do the following things occur in your neighborhood? Racist behavior
note nei_drugs01: How frequently do the following things occur in your neighborhood? Drug sale in streets
note nei_viol01: How frequently do the following things occur in your neighborhood? Street violence and fights
note nei_harass01: How frequently do the following things occur in your neighborhood? Sexual harassment
note nei_cash01: Which of the following things have you done for reasons of security? Didn't carry much money
note nei_out01: Which of the following things have you done for reasons of security? Preferred not to go out at night
note nei_weap01: Which of the following things have you done for reasons of security? Carried a knife, gun or other weapon
note worry_job01: To what degree are you worried about the following situations? Losing my job or not finding a job
note worry_kidseduc01: To what degree are you worried about the following situations? Not being able to give one's children a good education
note victim_self01: Have you been the victim of a crime during the past year?
note victim_fam01: And what about your immediate family--has someone in your family been the victim of a crime during the last year?
note worry_war01: To what degree are you worried about the following situations? A war involving my country
note worry_terror01: To what degree are you worried about the following situations? A terrorist attack
note worry_civwar01: To what degree are you worried about the following situations? A civil war
note val_free_equal01: Most people consider both freedom and equality to be important, but if you had to choose between them, which one would you consider more important?
note val_free_sec01: Most people consider both freedom and security to be important, but if you had to choose between them, which one would you consider more important?
note fight_country01: Of course, we all hope that there will not be another war, but if it were to come to that, would you be willing to fight for your country?
note valsci_life01: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree.' Science and technology are making our lives healthier, easier, and more comfortable
note valsci_opp01: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree.' Because of science and technology, there will be more opportunities for the next generation
note valsci_faith01: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree.' We depend too much on science and not enough on faith
note valsci_morals01: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree' - One of the bad effects of science is that it breaks down people's ideas of right and wrong 
note valsci_know01: Now, I would like to read some statements and ask how much you agree or disagree with each of these statements. For these questions, a 1 means that you 'completely disagree' and a 10 means that you 'completely agree' - It is not important for me to know about science in my daily life 
note valsci_better01: All things considered, would you say that the world is better off, or worse off, because of science and technology? Please tell me which comes closest to your view on this scale - 1 means that 'the world is a lot worse off,' and 10 means that ''the world is a lot better off.' The world is better off, or worse off, because of science and technology
note rel_godimp01: How important is God in your life?. Please use this scale to indicate. 10 means 'very important' and 1 means 'not at all important'.
note rel_god01: In which of the following things do you believe, if you believe in any? - God
note rel_life01: In which of the following things do you believe, if you believe in any? - Life after death
note rel_hell01: In which of the following things do you believe, if you believe in any? - Hell
note rel_heaven01: In which of the following things do you believe, if you believe in any? - Heaven
note rel_right01: Please tell us if you strongly agree, agree, disagree, or strongly disagree with the following statements - Whenever science and religion conflict, religion is always right
note rel_mine01: Please tell us if you strongly agree, agree, disagree, or strongly disagree with the following statements - The only acceptable religion is my religion
note rel_attend01: Apart from weddings, funerals and christenings, about how often do you attend religious services these days?
note rel_pray01: Apart from weddings and funerals, about how often do you pray?
note rel_pers01: Independently of whether you go to church or not, would you say you are…
note rel_good01: With which one of the following statements do you agree most? The meaning of religion is…
note rel_thislife01: And with which of the following statements do you agree most? The meaning of religion is…
note morals_hard01: How much do you agree or disagree with the statement that nowadays one often has trouble deciding which moral rules are the right ones to follow?
note law_govben01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between -  - Claiming government benefits to which you are not entitled
note law_fare01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - - Avoiding a fare on public transport 
note law_steal01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Stealing property
note law_taxes01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Cheating on taxes if you have a chance
note law_bribe01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Someone accepting a bribe in the course of their duties
note morals_gay01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Homosexuality
note morals_prost01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Prostitution
note morals_abor01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Abortion
note morals_div01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Divorce
note morals_sex01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Sex before marriage
note morals_suic01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Suicide
note morals_letdie01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Euthanasia
note viol_beatwife01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - For a man to beat his wife
note viol_childs01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Parents beating children
note viol_other01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Violence against other people
note viol_terror01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Terrorism as a political, ideological or religious mean
note morals_casual01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between - Having casual sex
note viol_pol01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between -  Political violence
note viol_death_pen01: Please tell me for each of the following statements whether you think it can always be justified, never be justified, or something in between -  Death penalty
note surv_video01: Do you think this country's government should or should not have the right to do the following - Keep people under video surveillance in public areas
note surv_email01: Do you think this country's government should or should not have the right to do the following - Monitor all emails and any other information exchanged on the Internet
note surv_allinfo01: Do you think that this country's government should or should not have the right to do the following - Collect information about anyone living in this country without their knowledge
note polint01: How interested would you say you are in politics?
note poltalk01: When you get together with your friends, would you say you discuss political matters frequently, occasionally or never?
note news_paper01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Daily newspaper
note news_tv01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - TV news
note news_radio01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Radio news
note news_mobile01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Mobile phone
note news_email01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Email
note news_web01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Internet
note news_social01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Social media (Facebook, Twitter, etc.)
note news_friends01: People learn what is going on in this country and the world from various sources. For each of the following sources, please indicate whether you use it to obtain information daily, weekly, monthly, less than monthly or never - Talk with friends or colleagues
note polpart_pet01: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Signing a petition
note polpart_boy01: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Joining in boycotts
note polpart_prot01: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Attending peaceful demonstrations
note polpart_strikes01: Now I'd like you to look at this card. I'm going to read out some different forms of political action that people can take, and I'd like you to tell me, for each one, whether you have actually done any of these things, whether you might do it or would never, under any circumstances, do it. Joining strikes
note polpart_donate01: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Donating to a group or campaign
note polpart_contact01: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Contacting a government official
note polpart_othact01: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Encouraging others to take action about political issues
note polpart_othvote01: What about these forms of political action and social activism that people can take?. Please, tell me for each of them if you have done any of these things, whether you might do it or would never under any circumstances do it-Encouraging others to vote
note polpart_socmed_search01: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it-Searching information about politics and political events
note polpart_socmed_sign01: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it-Signing an electronic petition
note polpart_socmed_othact01: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it - Encouraging other people to take any form of political action
note polpart_socmed_organize01: Now I'd like you to look at this card. I'm going to read out some other forms of political action that people can take using Internet and social media tools like Facebook, Twitter etc., and I'd like you to tell me, for each one, whether you have done any of these things, whether you might do it or would never under any circumstances do it-Organizing political activities, events, protests
note vote_local01: Vote in elections - Local level
note vote_nat01: Vote in elections - National level
note elec_votes01: In your view, how often do the following things occur in this country's elections? Votes are counted fairly
note elec_oppno01: In your view, how often do the following things occur in this country's elections? Opposition candidates are prevented from running
note elec_press_incum01: In your view, how often do the following things occur in this country's elections? TV news favors the governing party
note elec_bribe01: In your view, how often do the following things occur in this country's elections? Voters are bribed
note elec_pressfair01: In your view, how often do the following things occur in this country's elections? Journalists provide fair coverage of elections
note elec_off01: In your view, how often do the following things occur in this country's elections? Election officials are fair
note elec_rich01: In your view, how often do the following things occur in this country's elections? Rich people buy elections
note elec_viol01: In your view, how often do the following things occur in this country's elections? Voters are threatened with violence at the polls
note elec_choice01: In your view, how often do the following things occur in this country's elections? Voters are offered a genuine choice in the elections
note elec_fem01: In your view, how often do the following things occur in this country's elections? - Women have equal opportunities to run the office
note elec_say01: Do you think that honest elections play an important role in deciding whether you and your family are able to make a good living? How important would you say this is—very important, fairly important, not very important or not at all important?
note honelec_matter01: How much would you say the political system in your country allows people like you to have a say in what the government does?
note dem_strong01: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having a strong leader who does not have to bother with parliament and elections
note dem_experts01: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having experts, not government, make decisions according to what they think is best for the country
note dem_army01: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having the army rule
note dem_dem01: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having a democratic political system
note dem_rel01: I'm going to describe various types of political systems and ask what you think about each as a way of governing this country. For each one, would you say it is a very good, fairly good, fairly bad or very bad way of governing this country? Having a system governed by religious law in which there are no political parties or elections
note val_left01: In political matters, people talk of 'the left' and 'the right.' How would you place your views on this scale, generally speaking?
note essdem_poor01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - Governments tax the rich and subsidize the poor
note essdem_rel01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - Religious authorities interpret the laws
note essdem_elec01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - People choose their leaders in free elections
note essdem_unemp01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - People receive state aid for unemployment
note essdem_army01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - The army takes over when government is incompetent
note essdem_liberty01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy. - Civil rights protect people's liberty from state oppression
note essdem_equal01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - The state makes people´s incomes equal
note essdem_obey01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - People obey their rulers
note essdem_fem01: Please tell me for each of the following things how essential you think it is as a characteristic of democracy.' - Women have the same rights as men
note demimp01: How important is it for you to live in a country that is governed democratically? On this scale where 1 means it is 'not at all important' and 10 means 'absolutely important' what position would you choose?
note howdem01: And how democratically is this country being governed today?. Again using a scale from 1 to 10, where 1 means that it is 'not at all democratic' and 10 means that it is 'completely democratic," what position would you choose?
note polsat01: How satisfied are you with how the political system is functioning in your country these days? On the scale from 1 to 10 below, 1 means not satisfied at all and 10 means completely satisfied.
note perc_rights01: How much respect is there for individual human rights nowadays in this country?
note nat_pride01: How proud are you to be of nationality of this country?
note close_local01: People have different views about themselves and how they relate to the world. Using this card, would you tell me how close do you feel to…? Your village, town or city
note seeself_local01: People have different views about themselves and how they relate to the world. Using this card, would you tell me how strongly you agree or disagree with each of the following statements about how you see yourself? Your county, region, district
note seeself_reg01: People have different views about themselves and how they relate to the world. Using this card, would you tell me how strongly you agree or disagree with each of the following statements about how you see yourself? Country
note close_cont01: People have different views about themselves and how they relate to the world. Using this card, would you tell me how close do you feel to…? Continent; e.g. Europe, Asia etc.
note close_world01: People have different views about themselves and how they relate to the world. Using this card, would you tell me how strongly you agree or disagree with each of the following statements about how you see yourself? World


















note 	townsize8	: Original variable is G_TOWNSIZE 
note 	townsize5	: Original variable is G_TOWNSIZE2 
note 	towntype	: Original variable is H_SETTLEMENT 
note 	urban	: Original variable is H_URBRURAL 
note 	int_rint	: Original variable is E_RESPINT 
note 	int_priv	: Original variable is F_INTPRIVACY 
note 	imp_family	: Original variable is Q1P 
note 	imp_friends	: Original variable is Q2P 
note 	imp_leisure	: Original variable is Q3P 
note 	imp_politics	: Original variable is Q4P 
note 	imp_work	: Original variable is Q5P 
note 	imp_rel	: Original variable is Q6P 
note 	val_manners	: Original variable is Q7P 
note 	val_indep	: Original variable is Q8P 
note 	val_work	: Original variable is Q9P 
note 	val_resp	: Original variable is Q10P 
note 	val_imag	: Original variable is Q11P 
note 	val_tol	: Original variable is Q12P 
note 	val_thrift	: Original variable is Q13P 
note 	val_determ	: Original variable is Q14P 
note 	val_rel	: Original variable is Q15P 
note 	val_unself	: Original variable is Q16P 
note 	val_obey	: Original variable is Q17P 
note 	nei_addicts	: Original variable is Q18P 
note 	nei_race	: Original variable is Q19P 
note 	nei_aids	: Original variable is Q20P 
note 	nei_imm	: Original variable is Q21P 
note 	nei_gay	: Original variable is Q22P 
note 	nei_reldif	: Original variable is Q23P 
note 	nei_drink	: Original variable is Q24P 
note 	nei_notmar	: Original variable is Q25P 
note 	nei_langdif	: Original variable is Q26P 
note 	par_proud	: Original variable is Q27P 
note 	notwork_lazy	: Original variable is Q39P 
note 	work_duty	: Original variable is Q40P 
note 	workfirst	: Original variable is Q41P 
note 	cons_ref_rev	: Original variable is Q42 
note 	fut_work_notless	: Original variable is Q43P 
note 	fut_tech	: Original variable is Q44P 
note 	fut_obey	: Original variable is Q45P 
note 	happy	: Original variable is Q46P 
note 	health	: Original variable is Q47P 
note 	ext_loc_control	: Original variable is Q48 
note 	satlife	: Original variable is Q49 
note 	satfin	: Original variable is Q50 
note 	econbad_food	: Original variable is Q51P 
note 	econbad_crime	: Original variable is Q52P 
note 	econbad_med	: Original variable is Q53P 
note 	econbad_cash	: Original variable is Q54P 
note 	econbad_home	: Original variable is Q55P 
note 	econ_parents	: Original variable is Q56P 
note 	trust	: Original variable is Q57P 
note 	trust_fam	: Original variable is Q58P 
note 	trust_nei	: Original variable is Q59P 
note 	trust_know	: Original variable is Q60P 
note 	trust_meet	: Original variable is Q61P 
note 	trust_rel	: Original variable is Q62P 
note 	trust_noncit	: Original variable is Q63P 
note 	conf_church	: Original variable is Q64P 
note 	conf_army	: Original variable is Q65P 
note 	conf_press	: Original variable is Q66P 
note 	conf_tv	: Original variable is Q67P 
note 	conf_unions	: Original variable is Q68P 
note 	conf_police	: Original variable is Q69P 
note 	conf_courts	: Original variable is Q70P 
note 	conf_gov	: Original variable is Q71P 
note 	conf_parties	: Original variable is Q72P 
note 	conf_parl	: Original variable is Q73P 
note 	conf_civil	: Original variable is Q74P 
note 	conf_univ	: Original variable is Q75P 
note 	conf_elec	: Original variable is Q76P 
note 	conf_bus	: Original variable is Q77P 
note 	conf_banks	: Original variable is Q78P 
note 	conf_env	: Original variable is Q79P 
note 	conf_womens	: Original variable is Q80P 
note 	conf_charit	: Original variable is Q81P 
note 	conf_reggov	: Original variable is Q82P 
note 	know_UN	: Original variable is Q91 
note 	know_IMF	: Original variable is Q92 
note 	know_Amnesty	: Original variable is Q93 
note 	mem_church	: Original variable is Q94 
note 	mem_sport	: Original variable is Q95 
note 	mem_art	: Original variable is Q96 
note 	mem_union	: Original variable is Q97 
note 	mem_party	: Original variable is Q98 
note 	mem_env	: Original variable is Q99 
note 	mem_prof	: Original variable is Q100 
note 	mem_charit	: Original variable is Q101 
note 	mem_consumer	: Original variable is Q102 
note 	mem_selfhelp	: Original variable is Q103 
note 	mem_womens	: Original variable is Q104 
note 	mem_other	: Original variable is Q105 
note 	val_incdif	: Original variable is Q106 
note 	val_privown	: Original variable is Q107 
note 	val_ind	: Original variable is Q108 
note 	val_compet	: Original variable is Q109 
note 	val_hardwork	: Original variable is Q110 
note 	val_env	: Original variable is Q111 
note 	corrupt	: Original variable is Q112 
note 	corr_state	: Original variable is Q113 
note 	corr_bus	: Original variable is Q114 
note 	corr_local	: Original variable is Q115 
note 	corr_civil	: Original variable is Q116 
note 	corr_journ	: Original variable is Q117 
note 	bribe_freq	: Original variable is Q118 
note 	bribe_account	: Original variable is Q120 
note 	imm_good	: Original variable is Q121 
note 	imm_useful_jobs	: Original variable is Q122 
note 	imm_cult_div	: Original variable is Q123 
note 	imm_crime	: Original variable is Q124 
note 	imm_asylum	: Original variable is Q125 
note 	imm_terror	: Original variable is Q126 
note 	imm_poor	: Original variable is Q127 
note 	imm_unemp	: Original variable is Q128 
note 	imm_conflict	: Original variable is Q129 
note 	mig_sup	: Original variable is Q130P 
note 	nei_sec	: Original variable is Q131P 
note 	nei_rob	: Original variable is Q132P 
note 	nei_alc	: Original variable is Q133P 
note 	nei_police	: Original variable is Q134P 
note 	nei_racist	: Original variable is Q135P 
note 	nei_drugs	: Original variable is Q136P 
note 	nei_viol	: Original variable is Q137P 
note 	nei_harass	: Original variable is Q138P 
note 	nei_cash	: Original variable is Q139P 
note 	nei_out	: Original variable is Q140P 
note 	nei_weap	: Original variable is Q141P 
note 	worry_job	: Original variable is Q142P 
note 	worry_kidseduc	: Original variable is Q143P 
note 	victim_self	: Original variable is Q144P 
note 	victim_fam	: Original variable is Q145P 
note 	worry_war	: Original variable is Q146P 
note 	worry_terror	: Original variable is Q147P 
note 	worry_civwar	: Original variable is Q148P 
note 	val_free_equal	: Original variable is Q149 
note 	val_free_sec	: Original variable is Q150 
note 	fight_country	: Original variable is Q151P 
note 	valsci_life	: Original variable is Q158 
note 	valsci_opp	: Original variable is Q159 
note 	valsci_faith	: Original variable is Q160 
note 	valsci_morals	: Original variable is Q161 
note 	valsci_know	: Original variable is Q162 
note 	valsci_better	: Original variable is Q163 
note 	rel_godimp	: Original variable is Q164 
note 	rel_god	: Original variable is Q165P 
note 	rel_life	: Original variable is Q166P 
note 	rel_hell	: Original variable is Q167P 
note 	rel_heaven	: Original variable is Q168P 
note 	rel_right	: Original variable is Q169P 
note 	rel_mine	: Original variable is Q170P 
note 	rel_attend	: Original variable is Q171P 
note 	rel_pray	: Original variable is Q172P 
note 	rel_pers	: Original variable is Q173P 
note 	rel_good	: Original variable is Q174 
note 	rel_thislife	: Original variable is Q175 
note 	morals_hard	: Original variable is Q176P 
note 	law_govben	: Original variable is Q177 
note 	law_fare	: Original variable is Q178 
note 	law_steal	: Original variable is Q179 
note 	law_taxes	: Original variable is Q180 
note 	law_bribe	: Original variable is Q181 
note 	morals_gay	: Original variable is Q182 
note 	morals_prost	: Original variable is Q183 
note 	morals_abor	: Original variable is Q184 
note 	morals_div	: Original variable is Q185 
note 	morals_sex	: Original variable is Q186 
note 	morals_suic	: Original variable is Q187 
note 	morals_letdie	: Original variable is Q188 
note 	viol_beatwife	: Original variable is Q189 
note 	viol_childs	: Original variable is Q190 
note 	viol_other	: Original variable is Q191 
note 	viol_terror	: Original variable is Q192 
note 	morals_casual	: Original variable is Q193 
note 	viol_pol	: Original variable is Q194 
note 	viol_death_pen	: Original variable is Q195 
note 	surv_video	: Original variable is Q196P 
note 	surv_email	: Original variable is Q197P 
note 	surv_allinfo	: Original variable is Q198P 
note 	polint	: Original variable is Q199P 
note 	poltalk	: Original variable is Q200P 
note 	news_paper	: Original variable is Q201P 
note 	news_tv	: Original variable is Q202P 
note 	news_radio	: Original variable is Q203P 
note 	news_mobile	: Original variable is Q204P 
note 	news_email	: Original variable is Q205P 
note 	news_web	: Original variable is Q206P 
note 	news_social	: Original variable is Q207P 
note 	news_friends	: Original variable is Q208P 
note 	polpart_pet	: Original variable is Q209P 
note 	polpart_boy	: Original variable is Q210P 
note 	polpart_prot	: Original variable is Q211P 
note 	polpart_strikes	: Original variable is Q212P 
note 	polpart_donate	: Original variable is Q213P 
note 	polpart_contact	: Original variable is Q214P 
note 	polpart_othact	: Original variable is Q215P 
note 	polpart_othvote	: Original variable is Q216P 
note 	polpart_socmed_search	: Original variable is Q217P 
note 	polpart_socmed_sign	: Original variable is Q218P 
note 	polpart_socmed_othact	: Original variable is Q219P 
note 	polpart_socmed_organize	: Original variable is Q220P 
note 	vote_local	: Original variable is Q221P 
note 	vote_nat	: Original variable is Q222P 
note 	elec_votes	: Original variable is Q224P 
note 	elec_oppno	: Original variable is Q225P 
note 	elec_press_incum	: Original variable is Q226P 
note 	elec_bribe	: Original variable is Q227P 
note 	elec_pressfair	: Original variable is Q228P 
note 	elec_off	: Original variable is Q229P 
note 	elec_rich	: Original variable is Q230P 
note 	elec_viol	: Original variable is Q231P 
note 	elec_choice	: Original variable is Q232P 
note 	elec_fem	: Original variable is Q233P 
note 	elec_say	: Original variable is Q234AP 
note 	honelec_matter	: Original variable is Q234P 
note 	dem_strong	: Original variable is Q235P 
note 	dem_experts	: Original variable is Q236P 
note 	dem_army	: Original variable is Q237P 
note 	dem_dem	: Original variable is Q238P 
note 	dem_rel	: Original variable is Q239P 
note 	val_left	: Original variable is Q240 
note 	essdem_poor	: Original variable is Q241 
note 	essdem_rel	: Original variable is Q242 
note 	essdem_elec	: Original variable is Q243 
note 	essdem_unemp	: Original variable is Q244 
note 	essdem_army	: Original variable is Q245 
note 	essdem_liberty	: Original variable is Q246 
note 	essdem_equal	: Original variable is Q247 
note 	essdem_obey	: Original variable is Q248 
note 	essdem_fem	: Original variable is Q249 
note 	demimp	: Original variable is Q250 
note 	howdem	: Original variable is Q251 
note 	polsat	: Original variable is Q252 
note 	perc_rights	: Original variable is Q253P 
note 	nat_pride	: Original variable is Q254P 
note 	close_local	: Original variable is Q255P 
note 	seeself_local	: Original variable is Q256P 
note 	seeself_reg	: Original variable is Q257P 
note 	close_cont	: Original variable is Q258P 
note 	close_world	: Original variable is Q259P 
note 	female	: Original variable is Q260 
note 	birthyr	: Original variable is Q261 
note 	age	: Original variable is Q262 
note 	age_6cat	: Original variable is X003R 
note 	age_3cat	: Original variable is X003R2 
note 	forborn	: Original variable is Q263 
note 	ma_forborn	: Original variable is Q264 
note 	pa_forborn	: Original variable is Q265 
note 	citizen	: Original variable is Q269 
note 	hh_num	: Original variable is Q270 
note 	hh_parents	: Original variable is Q271 
note 	mar_nom	: Original variable is Q273 
note 	hh_kidsnum	: Original variable is Q274 
note 	educ	: Original variable is Q275 
note 	sp_educ	: Original variable is Q276 
note 	ma_educ	: Original variable is Q277 
note 	pa_educ	: Original variable is Q278 
note 	employ_nom	: Original variable is Q279 
note 	sp_employ_nom	: Original variable is Q280 
note 	occ_nom	: Original variable is Q281 
note 	sp_occ_nom	: Original variable is Q282 
note 	pa_occ_nom	: Original variable is Q283 
note 	sector_nom	: Original variable is Q284 
note 	chief_earn	: Original variable is Q285 
note 	savings	: Original variable is Q286 
note 	class	: Original variable is Q287P 
note 	income	: Original variable is Q288 
note 	inc_3cat	: Original variable is Q288R 
note 	denom	: Original variable is Q289 
note 	townsize801	: Original variable is G_TOWNSIZE 
note 	townsize501	: Original variable is G_TOWNSIZE2 
note 	towntype01	: Original variable is H_SETTLEMENT 
note 	urban01	: Original variable is H_URBRURAL 
note 	int_rint01	: Original variable is E_RESPINT 
note 	int_priv01	: Original variable is F_INTPRIVACY 
note 	imp_family01	: Original variable is Q1P 
note 	imp_friends01	: Original variable is Q2P 
note 	imp_leisure01	: Original variable is Q3P 
note 	imp_politics01	: Original variable is Q4P 
note 	imp_work01	: Original variable is Q5P 
note 	imp_rel01	: Original variable is Q6P 
note 	val_manners01	: Original variable is Q7P 
note 	val_indep01	: Original variable is Q8P 
note 	val_work01	: Original variable is Q9P 
note 	val_resp01	: Original variable is Q10P 
note 	val_imag01	: Original variable is Q11P 
note 	val_tol01	: Original variable is Q12P 
note 	val_thrift01	: Original variable is Q13P 
note 	val_determ01	: Original variable is Q14P 
note 	val_rel01	: Original variable is Q15P 
note 	val_unself01	: Original variable is Q16P 
note 	val_obey01	: Original variable is Q17P 
note 	nei_addicts01	: Original variable is Q18P 
note 	nei_race01	: Original variable is Q19P 
note 	nei_aids01	: Original variable is Q20P 
note 	nei_imm01	: Original variable is Q21P 
note 	nei_gay01	: Original variable is Q22P 
note 	nei_reldif01	: Original variable is Q23P 
note 	nei_drink01	: Original variable is Q24P 
note 	nei_notmar01	: Original variable is Q25P 
note 	nei_langdif01	: Original variable is Q26P 
note 	par_proud01	: Original variable is Q27P 
note 	notwork_lazy01	: Original variable is Q39P 
note 	work_duty01	: Original variable is Q40P 
note 	workfirst01	: Original variable is Q41P 
note 	cons_ref_rev01	: Original variable is Q42 
note 	fut_work_notless01	: Original variable is Q43P 
note 	fut_tech01	: Original variable is Q44P 
note 	fut_obey01	: Original variable is Q45P 
note 	happy01	: Original variable is Q46P 
note 	health01	: Original variable is Q47P 
note 	ext_loc_control01	: Original variable is Q48 
note 	satlife01	: Original variable is Q49 
note 	satfin01	: Original variable is Q50 
note 	econbad_food01	: Original variable is Q51P 
note 	econbad_crime01	: Original variable is Q52P 
note 	econbad_med01	: Original variable is Q53P 
note 	econbad_cash01	: Original variable is Q54P 
note 	econbad_home01	: Original variable is Q55P 
note 	econ_parents01	: Original variable is Q56P 
note 	trust01	: Original variable is Q57P 
note 	trust_fam01	: Original variable is Q58P 
note 	trust_nei01	: Original variable is Q59P 
note 	trust_know01	: Original variable is Q60P 
note 	trust_meet01	: Original variable is Q61P 
note 	trust_rel01	: Original variable is Q62P 
note 	trust_noncit01	: Original variable is Q63P 
note 	conf_church01	: Original variable is Q64P 
note 	conf_army01	: Original variable is Q65P 
note 	conf_press01	: Original variable is Q66P 
note 	conf_tv01	: Original variable is Q67P 
note 	conf_unions01	: Original variable is Q68P 
note 	conf_police01	: Original variable is Q69P 
note 	conf_courts01	: Original variable is Q70P 
note 	conf_gov01	: Original variable is Q71P 
note 	conf_parties01	: Original variable is Q72P 
note 	conf_parl01	: Original variable is Q73P 
note 	conf_civil01	: Original variable is Q74P 
note 	conf_univ01	: Original variable is Q75P 
note 	conf_elec01	: Original variable is Q76P 
note 	conf_bus01	: Original variable is Q77P 
note 	conf_banks01	: Original variable is Q78P 
note 	conf_env01	: Original variable is Q79P 
note 	conf_womens01	: Original variable is Q80P 
note 	conf_charit01	: Original variable is Q81P 
note 	conf_reggov01	: Original variable is Q82P 
note 	know_UN01	: Original variable is Q91 
note 	know_IMF01	: Original variable is Q92 
note 	know_Amnesty01	: Original variable is Q93 
note 	mem_church01	: Original variable is Q94 
note 	mem_sport01	: Original variable is Q95 
note 	mem_art01	: Original variable is Q96 
note 	mem_union01	: Original variable is Q97 
note 	mem_party01	: Original variable is Q98 
note 	mem_env01	: Original variable is Q99 
note 	mem_prof01	: Original variable is Q100 
note 	mem_charit01	: Original variable is Q101 
note 	mem_consumer01	: Original variable is Q102 
note 	mem_selfhelp01	: Original variable is Q103 
note 	mem_womens01	: Original variable is Q104 
note 	mem_other01	: Original variable is Q105 
note 	val_incdif01	: Original variable is Q106 
note 	val_privown01	: Original variable is Q107 
note 	val_ind01	: Original variable is Q108 
note 	val_compet01	: Original variable is Q109 
note 	val_hardwork01	: Original variable is Q110 
note 	val_env01	: Original variable is Q111 
note 	corrupt01	: Original variable is Q112 
note 	corr_state01	: Original variable is Q113 
note 	corr_bus01	: Original variable is Q114 
note 	corr_local01	: Original variable is Q115 
note 	corr_civil01	: Original variable is Q116 
note 	corr_journ01	: Original variable is Q117 
note 	bribe_freq01	: Original variable is Q118 
note 	bribe_account01	: Original variable is Q120 
note 	imm_good01	: Original variable is Q121 
note 	imm_useful_jobs01	: Original variable is Q122 
note 	imm_cult_div01	: Original variable is Q123 
note 	imm_crime01	: Original variable is Q124 
note 	imm_asylum01	: Original variable is Q125 
note 	imm_terror01	: Original variable is Q126 
note 	imm_poor01	: Original variable is Q127 
note 	imm_unemp01	: Original variable is Q128 
note 	imm_conflict01	: Original variable is Q129 
note 	mig_sup01	: Original variable is Q130P 
note 	nei_sec01	: Original variable is Q131P 
note 	nei_rob01	: Original variable is Q132P 
note 	nei_alc01	: Original variable is Q133P 
note 	nei_police01	: Original variable is Q134P 
note 	nei_racist01	: Original variable is Q135P 
note 	nei_drugs01	: Original variable is Q136P 
note 	nei_viol01	: Original variable is Q137P 
note 	nei_harass01	: Original variable is Q138P 
note 	nei_cash01	: Original variable is Q139P 
note 	nei_out01	: Original variable is Q140P 
note 	nei_weap01	: Original variable is Q141P 
note 	worry_job01	: Original variable is Q142P 
note 	worry_kidseduc01	: Original variable is Q143P 
note 	victim_self01	: Original variable is Q144P 
note 	victim_fam01	: Original variable is Q145P 
note 	worry_war01	: Original variable is Q146P 
note 	worry_terror01	: Original variable is Q147P 
note 	worry_civwar01	: Original variable is Q148P 
note 	val_free_equal01	: Original variable is Q149 
note 	val_free_sec01	: Original variable is Q150 
note 	fight_country01	: Original variable is Q151P 
note 	valsci_life01	: Original variable is Q158 
note 	valsci_opp01	: Original variable is Q159 
note 	valsci_faith01	: Original variable is Q160 
note 	valsci_morals01	: Original variable is Q161 
note 	valsci_know01	: Original variable is Q162 
note 	valsci_better01	: Original variable is Q163 
note 	rel_godimp01	: Original variable is Q164 
note 	rel_god01	: Original variable is Q165P 
note 	rel_life01	: Original variable is Q166P 
note 	rel_hell01	: Original variable is Q167P 
note 	rel_heaven01	: Original variable is Q168P 
note 	rel_right01	: Original variable is Q169P 
note 	rel_mine01	: Original variable is Q170P 
note 	rel_attend01	: Original variable is Q171P 
note 	rel_pray01	: Original variable is Q172P 
note 	rel_pers01	: Original variable is Q173P 
note 	rel_good01	: Original variable is Q174 
note 	rel_thislife01	: Original variable is Q175 
note 	morals_hard01	: Original variable is Q176P 
note 	law_govben01	: Original variable is Q177 
note 	law_fare01	: Original variable is Q178 
note 	law_steal01	: Original variable is Q179 
note 	law_taxes01	: Original variable is Q180 
note 	law_bribe01	: Original variable is Q181 
note 	morals_gay01	: Original variable is Q182 
note 	morals_prost01	: Original variable is Q183 
note 	morals_abor01	: Original variable is Q184 
note 	morals_div01	: Original variable is Q185 
note 	morals_sex01	: Original variable is Q186 
note 	morals_suic01	: Original variable is Q187 
note 	morals_letdie01	: Original variable is Q188 
note 	viol_beatwife01	: Original variable is Q189 
note 	viol_childs01	: Original variable is Q190 
note 	viol_other01	: Original variable is Q191 
note 	viol_terror01	: Original variable is Q192 
note 	morals_casual01	: Original variable is Q193 
note 	viol_pol01	: Original variable is Q194 
note 	viol_death_pen01	: Original variable is Q195 
note 	surv_video01	: Original variable is Q196P 
note 	surv_email01	: Original variable is Q197P 
note 	surv_allinfo01	: Original variable is Q198P 
note 	polint01	: Original variable is Q199P 
note 	poltalk01	: Original variable is Q200P 
note 	news_paper01	: Original variable is Q201P 
note 	news_tv01	: Original variable is Q202P 
note 	news_radio01	: Original variable is Q203P 
note 	news_mobile01	: Original variable is Q204P 
note 	news_email01	: Original variable is Q205P 
note 	news_web01	: Original variable is Q206P 
note 	news_social01	: Original variable is Q207P 
note 	news_friends01	: Original variable is Q208P 
note 	polpart_pet01	: Original variable is Q209P 
note 	polpart_boy01	: Original variable is Q210P 
note 	polpart_prot01	: Original variable is Q211P 
note 	polpart_strikes01	: Original variable is Q212P 
note 	polpart_donate01	: Original variable is Q213P 
note 	polpart_contact01	: Original variable is Q214P 
note 	polpart_othact01	: Original variable is Q215P 
note 	polpart_othvote01	: Original variable is Q216P 
note 	polpart_socmed_search01	: Original variable is Q217P 
note 	polpart_socmed_sign01	: Original variable is Q218P 
note 	polpart_socmed_othact01	: Original variable is Q219P 
note 	polpart_socmed_organize01	: Original variable is Q220P 
note 	vote_local01	: Original variable is Q221P 
note 	vote_nat01	: Original variable is Q222P 
note 	elec_votes01	: Original variable is Q224P 
note 	elec_oppno01	: Original variable is Q225P 
note 	elec_press_incum01	: Original variable is Q226P 
note 	elec_bribe01	: Original variable is Q227P 
note 	elec_pressfair01	: Original variable is Q228P 
note 	elec_off01	: Original variable is Q229P 
note 	elec_rich01	: Original variable is Q230P 
note 	elec_viol01	: Original variable is Q231P 
note 	elec_choice01	: Original variable is Q232P 
note 	elec_fem01	: Original variable is Q233P 
note 	elec_say01	: Original variable is Q234AP 
note 	honelec_matter01	: Original variable is Q234P 
note 	dem_strong01	: Original variable is Q235P 
note 	dem_experts01	: Original variable is Q236P 
note 	dem_army01	: Original variable is Q237P 
note 	dem_dem01	: Original variable is Q238P 
note 	dem_rel01	: Original variable is Q239P 
note 	val_left01	: Original variable is Q240 
note 	essdem_poor01	: Original variable is Q241 
note 	essdem_rel01	: Original variable is Q242 
note 	essdem_elec01	: Original variable is Q243 
note 	essdem_unemp01	: Original variable is Q244 
note 	essdem_army01	: Original variable is Q245 
note 	essdem_liberty01	: Original variable is Q246 
note 	essdem_equal01	: Original variable is Q247 
note 	essdem_obey01	: Original variable is Q248 
note 	essdem_fem01	: Original variable is Q249 
note 	demimp01	: Original variable is Q250 
note 	howdem01	: Original variable is Q251 
note 	polsat01	: Original variable is Q252 
note 	perc_rights01	: Original variable is Q253P 
note 	nat_pride01	: Original variable is Q254P 
note 	close_local01	: Original variable is Q255P 
note 	seeself_local01	: Original variable is Q256P 
note 	seeself_reg01	: Original variable is Q257P 
note 	close_cont01	: Original variable is Q258P 
note 	close_world01	: Original variable is Q259P 
note 	female01	: Original variable is Q260 
note 	birthyr01	: Original variable is Q261 
note 	age01	: Original variable is Q262 
note 	forborn01	: Original variable is Q263 
note 	ma_forborn01	: Original variable is Q264 
note 	pa_forborn01	: Original variable is Q265 
note 	citizen01	: Original variable is Q269 
note 	hh_num01	: Original variable is Q270 
note 	hh_parents01	: Original variable is Q271 
note 	mar_nom	: Original variable is Q273 
note 	hh_kidsnum01	: Original variable is Q274 
note 	educ01	: Original variable is Q275 
note 	sp_educ01	: Original variable is Q276 
note 	ma_educ01	: Original variable is Q277 
note 	pa_educ01	: Original variable is Q278 
note 	employ_nom	: Original variable is Q279 
note 	sp_employ_nom	: Original variable is Q280 
note 	occ_nom	: Original variable is Q281 
note 	sp_occ_nom	: Original variable is Q282 
note 	pa_occ_nom	: Original variable is Q283 
note 	sector_nom	: Original variable is Q284 
note 	chief_earn	: Original variable is Q285 
note 	savings01	: Original variable is Q286 
note 	class01	: Original variable is Q287P 
note 	income01	: Original variable is Q288 









* codebook val_voice1_alt01 I_VOICE1 val_voice2_alt01 I_VOICE2 valsec01 sacsecval  valeman01 resemaval  val_notobey01 I_AUTHORITY  val_notnat01 I_NATIONALISM  val_notrel01 I_DEVOUT  valdefy01 defiance  rel_notimp01 I_RELIGIMP  rel_notbel01 I_RELIGBEL  rel_notprac01 I_RELIGPRAC  reldis01 disbelief  norm1 I_NORM1  norm2 I_NORM2  norm3 I_NORM3  nonconform01 relativism  not_trustarmy01 I_TRUSTARMY  not_trustpolice01 I_TRUSTPOLICE  not_trust_courts01 I_TRUSTCOURTS  skeptic01 scepticism  indep01 I_INDEP  imag01 I_IMAGIN  notobey01 I_NONOBED  autonomy01 autonomy equality01 equality  choice01 choice  voice01 voice  townsize8 G_TOWNSIZE   townsize5 G_TOWNSIZE2   towntype H_SETTLEMENT   urban H_URBRURAL   int_rint E_RESPINT   int_priv F_INTPRIVACY   imp_family Q1P   imp_friends Q2P   imp_leisure Q3P   imp_politics Q4P   imp_work Q5P   imp_rel Q6P   val_manners Q7P   val_indep Q8P   val_work Q9P   val_resp Q10P   val_imag Q11P   val_tol Q12P   val_thrift Q13P   val_determ Q14P   val_rel Q15P   val_unself Q16P   val_obey Q17P   nei_addicts Q18P   nei_race Q19P   nei_aids Q20P   nei_imm Q21P   nei_gay Q22P   nei_reldif Q23P   nei_drink Q24P   nei_notmar Q25P   nei_langdif Q26P   par_proud Q27P   notwork_lazy Q39P   work_duty Q40P   workfirst Q41P   cons_ref_rev Q42   fut_work_notless Q43P   fut_tech Q44P   fut_obey Q45P   happy Q46P   health Q47P   ext_loc_control Q48   satlife Q49   satfin Q50   econbad_food Q51P   econbad_crime Q52P   econbad_med Q53P   econbad_cash Q54P   econbad_home Q55P   econ_parents Q56P   trust Q57P   trust_fam Q58P   trust_nei Q59P   trust_know Q60P   trust_meet Q61P   trust_rel Q62P   trust_noncit Q63P   conf_church Q64P   conf_army Q65P   conf_press Q66P   conf_tv Q67P   conf_unions Q68P   conf_police Q69P   conf_courts Q70P   conf_gov Q71P   conf_parties Q72P   conf_parl Q73P   conf_civil Q74P   conf_univ Q75P   conf_elec Q76P   conf_bus Q77P   conf_banks Q78P   conf_env Q79P   conf_womens Q80P   conf_charit Q81P   conf_reggov Q82P   know_UN Q91   know_IMF Q92   know_Amnesty Q93   mem_church Q94   mem_sport Q95   mem_art Q96   mem_union Q97   mem_party Q98   mem_env Q99   mem_prof Q100   mem_charit Q101   mem_consumer Q102   mem_selfhelp Q103   mem_womens Q104   mem_other Q105   val_incdif Q106   val_privown Q107   val_ind Q108   val_compet Q109   val_hardwork Q110   val_env Q111   corrupt Q112   corr_state Q113   corr_bus Q114   corr_local Q115   corr_civil Q116   corr_journ Q117   bribe_freq Q118   bribe_account Q120   imm_good Q121   imm_useful_jobs Q122   imm_cult_div Q123   imm_crime Q124   imm_asylum Q125   imm_terror Q126   imm_poor Q127   imm_unemp Q128   imm_conflict Q129   mig_sup Q130P   nei_sec Q131P   nei_rob Q132P   nei_alc Q133P   nei_police Q134P   nei_racist Q135P   nei_drugs Q136P   nei_viol Q137P   nei_harass Q138P   nei_cash Q139P   nei_out Q140P   nei_weap Q141P   worry_job Q142P   worry_kidseduc Q143P   victim_self Q144P   victim_fam Q145P   worry_war Q146P   worry_terror Q147P   worry_civwar Q148P   val_free_equal Q149   val_free_sec Q150   fight_country Q151P   valsci_life Q158   valsci_opp Q159   valsci_faith Q160   valsci_morals Q161   valsci_know Q162   valsci_better Q163   rel_godimp Q164   rel_god Q165P   rel_life Q166P   rel_hell Q167P   rel_heaven Q168P   rel_right Q169P   rel_mine Q170P   rel_attend Q171P   rel_pray Q172P   rel_pers Q173P   rel_good Q174   rel_thislife Q175   morals_hard Q176P   law_govben Q177   law_fare Q178   law_steal Q179   law_taxes Q180   law_bribe Q181   morals_gay Q182   morals_prost Q183   morals_abor Q184   morals_div Q185   morals_sex Q186   morals_suic Q187   morals_letdie Q188   viol_beatwife Q189   viol_childs Q190   viol_other Q191   viol_terror Q192   morals_casual Q193   viol_pol Q194   viol_death_pen Q195   surv_video Q196P   surv_email Q197P   surv_allinfo Q198P   polint Q199P   poltalk Q200P   news_paper Q201P   news_tv Q202P   news_radio Q203P   news_mobile Q204P   news_email Q205P   news_web Q206P   news_social Q207P   news_friends Q208P   polpart_pet Q209P   polpart_boy Q210P   polpart_prot Q211P   polpart_strikes Q212P   polpart_donate Q213P   polpart_contact Q214P   polpart_othact Q215P   polpart_othvote Q216P   polpart_socmed_search Q217P   polpart_socmed_sign Q218P   polpart_socmed_othact Q219P   polpart_socmed_organize Q220P   vote_local Q221P   vote_nat Q222P   elec_votes Q224P   elec_oppno Q225P   elec_press_incum Q226P   elec_bribe Q227P   elec_pressfair Q228P   elec_off Q229P   elec_rich Q230P   elec_viol Q231P   elec_choice Q232P   elec_fem Q233P   elec_say Q234AP   honelec_matter Q234P   dem_strong Q235P   dem_experts Q236P   dem_army Q237P   dem_dem Q238P   dem_rel Q239P   val_left Q240   essdem_poor Q241   essdem_rel Q242   essdem_elec Q243   essdem_unemp Q244   essdem_army Q245   essdem_liberty Q246   essdem_equal Q247   essdem_obey Q248   essdem_fem Q249   demimp Q250   howdem Q251   polsat Q252   perc_rights Q253P   nat_pride Q254P   close_local Q255P   seeself_local Q256P   seeself_reg Q257P   close_cont Q258P   close_world Q259P   female Q260   birthyr Q261   age Q262   age_6cat X003R   age_3cat X003R2   forborn Q263   ma_forborn Q264   pa_forborn Q265   citizen Q269   hh_num Q270   hh_parents Q271   mar_nom Q273   hh_kidsnum Q274   educ Q275   sp_educ Q276   ma_educ Q277   pa_educ Q278   employ_nom Q279   sp_employ_nom Q280   occ_nom Q281   sp_occ_nom Q282   pa_occ_nom Q283   sector_nom Q284   chief_earn Q285   savings Q286   class Q287P   income Q288   inc_3cat Q288R   denom Q289   townsize801 G_TOWNSIZE   townsize501 G_TOWNSIZE2   towntype01 H_SETTLEMENT   urban01 H_URBRURAL   int_rint01 E_RESPINT   int_priv01 F_INTPRIVACY   imp_family01 Q1P   imp_friends01 Q2P   imp_leisure01 Q3P   imp_politics01 Q4P   imp_work01 Q5P   imp_rel01 Q6P   val_manners01 Q7P   val_indep01 Q8P   val_work01 Q9P   val_resp01 Q10P   val_imag01 Q11P   val_tol01 Q12P   val_thrift01 Q13P   val_determ01 Q14P   val_rel01 Q15P   val_unself01 Q16P   val_obey01 Q17P   nei_addicts01 Q18P   nei_race01 Q19P   nei_aids01 Q20P   nei_imm01 Q21P   nei_gay01 Q22P   nei_reldif01 Q23P   nei_drink01 Q24P   nei_notmar01 Q25P   nei_langdif01 Q26P   par_proud01 Q27P   notwork_lazy01 Q39P   work_duty01 Q40P   workfirst01 Q41P   cons_ref_rev01 Q42   fut_work_notless01 Q43P   fut_tech01 Q44P   fut_obey01 Q45P   happy01 Q46P   health01 Q47P   ext_loc_control01 Q48   satlife01 Q49   satfin01 Q50   econbad_food01 Q51P   econbad_crime01 Q52P   econbad_med01 Q53P   econbad_cash01 Q54P   econbad_home01 Q55P   econ_parents01 Q56P   trust01 Q57P   trust_fam01 Q58P   trust_nei01 Q59P   trust_know01 Q60P   trust_meet01 Q61P   trust_rel01 Q62P   trust_noncit01 Q63P   conf_church01 Q64P   conf_army01 Q65P   conf_press01 Q66P   conf_tv01 Q67P   conf_unions01 Q68P   conf_police01 Q69P   conf_courts01 Q70P   conf_gov01 Q71P   conf_parties01 Q72P   conf_parl01 Q73P   conf_civil01 Q74P   conf_univ01 Q75P   conf_elec01 Q76P   conf_bus01 Q77P   conf_banks01 Q78P   conf_env01 Q79P   conf_womens01 Q80P   conf_charit01 Q81P   conf_reggov01 Q82P   know_UN01 Q91   know_IMF01 Q92   know_Amnesty01 Q93   mem_church01 Q94   mem_sport01 Q95   mem_art01 Q96   mem_union01 Q97   mem_party01 Q98   mem_env01 Q99   mem_prof01 Q100   mem_charit01 Q101   mem_consumer01 Q102   mem_selfhelp01 Q103   mem_womens01 Q104   mem_other01 Q105   val_incdif01 Q106   val_privown01 Q107   val_ind01 Q108   val_compet01 Q109   val_hardwork01 Q110   val_env01 Q111   corrupt01 Q112   corr_state01 Q113   corr_bus01 Q114   corr_local01 Q115   corr_civil01 Q116   corr_journ01 Q117   bribe_freq01 Q118   bribe_account01 Q120   imm_good01 Q121   imm_useful_jobs01 Q122   imm_cult_div01 Q123   imm_crime01 Q124   imm_asylum01 Q125   imm_terror01 Q126   imm_poor01 Q127   imm_unemp01 Q128   imm_conflict01 Q129   mig_sup01 Q130P   nei_sec01 Q131P   nei_rob01 Q132P   nei_alc01 Q133P   nei_police01 Q134P   nei_racist01 Q135P   nei_drugs01 Q136P   nei_viol01 Q137P   nei_harass01 Q138P   nei_cash01 Q139P   nei_out01 Q140P   nei_weap01 Q141P   worry_job01 Q142P   worry_kidseduc01 Q143P   victim_self01 Q144P   victim_fam01 Q145P   worry_war01 Q146P   worry_terror01 Q147P   worry_civwar01 Q148P   val_free_equal01 Q149   val_free_sec01 Q150   fight_country01 Q151P   valsci_life01 Q158   valsci_opp01 Q159   valsci_faith01 Q160   valsci_morals01 Q161   valsci_know01 Q162   valsci_better01 Q163   rel_godimp01 Q164   rel_god01 Q165P   rel_life01 Q166P   rel_hell01 Q167P   rel_heaven01 Q168P   rel_right01 Q169P   rel_mine01 Q170P   rel_attend01 Q171P   rel_pray01 Q172P   rel_pers01 Q173P   rel_good01 Q174   rel_thislife01 Q175   morals_hard01 Q176P   law_govben01 Q177   law_fare01 Q178   law_steal01 Q179   law_taxes01 Q180   law_bribe01 Q181   morals_gay01 Q182   morals_prost01 Q183   morals_abor01 Q184   morals_div01 Q185   morals_sex01 Q186   morals_suic01 Q187   morals_letdie01 Q188   viol_beatwife01 Q189   viol_childs01 Q190   viol_other01 Q191   viol_terror01 Q192   morals_casual01 Q193   viol_pol01 Q194   viol_death_pen01 Q195   surv_video01 Q196P   surv_email01 Q197P   surv_allinfo01 Q198P   polint01 Q199P   poltalk01 Q200P   news_paper01 Q201P   news_tv01 Q202P   news_radio01 Q203P   news_mobile01 Q204P   news_email01 Q205P   news_web01 Q206P   news_social01 Q207P   news_friends01 Q208P   polpart_pet01 Q209P   polpart_boy01 Q210P   polpart_prot01 Q211P   polpart_strikes01 Q212P   polpart_donate01 Q213P   polpart_contact01 Q214P   polpart_othact01 Q215P   polpart_othvote01 Q216P   polpart_socmed_search01 Q217P   polpart_socmed_sign01 Q218P   polpart_socmed_othact01 Q219P   polpart_socmed_organize01 Q220P   vote_local01 Q221P   vote_nat01 Q222P   elec_votes01 Q224P   elec_oppno01 Q225P   elec_press_incum01 Q226P   elec_bribe01 Q227P   elec_pressfair01 Q228P   elec_off01 Q229P   elec_rich01 Q230P   elec_viol01 Q231P   elec_choice01 Q232P   elec_fem01 Q233P   elec_say01 Q234AP   honelec_matter01 Q234P   dem_strong01 Q235P   dem_experts01 Q236P   dem_army01 Q237P   dem_dem01 Q238P   dem_rel01 Q239P   val_left01 Q240   essdem_poor01 Q241   essdem_rel01 Q242   essdem_elec01 Q243   essdem_unemp01 Q244   essdem_army01 Q245   essdem_liberty01 Q246   essdem_equal01 Q247   essdem_obey01 Q248   essdem_fem01 Q249   demimp01 Q250   howdem01 Q251   polsat01 Q252   perc_rights01 Q253P   nat_pride01 Q254P   close_local01 Q255P   seeself_local01 Q256P   seeself_reg01 Q257P   close_cont01 Q258P   close_world01 Q259P   female01 Q260   birthyr01 Q261   age01 Q262   forborn01 Q263   ma_forborn01 Q264   pa_forborn01 Q265   citizen01 Q269   hh_num01 Q270   hh_parents01 Q271   mar_nom Q273   hh_kidsnum01 Q274   educ01 Q275   sp_educ01 Q276   ma_educ01 Q277   pa_educ01 Q278   employ_nom Q279   sp_employ_nom Q280   occ_nom Q281   sp_occ_nom Q282   pa_occ_nom Q283   sector_nom Q284   chief_earn Q285   savings01 Q286   class01 Q287P   income01 Q288 , notes 

 
 
 
 
 
 
 
 * To make a compact data format that can be read if using Intercooled Stata, I deleted some of the original questions.
 
 * drop Q267 Q268 Q269 Q270 Q271 Q272 Q273 Q274 Q275 Q275R Q276 Q276R Q277 Q277A Q277R Q278 Q278R Q279 Q280 Q281 Q282 Q283 Q284 Q285 Q286 Q287P Q288 Q94 Q95 Q96 Q97 Q98 Q99 Q100 Q101 Q102 Q103 Q104 Q105 Q106 Q107 Q108 Q109 Q110 Q111 Q112 Q113 Q114 Q115 Q116 Q117 Q118 Q119P Q120 Q121 Q122 Q123 Q124 Q125 Q126 Q127 Q128 Q129 Q130P Q131P Q132P Q133P Q134P Q135P Q136P Q137P Q138P Q139P Q140P Q141P Q142P Q143P Q144P Q145P Q146P Q147P Q148P Q149 Q150 Q151P Q152 Q153 Q154 Q155 Q156 Q157 Q158 Q159 Q160 Q161 Q162 Q163 Q164 Q165P Q166P Q167P Q168P Q169P Q170P Q171P Q172P Q173P Q174 Q175 Q176P Q177 Q178 Q179 Q180 Q181 Q182 Q183 Q184 Q185 Q186 Q187 Q188 Q189 Q190 Q191 Q192 Q193 Q194 Q195 Q196P Q197P Q198P Q199P Q200P Q201P Q202P Q203P Q204P Q205P Q206P Q207P Q208P Q209P Q210P Q211P Q212P Q213P Q214P Q215P Q216P Q217P Q218P Q219P Q220P Q221P Q222P Q223 Q223_ABREV Q223_LOCAL Q224P Q225P Q226P Q227P Q228P Q229P Q230P Q231P Q232P Q233P Q234AP Q234P Q235P Q236P Q237P Q238P Q239P Q240 Q241 Q242 Q243 Q244 Q245 Q246 Q247 Q248 Q249 Q250 Q251 Q252 Q253P Q254P Q255P Q256P Q257P Q258P Q259P Q260 Q261 Q262 X003R X003R2 Q1P Q2P Q3P Q4P Q5P Q6P Q7P Q8P Q9P Q10P Q11P Q12P Q13P Q14P Q15P Q16P Q17P Q18P Q19P Q20P Q21P Q22P Q23P Q24P Q25P Q26P Q27P Q28P Q29P Q30P Q31P Q32P Q33_3 Q33P Q34_3 Q34P Q35_3 Q35P Q36P Q37P Q38P Q39P Q40P Q41P Q42 Q43P Q44P Q45P Q46P Q47P Q48 Q49 Q50 Q51P Q52P Q53P Q54P Q55P Q56P Q57P Q58P Q59P Q60P Q61P Q62P Q63P Q64P Q65P Q66P Q67P Q68P Q69P Q70P Q71P Q72P Q73P Q74P Q75P Q76P Q77P Q78P Q79P Q80P Q81P
